# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/faststripe',
                'doc_host': 'https://AnswerDotAI.github.io',
                'git_url': 'https://github.com/AnswerDotAI/faststripe',
                'lib_path': 'faststripe'},
  'syms': { 'faststripe.core': { 'faststripe.core.StripeApi': ('core.html#stripeapi', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__call__': ('core.html#stripeapi.__call__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__dir__': ('core.html#stripeapi.__dir__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__getattr__': ('core.html#stripeapi.__getattr__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__getitem__': ('core.html#stripeapi.__getitem__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.__init__': ('core.html#stripeapi.__init__', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi._prep': ('core.html#stripeapi._prep', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi._repr_markdown_': ('core.html#stripeapi._repr_markdown_', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.find_prices': ('core.html#stripeapi.find_prices', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.find_product': ('core.html#stripeapi.find_product', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.one_time_payment': ( 'core.html#stripeapi.one_time_payment',
                                                                                 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.priced_product': ('core.html#stripeapi.priced_product', 'faststripe/core.py'),
                                 'faststripe.core.StripeApi.subscription': ('core.html#stripeapi.subscription', 'faststripe/core.py'),
                                 'faststripe.core.StripeApiAsync': ('core.html#stripeapiasync', 'faststripe/core.py'),
                                 'faststripe.core.StripeApiAsync.__call__': ('core.html#stripeapiasync.__call__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIObj': ('core.html#_oapiobj', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb': ('core.html#_oapiverb', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb.__call__': ('core.html#_oapiverb.__call__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb.__init__': ('core.html#_oapiverb.__init__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb.__signature__': ('core.html#_oapiverb.__signature__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb.__str__': ('core.html#_oapiverb.__str__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerb._repr_markdown_': ('core.html#_oapiverb._repr_markdown_', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerbGroup': ('core.html#_oapiverbgroup', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerbGroup.__init__': ('core.html#_oapiverbgroup.__init__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerbGroup.__str__': ('core.html#_oapiverbgroup.__str__', 'faststripe/core.py'),
                                 'faststripe.core._OAPIVerbGroup._repr_markdown_': ( 'core.html#_oapiverbgroup._repr_markdown_',
                                                                                     'faststripe/core.py'),
                                 'faststripe.core._flatten_data': ('core.html#_flatten_data', 'faststripe/core.py'),
                                 'faststripe.core._mk_param': ('core.html#_mk_param', 'faststripe/core.py'),
                                 'faststripe.core._mk_sig': ('core.html#_mk_sig', 'faststripe/core.py'),
                                 'faststripe.core.op2nm': ('core.html#op2nm', 'faststripe/core.py'),
                                 'faststripe.core.paged': ('core.html#paged', 'faststripe/core.py'),
                                 'faststripe.core.pages': ('core.html#pages', 'faststripe/core.py')},
            'faststripe.endpoints': {},
            'faststripe.spec': { 'faststripe.spec._deets': ('spec.html#_deets', 'faststripe/spec.py'),
                                 'faststripe.spec._durl': ('spec.html#_durl', 'faststripe/spec.py'),
                                 'faststripe.spec._find_data': ('spec.html#_find_data', 'faststripe/spec.py'),
                                 'faststripe.spec._info': ('spec.html#_info', 'faststripe/spec.py'),
                                 'faststripe.spec._slug': ('spec.html#_slug', 'faststripe/spec.py'),
                                 'faststripe.spec.build_eps': ('spec.html#build_eps', 'faststripe/spec.py'),
                                 'faststripe.spec.update_version': ('spec.html#update_version', 'faststripe/spec.py')}}}
