eps = [{'data': [], 'doc_url': 'https://docs.stripe.com/api/accounts/retrieve', 'op_id': 'GetAccount', 'path': '/v1/account', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve account', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The identifier of the account to create an account link for.', 'name': 'account'},
           {'annotation': str, 'default': None, 'description': 'The collect parameter is deprecated. Use `collection_options` instead.', 'name': 'collect'},
           {'annotation': dict, 'default': None, 'description': 'Specifies the requirements that Stripe collects from connected accounts in the Connect Onboarding flow.', 'name': 'collection_options'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': "The URL the user will be redirected to if the account link is expired, has been previously-visited, or is otherwise invalid. The URL you specify should attempt to generate a new account link with the same parameters used to create the original account link, then redirect the user to the new account link's URL so they can "
                           'continue with Connect Onboarding. If a new account link cannot be generated or the redirect fails you should display a useful error to the user.',
            'name': 'refresh_url'},
           {'annotation': str, 'default': None, 'description': 'The URL that the user will be redirected to upon leaving or completing the linked flow.', 'name': 'return_url'},
           {'annotation': str,
            'default': None,
            'description': 'The type of account link the user is requesting.\n'
                           '\n'
                           "You can create Account Links of type `account_update` only for connected accounts where your platform is responsible for collecting requirements, including Custom accounts. You can't create them for accounts that have access to a Stripe-hosted Dashboard. If you use [Connect embedded "
                           'components](/connect/get-started-connect-embedded-components), you can include components that allow your connected accounts to update their own information. For an account without Stripe-hosted Dashboard access where Stripe is liable for negative balances, you must use embedded components.',
            'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/account_links/create',
  'op_id': 'PostAccountLinks',
  'path': '/v1/account_links',
  'qparams': [],
  'summary': 'Create an account link',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The identifier of the account to create an Account Session for.', 'name': 'account'},
           {'annotation': dict, 'default': None, 'description': 'Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).', 'name': 'components'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/account_sessions/create',
  'op_id': 'PostAccountSessions',
  'path': '/v1/account_sessions',
  'qparams': [],
  'summary': 'Create an Account Session',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/accounts/list',
  'op_id': 'GetAccounts',
  'path': '/v1/accounts',
  'qparams': [{'annotation': 'str', 'description': 'Only return connected accounts that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all connected accounts',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An [account token](https://api.stripe.com#create_account_token), used to securely provide details to the account.', 'name': 'account_token'},
           {'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': dict, 'default': None, 'description': 'Business information about the account.', 'name': 'business_profile'},
           {'annotation': str,
            'default': None,
            'description': 'The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'business_type'},
           {'annotation': dict,
            'default': None,
            'description': 'Each key of the dictionary represents a capability, and each capability\n'
                           'maps to its settings (for example, whether it has been requested or not). Each\n'
                           'capability is inactive until you have provided its specific\n'
                           'requirements and Stripe has verified them. An account might have some\n'
                           'of its requested capabilities be active and some be inactive.\n'
                           '\n'
                           'Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type)\n'
                           'is `none`, which includes Custom accounts.',
            'name': 'capabilities'},
           {'annotation': dict,
            'default': None,
            'description': 'Information about the company or business. This field is available for any `business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'company'},
           {'annotation': dict, 'default': None, 'description': "A hash of configuration describing the account controller's attributes.", 'name': 'controller'},
           {'annotation': str,
            'default': None,
            'description': "The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you're creating an account is legally represented in Canada, you would use `CA` as the country for the "
                           "account being created. Available countries include [Stripe's global markets](https://stripe.com/global) as well as countries where [cross-border payouts](https://stripe.com/docs/connect/cross-border-payouts) are supported.",
            'name': 'country'},
           {'annotation': str, 'default': None, 'description': "Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account's country](https://docs.stripe.com/payouts).", 'name': 'default_currency'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str,
            'default': None,
            'description': "The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts, Stripe doesn't email the account without your consent.",
            'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the `external_account` parameter for [bank '
                           'account](/api#account_create_bank_account) creation. <br><br>By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank '
                           'account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'external_account'},
           {'annotation': dict, 'default': None, 'description': 'A hash of account group type to tokens. These are account groups this account should be added to.', 'name': 'groups'},
           {'annotation': dict,
            'default': None,
            'description': 'Information about the person represented by the account. This field is null unless `business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'individual'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Options for customizing how the account functions within Stripe.', 'name': 'settings'},
           {'annotation': dict,
            'default': None,
            'description': "Details on the account's acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts. This "
                           'property defaults to a `full` service agreement when empty.',
            'name': 'tos_acceptance'},
           {'annotation': str, 'default': None, 'description': 'The type of Stripe account to create. May be one of `custom`, `express` or `standard`.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/accounts/create',
  'op_id': 'PostAccounts',
  'path': '/v1/accounts',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/accounts/delete', 'op_id': 'DeleteAccountsAccount', 'path': '/v1/accounts/{account}', 'qparams': [], 'summary': 'Delete an account', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/accounts/delete', 'op_id': 'GetAccountsAccount', 'path': '/v1/accounts/{account}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve account', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An [account token](https://api.stripe.com#create_account_token), used to securely provide details to the account.', 'name': 'account_token'},
           {'annotation': dict, 'default': None, 'description': 'Business information about the account.', 'name': 'business_profile'},
           {'annotation': str,
            'default': None,
            'description': 'The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'business_type'},
           {'annotation': dict,
            'default': None,
            'description': 'Each key of the dictionary represents a capability, and each capability\n'
                           'maps to its settings (for example, whether it has been requested or not). Each\n'
                           'capability is inactive until you have provided its specific\n'
                           'requirements and Stripe has verified them. An account might have some\n'
                           'of its requested capabilities be active and some be inactive.\n'
                           '\n'
                           'Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type)\n'
                           'is `none`, which includes Custom accounts.',
            'name': 'capabilities'},
           {'annotation': dict,
            'default': None,
            'description': 'Information about the company or business. This field is available for any `business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'company'},
           {'annotation': str, 'default': None, 'description': "Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account's country](https://docs.stripe.com/payouts).", 'name': 'default_currency'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str,
            'default': None,
            'description': "The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts, Stripe doesn't email the account without your consent.",
            'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the `external_account` parameter for [bank '
                           'account](/api#account_create_bank_account) creation. <br><br>By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank '
                           'account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'external_account'},
           {'annotation': dict, 'default': None, 'description': 'A hash of account group type to tokens. These are account groups this account should be added to.', 'name': 'groups'},
           {'annotation': dict,
            'default': None,
            'description': 'Information about the person represented by the account. This field is null unless `business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where '
                           '[controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.',
            'name': 'individual'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Options for customizing how the account functions within Stripe.', 'name': 'settings'},
           {'annotation': dict,
            'default': None,
            'description': "Details on the account's acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts. This "
                           'property defaults to a `full` service agreement when empty.',
            'name': 'tos_acceptance'}],
  'doc_url': 'https://docs.stripe.com/api/accounts/update',
  'op_id': 'PostAccountsAccount',
  'path': '/v1/accounts/{account}',
  'qparams': [],
  'summary': 'Update an account',
  'verb': 'post'},
 {'data': [{'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': bool, 'default': None, 'description': 'When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.', 'name': 'default_for_currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "A token, like the ones returned by [Stripe.js](https://docs.stripe.com/js) or a dictionary containing a user's external account details (with the options shown below). Please refer to full [documentation](https://stripe.com/docs/api/external_accounts) instead.", 'name': 'external_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/update',
  'op_id': 'PostAccountsAccountBankAccounts',
  'path': '/v1/accounts/{account}/bank_accounts',
  'qparams': [],
  'summary': 'Create an external account',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/bank_accounts/delete', 'op_id': 'DeleteAccountsAccountBankAccountsId', 'path': '/v1/accounts/{account}/bank_accounts/{id}', 'qparams': [], 'summary': 'Delete an external account', 'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/delete',
  'op_id': 'GetAccountsAccountBankAccountsId',
  'path': '/v1/accounts/{account}/bank_accounts/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an external account',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'The bank account type. This can only be `checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.', 'name': 'account_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': bool, 'default': None, 'description': 'When set to true, this becomes the default external account for its currency.', 'name': 'default_for_currency'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/update',
  'op_id': 'PostAccountsAccountBankAccountsId',
  'path': '/v1/accounts/{account}/bank_accounts/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/capabilities/delete', 'op_id': 'GetAccountsAccountCapabilities', 'path': '/v1/accounts/{account}/capabilities', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'List all account capabilities', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/capabilities/delete',
  'op_id': 'GetAccountsAccountCapabilitiesCapability',
  'path': '/v1/accounts/{account}/capabilities/{capability}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an Account Capability',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool,
            'default': None,
            'description': 'To request a new capability for an account, pass true. There can be a delay before the requested capability becomes active. If the capability has any activation requirements, the response includes them in the `requirements` arrays.\n'
                           '\n'
                           "If a capability isn't permanent, you can remove it from the account by passing false. Some capabilities are permanent after they've been requested. Attempting to remove a permanent capability returns an error.",
            'name': 'requested'}],
  'doc_url': 'https://docs.stripe.com/api/capabilities/update',
  'op_id': 'PostAccountsAccountCapabilitiesCapability',
  'path': '/v1/accounts/{account}/capabilities/{capability}',
  'qparams': [],
  'summary': 'Update an Account Capability',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/external_accounts/delete',
  'op_id': 'GetAccountsAccountExternalAccounts',
  'path': '/v1/accounts/{account}/external_accounts',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Filter external accounts according to a particular object type.', 'name': 'object'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all external accounts',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': bool, 'default': None, 'description': 'When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.', 'name': 'default_for_currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "A token, like the ones returned by [Stripe.js](https://docs.stripe.com/js) or a dictionary containing a user's external account details (with the options shown below). Please refer to full [documentation](https://stripe.com/docs/api/external_accounts) instead.", 'name': 'external_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/external_accounts/update',
  'op_id': 'PostAccountsAccountExternalAccounts',
  'path': '/v1/accounts/{account}/external_accounts',
  'qparams': [],
  'summary': 'Create an external account',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/external_accounts/delete', 'op_id': 'DeleteAccountsAccountExternalAccountsId', 'path': '/v1/accounts/{account}/external_accounts/{id}', 'qparams': [], 'summary': 'Delete an external account', 'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/external_accounts/delete',
  'op_id': 'GetAccountsAccountExternalAccountsId',
  'path': '/v1/accounts/{account}/external_accounts/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an external account',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'The bank account type. This can only be `checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.', 'name': 'account_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': bool, 'default': None, 'description': 'When set to true, this becomes the default external account for its currency.', 'name': 'default_for_currency'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/external_accounts/update',
  'op_id': 'PostAccountsAccountExternalAccountsId',
  'path': '/v1/accounts/{account}/external_accounts/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/login_links/update', 'op_id': 'PostAccountsAccountLoginLinks', 'path': '/v1/accounts/{account}/login_links', 'qparams': [], 'summary': 'Create a login link', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/peoples/retrieve',
  'op_id': 'GetAccountsAccountPeople',
  'path': '/v1/accounts/{account}/people',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "Filters on the list of people returned based on the person's relationship to the account's company.", 'name': 'relationship'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all persons',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Details on the legal guardian's or authorizer's acceptance of the required Stripe agreements.", 'name': 'additional_tos_acceptances'},
           {'annotation': dict, 'default': None, 'description': "The person's address.", 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': "The Kana variation of the person's address (Japan only).", 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': "The Kanji variation of the person's address (Japan only).", 'name': 'address_kanji'},
           {'annotation': object, 'default': None, 'description': "The person's date of birth.", 'name': 'dob'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': "The person's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The person's first name.", 'name': 'first_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's first name (Japan only).", 'name': 'first_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's first name (Japan only).", 'name': 'first_name_kanji'},
           {'annotation': object, 'default': None, 'description': 'A list of alternate names or aliases that the person is known by.', 'name': 'full_name_aliases'},
           {'annotation': str, 'default': None, 'description': 'The person\'s gender (International regulations require either "male" or "female").', 'name': 'gender'},
           {'annotation': str,
            'default': None,
            'description': "The person's ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).",
            'name': 'id_number'},
           {'annotation': str,
            'default': None,
            'description': "The person's secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by "
                           'Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).',
            'name': 'id_number_secondary'},
           {'annotation': str, 'default': None, 'description': "The person's last name.", 'name': 'last_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's last name (Japan only).", 'name': 'last_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's last name (Japan only).", 'name': 'last_name_kanji'},
           {'annotation': str, 'default': None, 'description': "The person's maiden name.", 'name': 'maiden_name'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or "XX" if unavailable.', 'name': 'nationality'},
           {'annotation': str, 'default': None, 'description': 'A [person token](https://docs.stripe.com/connect/account-tokens), used to securely provide details to the person.', 'name': 'person_token'},
           {'annotation': str, 'default': None, 'description': "The person's phone number.", 'name': 'phone'},
           {'annotation': str, 'default': None, 'description': 'Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.', 'name': 'political_exposure'},
           {'annotation': dict, 'default': None, 'description': "The person's registered address.", 'name': 'registered_address'},
           {'annotation': dict, 'default': None, 'description': "The relationship that this person has with the account's legal entity.", 'name': 'relationship'},
           {'annotation': str, 'default': None, 'description': "The last four digits of the person's Social Security number (U.S. only).", 'name': 'ssn_last_4'},
           {'annotation': dict, 'default': None, 'description': 'Demographic data related to the person.', 'name': 'us_cfpb_data'},
           {'annotation': dict, 'default': None, 'description': "The person's verification status.", 'name': 'verification'}],
  'doc_url': 'https://docs.stripe.com/api/peoples/update',
  'op_id': 'PostAccountsAccountPeople',
  'path': '/v1/accounts/{account}/people',
  'qparams': [],
  'summary': 'Create a person',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/peoples/delete', 'op_id': 'DeleteAccountsAccountPeoplePerson', 'path': '/v1/accounts/{account}/people/{person}', 'qparams': [], 'summary': 'Delete a person', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/peoples/retrieve', 'op_id': 'GetAccountsAccountPeoplePerson', 'path': '/v1/accounts/{account}/people/{person}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a person', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Details on the legal guardian's or authorizer's acceptance of the required Stripe agreements.", 'name': 'additional_tos_acceptances'},
           {'annotation': dict, 'default': None, 'description': "The person's address.", 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': "The Kana variation of the person's address (Japan only).", 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': "The Kanji variation of the person's address (Japan only).", 'name': 'address_kanji'},
           {'annotation': object, 'default': None, 'description': "The person's date of birth.", 'name': 'dob'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': "The person's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The person's first name.", 'name': 'first_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's first name (Japan only).", 'name': 'first_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's first name (Japan only).", 'name': 'first_name_kanji'},
           {'annotation': object, 'default': None, 'description': 'A list of alternate names or aliases that the person is known by.', 'name': 'full_name_aliases'},
           {'annotation': str, 'default': None, 'description': 'The person\'s gender (International regulations require either "male" or "female").', 'name': 'gender'},
           {'annotation': str,
            'default': None,
            'description': "The person's ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).",
            'name': 'id_number'},
           {'annotation': str,
            'default': None,
            'description': "The person's secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by "
                           'Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).',
            'name': 'id_number_secondary'},
           {'annotation': str, 'default': None, 'description': "The person's last name.", 'name': 'last_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's last name (Japan only).", 'name': 'last_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's last name (Japan only).", 'name': 'last_name_kanji'},
           {'annotation': str, 'default': None, 'description': "The person's maiden name.", 'name': 'maiden_name'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or "XX" if unavailable.', 'name': 'nationality'},
           {'annotation': str, 'default': None, 'description': 'A [person token](https://docs.stripe.com/connect/account-tokens), used to securely provide details to the person.', 'name': 'person_token'},
           {'annotation': str, 'default': None, 'description': "The person's phone number.", 'name': 'phone'},
           {'annotation': str, 'default': None, 'description': 'Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.', 'name': 'political_exposure'},
           {'annotation': dict, 'default': None, 'description': "The person's registered address.", 'name': 'registered_address'},
           {'annotation': dict, 'default': None, 'description': "The relationship that this person has with the account's legal entity.", 'name': 'relationship'},
           {'annotation': str, 'default': None, 'description': "The last four digits of the person's Social Security number (U.S. only).", 'name': 'ssn_last_4'},
           {'annotation': dict, 'default': None, 'description': 'Demographic data related to the person.', 'name': 'us_cfpb_data'},
           {'annotation': dict, 'default': None, 'description': "The person's verification status.", 'name': 'verification'}],
  'doc_url': 'https://docs.stripe.com/api/peoples/update',
  'op_id': 'PostAccountsAccountPeoplePerson',
  'path': '/v1/accounts/{account}/people/{person}',
  'qparams': [],
  'summary': 'Update a person',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/persons/delete',
  'op_id': 'GetAccountsAccountPersons',
  'path': '/v1/accounts/{account}/persons',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "Filters on the list of people returned based on the person's relationship to the account's company.", 'name': 'relationship'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all persons',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Details on the legal guardian's or authorizer's acceptance of the required Stripe agreements.", 'name': 'additional_tos_acceptances'},
           {'annotation': dict, 'default': None, 'description': "The person's address.", 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': "The Kana variation of the person's address (Japan only).", 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': "The Kanji variation of the person's address (Japan only).", 'name': 'address_kanji'},
           {'annotation': object, 'default': None, 'description': "The person's date of birth.", 'name': 'dob'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': "The person's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The person's first name.", 'name': 'first_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's first name (Japan only).", 'name': 'first_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's first name (Japan only).", 'name': 'first_name_kanji'},
           {'annotation': object, 'default': None, 'description': 'A list of alternate names or aliases that the person is known by.', 'name': 'full_name_aliases'},
           {'annotation': str, 'default': None, 'description': 'The person\'s gender (International regulations require either "male" or "female").', 'name': 'gender'},
           {'annotation': str,
            'default': None,
            'description': "The person's ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).",
            'name': 'id_number'},
           {'annotation': str,
            'default': None,
            'description': "The person's secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by "
                           'Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).',
            'name': 'id_number_secondary'},
           {'annotation': str, 'default': None, 'description': "The person's last name.", 'name': 'last_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's last name (Japan only).", 'name': 'last_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's last name (Japan only).", 'name': 'last_name_kanji'},
           {'annotation': str, 'default': None, 'description': "The person's maiden name.", 'name': 'maiden_name'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or "XX" if unavailable.', 'name': 'nationality'},
           {'annotation': str, 'default': None, 'description': 'A [person token](https://docs.stripe.com/connect/account-tokens), used to securely provide details to the person.', 'name': 'person_token'},
           {'annotation': str, 'default': None, 'description': "The person's phone number.", 'name': 'phone'},
           {'annotation': str, 'default': None, 'description': 'Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.', 'name': 'political_exposure'},
           {'annotation': dict, 'default': None, 'description': "The person's registered address.", 'name': 'registered_address'},
           {'annotation': dict, 'default': None, 'description': "The relationship that this person has with the account's legal entity.", 'name': 'relationship'},
           {'annotation': str, 'default': None, 'description': "The last four digits of the person's Social Security number (U.S. only).", 'name': 'ssn_last_4'},
           {'annotation': dict, 'default': None, 'description': 'Demographic data related to the person.', 'name': 'us_cfpb_data'},
           {'annotation': dict, 'default': None, 'description': "The person's verification status.", 'name': 'verification'}],
  'doc_url': 'https://docs.stripe.com/api/persons/update',
  'op_id': 'PostAccountsAccountPersons',
  'path': '/v1/accounts/{account}/persons',
  'qparams': [],
  'summary': 'Create a person',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/persons/delete', 'op_id': 'DeleteAccountsAccountPersonsPerson', 'path': '/v1/accounts/{account}/persons/{person}', 'qparams': [], 'summary': 'Delete a person', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/persons/delete', 'op_id': 'GetAccountsAccountPersonsPerson', 'path': '/v1/accounts/{account}/persons/{person}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a person', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Details on the legal guardian's or authorizer's acceptance of the required Stripe agreements.", 'name': 'additional_tos_acceptances'},
           {'annotation': dict, 'default': None, 'description': "The person's address.", 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': "The Kana variation of the person's address (Japan only).", 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': "The Kanji variation of the person's address (Japan only).", 'name': 'address_kanji'},
           {'annotation': object, 'default': None, 'description': "The person's date of birth.", 'name': 'dob'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': "The person's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The person's first name.", 'name': 'first_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's first name (Japan only).", 'name': 'first_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's first name (Japan only).", 'name': 'first_name_kanji'},
           {'annotation': object, 'default': None, 'description': 'A list of alternate names or aliases that the person is known by.', 'name': 'full_name_aliases'},
           {'annotation': str, 'default': None, 'description': 'The person\'s gender (International regulations require either "male" or "female").', 'name': 'gender'},
           {'annotation': str,
            'default': None,
            'description': "The person's ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).",
            'name': 'id_number'},
           {'annotation': str,
            'default': None,
            'description': "The person's secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by "
                           'Stripe.js](https://docs.stripe.com/js/tokens/create_token?type=pii).',
            'name': 'id_number_secondary'},
           {'annotation': str, 'default': None, 'description': "The person's last name.", 'name': 'last_name'},
           {'annotation': str, 'default': None, 'description': "The Kana variation of the person's last name (Japan only).", 'name': 'last_name_kana'},
           {'annotation': str, 'default': None, 'description': "The Kanji variation of the person's last name (Japan only).", 'name': 'last_name_kanji'},
           {'annotation': str, 'default': None, 'description': "The person's maiden name.", 'name': 'maiden_name'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or "XX" if unavailable.', 'name': 'nationality'},
           {'annotation': str, 'default': None, 'description': 'A [person token](https://docs.stripe.com/connect/account-tokens), used to securely provide details to the person.', 'name': 'person_token'},
           {'annotation': str, 'default': None, 'description': "The person's phone number.", 'name': 'phone'},
           {'annotation': str, 'default': None, 'description': 'Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.', 'name': 'political_exposure'},
           {'annotation': dict, 'default': None, 'description': "The person's registered address.", 'name': 'registered_address'},
           {'annotation': dict, 'default': None, 'description': "The relationship that this person has with the account's legal entity.", 'name': 'relationship'},
           {'annotation': str, 'default': None, 'description': "The last four digits of the person's Social Security number (U.S. only).", 'name': 'ssn_last_4'},
           {'annotation': dict, 'default': None, 'description': 'Demographic data related to the person.', 'name': 'us_cfpb_data'},
           {'annotation': dict, 'default': None, 'description': "The person's verification status.", 'name': 'verification'}],
  'doc_url': 'https://docs.stripe.com/api/persons/update',
  'op_id': 'PostAccountsAccountPersonsPerson',
  'path': '/v1/accounts/{account}/persons/{person}',
  'qparams': [],
  'summary': 'Update a person',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': str, 'default': None, 'description': 'The reason for rejecting the account. Can be `fraud`, `terms_of_service`, or `other`.', 'name': 'reason'}],
  'doc_url': 'https://docs.stripe.com/api/rejects/update',
  'op_id': 'PostAccountsAccountReject',
  'path': '/v1/accounts/{account}/reject',
  'qparams': [],
  'summary': 'Reject an account',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/domains/list',
  'op_id': 'GetApplePayDomains',
  'path': '/v1/apple_pay/domains',
  'qparams': [{'annotation': 'str', 'description': '', 'name': 'domain_name'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': '',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': '', 'name': 'domain_name'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/domains/create',
  'op_id': 'PostApplePayDomains',
  'path': '/v1/apple_pay/domains',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/domains/delete', 'op_id': 'DeleteApplePayDomainsDomain', 'path': '/v1/apple_pay/domains/{domain}', 'qparams': [], 'summary': '', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/domains/delete', 'op_id': 'GetApplePayDomainsDomain', 'path': '/v1/apple_pay/domains/{domain}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': '', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/application_fees/list',
  'op_id': 'GetApplicationFees',
  'path': '/v1/application_fees',
  'qparams': [{'annotation': 'str', 'description': 'Only return application fees for the charge specified by this charge ID.', 'name': 'charge'},
              {'annotation': 'str', 'description': 'Only return applications fees that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all application fees',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/refunds/delete', 'op_id': 'GetApplicationFeesFeeRefundsId', 'path': '/v1/application_fees/{fee}/refunds/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an application fee refund', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostApplicationFeesFeeRefundsId',
  'path': '/v1/application_fees/{fee}/refunds/{id}',
  'qparams': [],
  'summary': 'Update an application fee refund',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/application_fees/delete', 'op_id': 'GetApplicationFeesId', 'path': '/v1/application_fees/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an application fee', 'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': '', 'name': 'amount'}, {'annotation': str, 'default': None, 'description': '', 'name': 'directive'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostApplicationFeesIdRefund',
  'path': '/v1/application_fees/{id}/refund',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/refunds/delete',
  'op_id': 'GetApplicationFeesIdRefunds',
  'path': '/v1/application_fees/{id}/refunds',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all application fee refunds',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer, in _cents (or local equivalent)_, representing how much of this fee to refund. Can refund only up to the remaining unrefunded amount of the fee.', 'name': 'amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostApplicationFeesIdRefunds',
  'path': '/v1/application_fees/{id}/refunds',
  'qparams': [],
  'summary': 'Create an application fee refund',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/secrets/list',
  'op_id': 'GetAppsSecrets',
  'path': '/v1/apps/secrets',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.', 'name': 'scope'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List secrets',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The Unix timestamp for the expiry time of the secret, after which the secret deletes.', 'name': 'expires_at'},
           {'annotation': str, 'default': None, 'description': "A name for the secret that's unique within the scope.", 'name': 'name'},
           {'annotation': str, 'default': None, 'description': 'The plaintext secret value to be stored.', 'name': 'payload'},
           {'annotation': dict, 'default': None, 'description': 'Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.', 'name': 'scope'}],
  'doc_url': 'https://docs.stripe.com/api/secrets/create',
  'op_id': 'PostAppsSecrets',
  'path': '/v1/apps/secrets',
  'qparams': [],
  'summary': 'Set a Secret',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "A name for the secret that's unique within the scope.", 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': 'Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.', 'name': 'scope'}],
  'doc_url': 'https://docs.stripe.com/api/deletes/create',
  'op_id': 'PostAppsSecretsDelete',
  'path': '/v1/apps/secrets/delete',
  'qparams': [],
  'summary': 'Delete a Secret',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/finds/retrieve',
  'op_id': 'GetAppsSecretsFind',
  'path': '/v1/apps/secrets/find',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': "A name for the secret that's unique within the scope.", 'name': 'name'},
              {'annotation': 'str', 'description': 'Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.', 'name': 'scope'}],
  'summary': 'Find a Secret',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/balances/retrieve', 'op_id': 'GetBalance', 'path': '/v1/balance', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve balance', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/historys/retrieve',
  'op_id': 'GetBalanceHistory',
  'path': '/v1/balance/history',
  'qparams': [{'annotation': 'str', 'description': 'Only return transactions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return transactions in a certain currency. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'For automatic Stripe payouts only, only returns transactions that were paid out on the specified payout ID.', 'name': 'payout'},
              {'annotation': 'str', 'description': 'Only returns transactions associated with the given object.', 'name': 'source'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str',
               'description': 'Only returns transactions of the given type. One of: `adjustment`, `advance`, `advance_funding`, `anticipation_repayment`, `application_fee`, `application_fee_refund`, `charge`, `climate_order_purchase`, `climate_order_refund`, `connect_collection_transfer`, `contribution`, `issuing_authorization_hold`, '
                              '`issuing_authorization_release`, `issuing_dispute`, `issuing_transaction`, `obligation_outbound`, `obligation_reversal_inbound`, `payment`, `payment_failure_refund`, `payment_network_reserve_hold`, `payment_network_reserve_release`, `payment_refund`, `payment_reversal`, `payment_unreconciled`, `payout`, `payout_cancel`, '
                              '`payout_failure`, `payout_minimum_balance_hold`, `payout_minimum_balance_release`, `refund`, `refund_failure`, `reserve_transaction`, `reserved_funds`, `reserve_hold`, `reserve_release`, `stripe_fee`, `stripe_fx_fee`, `stripe_balance_payment_debit`, `stripe_balance_payment_debit_reversal`, `tax_fee`, `topup`, '
                              '`topup_reversal`, `transfer`, `transfer_cancel`, `transfer_failure`, or `transfer_refund`.',
               'name': 'type'}],
  'summary': 'List all balance transactions',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/historys/retrieve', 'op_id': 'GetBalanceHistoryId', 'path': '/v1/balance/history/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a balance transaction', 'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/balance_settings/list', 'op_id': 'GetBalanceSettings', 'path': '/v1/balance_settings', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve balance settings', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Settings that apply to the [Payments Balance](https://docs.stripe.com/api/balance).', 'name': 'payments'}],
  'doc_url': 'https://docs.stripe.com/api/balance_settings/create',
  'op_id': 'PostBalanceSettings',
  'path': '/v1/balance_settings',
  'qparams': [],
  'summary': 'Update balance settings',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/balance_transactions/list',
  'op_id': 'GetBalanceTransactions',
  'path': '/v1/balance_transactions',
  'qparams': [{'annotation': 'str', 'description': 'Only return transactions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return transactions in a certain currency. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'For automatic Stripe payouts only, only returns transactions that were paid out on the specified payout ID.', 'name': 'payout'},
              {'annotation': 'str', 'description': 'Only returns transactions associated with the given object.', 'name': 'source'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str',
               'description': 'Only returns transactions of the given type. One of: `adjustment`, `advance`, `advance_funding`, `anticipation_repayment`, `application_fee`, `application_fee_refund`, `charge`, `climate_order_purchase`, `climate_order_refund`, `connect_collection_transfer`, `contribution`, `issuing_authorization_hold`, '
                              '`issuing_authorization_release`, `issuing_dispute`, `issuing_transaction`, `obligation_outbound`, `obligation_reversal_inbound`, `payment`, `payment_failure_refund`, `payment_network_reserve_hold`, `payment_network_reserve_release`, `payment_refund`, `payment_reversal`, `payment_unreconciled`, `payout`, `payout_cancel`, '
                              '`payout_failure`, `payout_minimum_balance_hold`, `payout_minimum_balance_release`, `refund`, `refund_failure`, `reserve_transaction`, `reserved_funds`, `reserve_hold`, `reserve_release`, `stripe_fee`, `stripe_fx_fee`, `stripe_balance_payment_debit`, `stripe_balance_payment_debit_reversal`, `tax_fee`, `topup`, '
                              '`topup_reversal`, `transfer`, `transfer_cancel`, `transfer_failure`, or `transfer_refund`.',
               'name': 'type'}],
  'summary': 'List all balance transactions',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/balance_transactions/delete', 'op_id': 'GetBalanceTransactionsId', 'path': '/v1/balance_transactions/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a balance transaction', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/alerts/list',
  'op_id': 'GetBillingAlerts',
  'path': '/v1/billing/alerts',
  'qparams': [{'annotation': 'str', 'description': 'Filter results to only include this type of alert.', 'name': 'alert_type'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Filter results to only include alerts with the given meter.', 'name': 'meter'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List billing alerts',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The type of alert to create.', 'name': 'alert_type'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The title of the alert.', 'name': 'title'},
           {'annotation': dict, 'default': None, 'description': 'The configuration of the usage threshold.', 'name': 'usage_threshold'}],
  'doc_url': 'https://docs.stripe.com/api/alerts/create',
  'op_id': 'PostBillingAlerts',
  'path': '/v1/billing/alerts',
  'qparams': [],
  'summary': 'Create a billing alert',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/alerts/delete', 'op_id': 'GetBillingAlertsId', 'path': '/v1/billing/alerts/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a billing alert', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/activates/update', 'op_id': 'PostBillingAlertsIdActivate', 'path': '/v1/billing/alerts/{id}/activate', 'qparams': [], 'summary': 'Activate a billing alert', 'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/archives/update', 'op_id': 'PostBillingAlertsIdArchive', 'path': '/v1/billing/alerts/{id}/archive', 'qparams': [], 'summary': 'Archive a billing alert', 'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/deactivates/update',
  'op_id': 'PostBillingAlertsIdDeactivate',
  'path': '/v1/billing/alerts/{id}/deactivate',
  'qparams': [],
  'summary': 'Deactivate a billing alert',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_balance_summarys/retrieve',
  'op_id': 'GetBillingCreditBalanceSummary',
  'path': '/v1/billing/credit_balance_summary',
  'qparams': [{'annotation': 'str', 'description': "The customer whose credit balance summary you're retrieving.", 'name': 'customer'},
              {'annotation': 'str', 'description': "The account representing the customer whose credit balance summary you're retrieving.", 'name': 'customer_account'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'The filter criteria for the credit balance summary.', 'name': 'filter'}],
  'summary': 'Retrieve the credit balance summary for a customer',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_balance_transactions/list',
  'op_id': 'GetBillingCreditBalanceTransactions',
  'path': '/v1/billing/credit_balance_transactions',
  'qparams': [{'annotation': 'str', 'description': 'The credit grant for which to fetch credit balance transactions.', 'name': 'credit_grant'},
              {'annotation': 'str', 'description': "The customer whose credit balance transactions you're retrieving.", 'name': 'customer'},
              {'annotation': 'str', 'description': "The account representing the customer whose credit balance transactions you're retrieving.", 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List credit balance transactions',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_balance_transactions/delete',
  'op_id': 'GetBillingCreditBalanceTransactionsId',
  'path': '/v1/billing/credit_balance_transactions/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a credit balance transaction',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_grants/list',
  'op_id': 'GetBillingCreditGrants',
  'path': '/v1/billing/credit_grants',
  'qparams': [{'annotation': 'str', 'description': 'Only return credit grants for this customer.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return credit grants for this account representing the customer.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List credit grants',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Amount of this credit grant.', 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Configuration specifying what this credit grant applies to. We currently only support `metered` prices that have a [Billing Meter](https://docs.stripe.com/api/billing/meter) attached to them.', 'name': 'applicability_config'},
           {'annotation': str, 'default': None, 'description': 'The category of this credit grant. It defaults to `paid` if not specified.', 'name': 'category'},
           {'annotation': str, 'default': None, 'description': 'ID of the customer receiving the billing credits.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'ID of the account representing the customer receiving the billing credits.', 'name': 'customer_account'},
           {'annotation': int, 'default': None, 'description': "The time when the billing credits become effective-when they're eligible for use. It defaults to the current timestamp if not specified.", 'name': 'effective_at'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': "The time when the billing credits expire. If not specified, the billing credits don't expire.", 'name': 'expires_at'},
           {'annotation': dict, 'default': None, 'description': 'Set of key-value pairs that you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.', 'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'A descriptive name shown in the Dashboard.', 'name': 'name'},
           {'annotation': int, 'default': None, 'description': 'The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.', 'name': 'priority'}],
  'doc_url': 'https://docs.stripe.com/api/credit_grants/create',
  'op_id': 'PostBillingCreditGrants',
  'path': '/v1/billing/credit_grants',
  'qparams': [],
  'summary': 'Create a credit grant',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/credit_grants/delete', 'op_id': 'GetBillingCreditGrantsId', 'path': '/v1/billing/credit_grants/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a credit grant', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'The time when the billing credits created by this credit grant expire. If set to empty, the billing credits never expire.', 'name': 'expires_at'},
           {'annotation': dict, 'default': None, 'description': 'Set of key-value pairs you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.', 'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/credit_grants/update',
  'op_id': 'PostBillingCreditGrantsId',
  'path': '/v1/billing/credit_grants/{id}',
  'qparams': [],
  'summary': 'Update a credit grant',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/expires/update',
  'op_id': 'PostBillingCreditGrantsIdExpire',
  'path': '/v1/billing/credit_grants/{id}/expire',
  'qparams': [],
  'summary': 'Expire a credit grant',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/voids/update', 'op_id': 'PostBillingCreditGrantsIdVoid', 'path': '/v1/billing/credit_grants/{id}/void', 'qparams': [], 'summary': 'Void a credit grant', 'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Specifies which event to cancel.', 'name': 'cancel'},
           {'annotation': str, 'default': None, 'description': 'The name of the meter event. Corresponds with the `event_name` field on a meter.', 'name': 'event_name'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/meter_event_adjustments/create',
  'op_id': 'PostBillingMeterEventAdjustments',
  'path': '/v1/billing/meter_event_adjustments',
  'qparams': [],
  'summary': 'Create a billing meter event adjustment',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the meter event. Corresponds with the `event_name` field on a meter.', 'name': 'event_name'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'A unique identifier for the event. If not provided, one is generated. We recommend using UUID-like identifiers. We will enforce uniqueness within a rolling period of at least 24 hours. The enforcement of uniqueness primarily addresses issues arising from accidental retries or other problems occurring within extremely brief time '
                           'intervals. This approach helps prevent duplicate entries and ensures data integrity in high-frequency operations.',
            'name': 'identifier'},
           {'annotation': dict,
            'default': None,
            'description': "The payload of the event. This must contain the fields corresponding to a meter's `customer_mapping.event_payload_key` (default is `stripe_customer_id`) and `value_settings.event_payload_key` (default is `value`). Read more about the "
                           '[payload](https://docs.stripe.com/billing/subscriptions/usage-based/meters/configure#meter-configuration-attributes).',
            'name': 'payload'},
           {'annotation': int, 'default': None, 'description': 'The time of the event. Measured in seconds since the Unix epoch. Must be within the past 35 calendar days or up to 5 minutes in the future. Defaults to current timestamp if not specified.', 'name': 'timestamp'}],
  'doc_url': 'https://docs.stripe.com/api/meter_events/create',
  'op_id': 'PostBillingMeterEvents',
  'path': '/v1/billing/meter_events',
  'qparams': [],
  'summary': 'Create a billing meter event',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/meters/list',
  'op_id': 'GetBillingMeters',
  'path': '/v1/billing/meters',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Filter results to only include meters with the given status.', 'name': 'status'}],
  'summary': 'List billing meters',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Fields that specify how to map a meter event to a customer.', 'name': 'customer_mapping'},
           {'annotation': dict, 'default': None, 'description': "The default settings to aggregate a meter's events with.", 'name': 'default_aggregation'},
           {'annotation': str, 'default': None, 'description': 'The meter’s name. Not visible to the customer.', 'name': 'display_name'},
           {'annotation': str, 'default': None, 'description': 'The name of the meter event to record usage for. Corresponds with the `event_name` field on meter events.', 'name': 'event_name'},
           {'annotation': str, 'default': None, 'description': 'The time window which meter events have been pre-aggregated for, if any.', 'name': 'event_time_window'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': "Fields that specify how to calculate a meter event's value.", 'name': 'value_settings'}],
  'doc_url': 'https://docs.stripe.com/api/meters/create',
  'op_id': 'PostBillingMeters',
  'path': '/v1/billing/meters',
  'qparams': [],
  'summary': 'Create a billing meter',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/meters/delete', 'op_id': 'GetBillingMetersId', 'path': '/v1/billing/meters/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a billing meter', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The meter’s name. Not visible to the customer.', 'name': 'display_name'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/meters/update',
  'op_id': 'PostBillingMetersId',
  'path': '/v1/billing/meters/{id}',
  'qparams': [],
  'summary': 'Update a billing meter',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/deactivates/update',
  'op_id': 'PostBillingMetersIdDeactivate',
  'path': '/v1/billing/meters/{id}/deactivate',
  'qparams': [],
  'summary': 'Deactivate a billing meter',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/event_summaries/delete',
  'op_id': 'GetBillingMetersIdEventSummaries',
  'path': '/v1/billing/meters/{id}/event_summaries',
  'qparams': [{'annotation': 'str', 'description': 'The customer for which to fetch event summaries.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'The timestamp from when to stop aggregating meter events (exclusive). Must be aligned with minute boundaries.', 'name': 'end_time'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The timestamp from when to start aggregating meter events (inclusive). Must be aligned with minute boundaries.', 'name': 'start_time'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str',
               'description': 'Specifies what granularity to use when generating event summaries. If not specified, a single event summary would be returned for the specified time range. For hourly granularity, start and end times must align with hour boundaries (e.g., 00:00, 01:00, ..., 23:00). For daily granularity, start and end times must align with '
                              'UTC day boundaries (00:00 UTC).',
               'name': 'value_grouping_window'}],
  'summary': 'List billing meter event summaries',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/reactivates/update',
  'op_id': 'PostBillingMetersIdReactivate',
  'path': '/v1/billing/meters/{id}/reactivate',
  'qparams': [],
  'summary': 'Reactivate a billing meter',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/configurations/list',
  'op_id': 'GetBillingPortalConfigurations',
  'path': '/v1/billing_portal/configurations',
  'qparams': [{'annotation': 'str', 'description': 'Only return configurations that are active or inactive (e.g., pass `true` to only list active configurations).', 'name': 'active'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return the default or non-default configurations (e.g., pass `true` to only list the default configuration).', 'name': 'is_default'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List portal configurations',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The business information shown to customers in the portal.', 'name': 'business_profile'},
           {'annotation': object, 'default': None, 'description': "The default URL to redirect customers to when they click on the portal's link to return to your website. This can be [overriden](https://docs.stripe.com/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.", 'name': 'default_return_url'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about the features available in the portal.', 'name': 'features'},
           {'annotation': dict, 'default': None, 'description': 'The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](https://stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).', 'name': 'login_page'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The name of the configuration.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/configurations/create',
  'op_id': 'PostBillingPortalConfigurations',
  'path': '/v1/billing_portal/configurations',
  'qparams': [],
  'summary': 'Create a portal configuration',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/configurations/delete',
  'op_id': 'GetBillingPortalConfigurationsConfiguration',
  'path': '/v1/billing_portal/configurations/{configuration}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a portal configuration',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the configuration is active and can be used to create portal sessions.', 'name': 'active'},
           {'annotation': dict, 'default': None, 'description': 'The business information shown to customers in the portal.', 'name': 'business_profile'},
           {'annotation': object, 'default': None, 'description': "The default URL to redirect customers to when they click on the portal's link to return to your website. This can be [overriden](https://docs.stripe.com/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.", 'name': 'default_return_url'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about the features available in the portal.', 'name': 'features'},
           {'annotation': dict, 'default': None, 'description': 'The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](https://stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).', 'name': 'login_page'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The name of the configuration.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/configurations/update',
  'op_id': 'PostBillingPortalConfigurationsConfiguration',
  'path': '/v1/billing_portal/configurations/{configuration}',
  'qparams': [],
  'summary': 'Update a portal configuration',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The ID of an existing [configuration](https://docs.stripe.com/api/customer_portal/configuration) to use for this session, describing its functionality and features. If not specified, the session uses the default configuration.', 'name': 'configuration'},
           {'annotation': str, 'default': None, 'description': 'The ID of an existing customer.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of an existing account.', 'name': 'customer_account'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about a specific flow for the customer to go through. See the [docs](https://docs.stripe.com/customer-management/portal-deep-links) to learn more about using customer portal deep links and flows.', 'name': 'flow_data'},
           {'annotation': str, 'default': None, 'description': 'The IETF language tag of the locale customer portal is displayed in. If blank or auto, the customer’s `preferred_locales` or browser’s locale is used.', 'name': 'locale'},
           {'annotation': str,
            'default': None,
            'description': 'The `on_behalf_of` account to use for this session. When specified, only subscriptions and invoices with this `on_behalf_of` account appear in the portal. For more information, see the [docs](https://docs.stripe.com/connect/separate-charges-and-transfers#settlement-merchant). Use the [Accounts '
                           "API](https://docs.stripe.com/api/accounts/object#account_object-settings-branding) to modify the `on_behalf_of` account's branding settings, which the portal displays.",
            'name': 'on_behalf_of'},
           {'annotation': str, 'default': None, 'description': "The default URL to redirect customers to when they click on the portal's link to return to your website.", 'name': 'return_url'}],
  'doc_url': 'https://docs.stripe.com/api/sessions/create',
  'op_id': 'PostBillingPortalSessions',
  'path': '/v1/billing_portal/sessions',
  'qparams': [],
  'summary': 'Create a portal session',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/charges/list',
  'op_id': 'GetCharges',
  'path': '/v1/charges',
  'qparams': [{'annotation': 'str', 'description': 'Only return charges that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return charges for the customer specified by this customer ID.', 'name': 'customer'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.', 'name': 'payment_intent'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return charges for this transfer group, limited to 100.', 'name': 'transfer_group'}],
  'summary': 'List all charges',
  'verb': 'get'},
 {'data': [{'annotation': int,
            'default': None,
            'description': 'Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge '
                           'currency](https://docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).',
            'name': 'amount'},
           {'annotation': int, 'default': None, 'description': '', 'name': 'application_fee'},
           {'annotation': int,
            'default': None,
            'description': "A fee in cents (or local equivalent) that will be applied to the charge and transferred to the application owner's Stripe account. The request must be made with an OAuth key or the `Stripe-Account` header in order to take an application fee. For more information, see the application fees "
                           '[documentation](https://docs.stripe.com/connect/direct-charges#collect-fees).',
            'name': 'application_fee_amount'},
           {'annotation': bool,
            'default': None,
            'description': 'Whether to immediately capture the charge. Defaults to `true`. When `false`, the charge issues an authorization (or pre-authorization), and will need to be [captured](https://api.stripe.com#capture_charge) later. Uncaptured charges expire after a set number of days (7 by default). For more information, see the [authorizing '
                           'charges and settling later](https://docs.stripe.com/charges/placing-a-hold) documentation.',
            'name': 'capture'},
           {'annotation': object, 'default': None, 'description': 'A token, like the ones returned by [Stripe.js](https://stripe.com/docs/js).', 'name': 'card'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'The ID of an existing customer that will be charged in this request.', 'name': 'customer'},
           {'annotation': str,
            'default': None,
            'description': 'An arbitrary string which you can attach to a `Charge` object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the `description` of the charge(s) that they are describing.',
            'name': 'description'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'destination'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'The Stripe account ID for which these funds are intended. You can specify the business of record as the connected account using the `on_behalf_of` attribute on the charge. For details, see [Creating Separate Charges and Transfers](https://docs.stripe.com/connect/separate-charges-and-transfers#settlement-merchant).',
            'name': 'on_behalf_of'},
           {'annotation': dict, 'default': None, 'description': 'Options to configure Radar. See [Radar Session](https://docs.stripe.com/radar/radar-session) for more information.', 'name': 'radar_options'},
           {'annotation': str,
            'default': None,
            'description': "The email address to which this charge's [receipt](https://docs.stripe.com/dashboard/receipts) will be sent. The receipt will not be sent until the charge is paid, and no receipts will be sent for test mode charges. If this charge is for a [Customer](https://docs.stripe.com/api/customers/object), the email address specified here "
                           "will override the customer's email address. If `receipt_email` is specified for a charge in live mode, a receipt will be sent regardless of your [email settings](https://dashboard.stripe.com/account/emails).",
            'name': 'receipt_email'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for the charge. Helps prevent fraud on charges for physical goods.', 'name': 'shipping'},
           {'annotation': str,
            'default': None,
            'description': 'A payment source to be charged. This can be the ID of a [card](https://docs.stripe.com/api#cards) (i.e., credit or debit card), a [bank account](https://docs.stripe.com/api#bank_accounts), a [source](https://docs.stripe.com/api#sources), a [token](https://docs.stripe.com/api#tokens), or a [connected '
                           'account](https://docs.stripe.com/connect/account-debits#charging-a-connected-account). For certain sources---namely, [cards](https://docs.stripe.com/api#cards), [bank accounts](https://docs.stripe.com/api#bank_accounts), and attached [sources](https://docs.stripe.com/api#sources)---you must also pass the ID of the associated '
                           'customer.',
            'name': 'source'},
           {'annotation': str,
            'default': None,
            'description': "For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).\n'
                           '\n'
                           "For a card charge, this value is ignored unless you don't specify a `statement_descriptor_suffix`, in which case this value is used as the suffix.",
            'name': 'statement_descriptor'},
           {'annotation': str,
            'default': None,
            'description': "Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the "
                           "account's statement descriptor.",
            'name': 'statement_descriptor_suffix'},
           {'annotation': dict, 'default': None, 'description': 'An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](https://docs.stripe.com/connect/destination-charges) for details.', 'name': 'transfer_data'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies this transaction as part of a group. For details, see [Grouping transactions](https://docs.stripe.com/connect/separate-charges-and-transfers#transfer-options).', 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/charges/create',
  'op_id': 'PostCharges',
  'path': '/v1/charges',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetChargesSearch',
  'path': '/v1/charges/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for charges](https://docs.stripe.com/search#query-fields-for-charges).', 'name': 'query'}],
  'summary': 'Search charges',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/charges/delete', 'op_id': 'GetChargesCharge', 'path': '/v1/charges/{charge}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a charge', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.', 'name': 'customer'},
           {'annotation': str,
            'default': None,
            'description': 'An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the `description` of the charge(s) that they are describing.',
            'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a `user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our '
                           'fraud detection algorithms.',
            'name': 'fraud_details'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.', 'name': 'receipt_email'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for the charge. Helps prevent fraud on charges for physical goods.', 'name': 'shipping'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies this transaction as part of a group. `transfer_group` may only be provided if it has not been set. See the [Connect documentation](https://docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.', 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/charges/update',
  'op_id': 'PostChargesCharge',
  'path': '/v1/charges/{charge}',
  'qparams': [],
  'summary': 'Update a charge',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The amount to capture, which must be less than or equal to the original amount.', 'name': 'amount'},
           {'annotation': int, 'default': None, 'description': 'An application fee to add on to this charge.', 'name': 'application_fee'},
           {'annotation': int, 'default': None, 'description': 'An application fee amount to add on to this charge, which must be less than or equal to the original amount.', 'name': 'application_fee_amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The email address to send this charge's receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.", 'name': 'receipt_email'},
           {'annotation': str,
            'default': None,
            'description': "For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).\n'
                           '\n'
                           "For a card charge, this value is ignored unless you don't specify a `statement_descriptor_suffix`, in which case this value is used as the suffix.",
            'name': 'statement_descriptor'},
           {'annotation': str,
            'default': None,
            'description': "Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the "
                           "account's statement descriptor.",
            'name': 'statement_descriptor_suffix'},
           {'annotation': dict, 'default': None, 'description': 'An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](https://docs.stripe.com/connect/destination-charges) for details.', 'name': 'transfer_data'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies this transaction as part of a group. `transfer_group` may only be provided if it has not been set. See the [Connect documentation](https://docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.', 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/captures/update',
  'op_id': 'PostChargesChargeCapture',
  'path': '/v1/charges/{charge}/capture',
  'qparams': [],
  'summary': 'Capture a payment',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/disputes/retrieve', 'op_id': 'GetChargesChargeDispute', 'path': '/v1/charges/{charge}/dispute', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': '', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Evidence to upload, to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review. The combined character count of all fields is limited to 150,000.', 'name': 'evidence'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Whether to immediately submit evidence to the bank. If `false`, evidence is staged on the dispute. Staged evidence is visible in the API and Dashboard, and can be submitted to the bank by making another request with this attribute set to `true` (the default).', 'name': 'submit'}],
  'doc_url': 'https://docs.stripe.com/api/disputes/update',
  'op_id': 'PostChargesChargeDispute',
  'path': '/v1/charges/{charge}/dispute',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/closes/update', 'op_id': 'PostChargesChargeDisputeClose', 'path': '/v1/charges/{charge}/dispute/close', 'qparams': [], 'summary': '', 'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) representing how much of this charge to refund. Can refund only up to the remaining, unrefunded amount of the charge.', 'name': 'amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.', 'name': 'instructions_email'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the PaymentIntent to refund.', 'name': 'payment_intent'},
           {'annotation': str,
            'default': None,
            'description': 'String indicating the reason for the refund. If set, possible values are `duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](https://docs.stripe.com/radar/lists), and will also help '
                           'us improve our fraud detection algorithms.',
            'name': 'reason'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the '
                           'application that created the charge.',
            'name': 'refund_application_fee'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).<br><br>A transfer can be reversed only by the application that created the charge.',
            'name': 'reverse_transfer'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostChargesChargeRefund',
  'path': '/v1/charges/{charge}/refund',
  'qparams': [],
  'summary': 'Create a refund',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/refunds/delete',
  'op_id': 'GetChargesChargeRefunds',
  'path': '/v1/charges/{charge}/refunds',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all refunds',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': '', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'Customer whose customer balance to refund from.', 'name': 'customer'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.', 'name': 'instructions_email'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Origin of the refund', 'name': 'origin'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the PaymentIntent to refund.', 'name': 'payment_intent'},
           {'annotation': str,
            'default': None,
            'description': 'String indicating the reason for the refund. If set, possible values are `duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](https://docs.stripe.com/radar/lists), and will also help '
                           'us improve our fraud detection algorithms.',
            'name': 'reason'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the '
                           'application that created the charge.',
            'name': 'refund_application_fee'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).<br><br>A transfer can be reversed only by the application that created the charge.',
            'name': 'reverse_transfer'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostChargesChargeRefunds',
  'path': '/v1/charges/{charge}/refunds',
  'qparams': [],
  'summary': 'Create customer balance refund',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/refunds/delete', 'op_id': 'GetChargesChargeRefundsRefund', 'path': '/v1/charges/{charge}/refunds/{refund}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': '', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': object, 'default': None, 'description': '', 'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostChargesChargeRefundsRefund',
  'path': '/v1/charges/{charge}/refunds/{refund}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/sessions/list',
  'op_id': 'GetCheckoutSessions',
  'path': '/v1/checkout/sessions',
  'qparams': [{'annotation': 'str', 'description': 'Only return Checkout Sessions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return the Checkout Sessions for the Customer specified.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return the Checkout Sessions for the Account specified.', 'name': 'customer_account'},
              {'annotation': 'str', 'description': 'Only return the Checkout Sessions for the Customer details specified.', 'name': 'customer_details'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return the Checkout Session for the PaymentIntent specified.', 'name': 'payment_intent'},
              {'annotation': 'str', 'description': 'Only return the Checkout Sessions for the Payment Link specified.', 'name': 'payment_link'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return the Checkout Sessions matching the given status.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Only return the Checkout Session for the subscription specified.', 'name': 'subscription'}],
  'summary': 'List all Checkout Sessions',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Settings for price localization with [Adaptive Pricing](https://docs.stripe.com/payments/checkout/adaptive-pricing).', 'name': 'adaptive_pricing'},
           {'annotation': dict, 'default': None, 'description': "Configure actions after a Checkout Session has expired. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'after_expiration'},
           {'annotation': bool, 'default': None, 'description': 'Enables user redeemable promotion codes.', 'name': 'allow_promotion_codes'},
           {'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': "Specify whether Checkout should collect the customer's billing address. Defaults to `auto`.", 'name': 'billing_address_collection'},
           {'annotation': dict, 'default': None, 'description': 'The branding settings for the Checkout Session. This parameter is not allowed if ui_mode is `custom`.', 'name': 'branding_settings'},
           {'annotation': str, 'default': None, 'description': 'If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is `embedded` or `custom`.', 'name': 'cancel_url'},
           {'annotation': str, 'default': None, 'description': 'A unique string to reference the Checkout Session. This can be a\ncustomer ID, a cart ID, or similar, and can be used to reconcile the\nsession with your internal systems.', 'name': 'client_reference_id'},
           {'annotation': dict, 'default': None, 'description': 'Configure fields for the Checkout Session to gather active consent from customers.', 'name': 'consent_collection'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies). Required in `setup` mode when `payment_method_types` is not set.', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': "Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_fields'},
           {'annotation': dict, 'default': None, 'description': "Display additional text for your customers using custom text. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_text'},
           {'annotation': str,
            'default': None,
            'description': 'ID of an existing Customer, if one exists. In `payment` mode, the customer’s most recently saved card\n'
                           'payment method will be used to prefill the email, name, card details, and billing address\n'
                           'on the Checkout page. In `subscription` mode, the customer’s [default payment method](https://docs.stripe.com/api/customers/update#update_customer-invoice_settings-default_payment_method)\n'
                           "will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer's card details.\n"
                           '\n'
                           'If the Customer already has a valid [email](https://docs.stripe.com/api/customers/object#customer_object-email) set, the email will be prefilled and not editable in Checkout.\n'
                           'If the Customer does not have a valid `email`, Checkout will set the email entered during the session on the Customer.\n'
                           '\n'
                           'If blank for Checkout Sessions in `subscription` mode or with `customer_creation` set as `always` in `payment` mode, Checkout will create a new Customer object based on information provided during the payment flow.\n'
                           '\n'
                           'You can set [`payment_intent_data.setup_future_usage`](https://docs.stripe.com/api/checkout/sessions/create#create_checkout_session-payment_intent_data-setup_future_usage) to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.',
            'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'ID of an existing Account, if one exists. Has the same behavior as `customer`.', 'name': 'customer_account'},
           {'annotation': str,
            'default': None,
            'description': 'Configure whether a Checkout Session creates a [Customer](https://docs.stripe.com/api/customers) during Session confirmation.\n'
                           '\n'
                           'When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout\n'
                           'with [customer_details](https://docs.stripe.com/api/checkout/sessions/object#checkout_session_object-customer_details).\n'
                           '\n'
                           "Sessions that don't create Customers instead are grouped by [guest customers](https://docs.stripe.com/payments/checkout/guest-customers)\n"
                           'in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.\n'
                           '\n'
                           'Can only be set in `payment` and `setup` mode.',
            'name': 'customer_creation'},
           {'annotation': str,
            'default': None,
            'description': 'If provided, this value will be used when the Customer object is created.\nIf not provided, customers will be asked to enter their email address.\nUse this parameter to prefill customer data if you already have an email\non file. To access information about the customer once a session is\ncomplete, use the `customer` field.',
            'name': 'customer_email'},
           {'annotation': dict, 'default': None, 'description': 'Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when `customer` is provided.', 'name': 'customer_update'},
           {'annotation': list, 'default': None, 'description': 'The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.', 'name': 'discounts'},
           {'annotation': list,
            'default': None,
            'description': 'A list of the types of payment methods (e.g., `card`) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the [Stripe Dashboard](https://dashboard.stripe.com/settings/payment_methods).',
            'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.', 'name': 'expires_at'},
           {'annotation': dict, 'default': None, 'description': 'Generate a post-purchase Invoice for one-time payments.', 'name': 'invoice_creation'},
           {'annotation': list,
            'default': None,
            'description': 'A list of items the customer is purchasing. Use this parameter to pass one-time or recurring [Prices](https://docs.stripe.com/api/prices). The parameter is required for `payment` and `subscription` mode.\n'
                           '\n'
                           'For `payment` mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.\n'
                           '\n'
                           'For `subscription` mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.',
            'name': 'line_items'},
           {'annotation': str, 'default': None, 'description': "The IETF language tag of the locale Checkout is displayed in. If blank or `auto`, the browser's locale is used.", 'name': 'locale'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The mode of the Checkout Session. Pass `subscription` if the Checkout Session includes at least one recurring item.', 'name': 'mode'},
           {'annotation': dict,
            'default': None,
            'description': 'Controls name collection settings for the session.\n'
                           '\n'
                           "You can configure Checkout to collect your customers' business names, individual names, or both. Each name field can be either required or optional.\n"
                           '\n'
                           'If a [Customer](https://docs.stripe.com/api/customers) is created or provided, the names can be saved to the Customer object as well.\n'
                           '\n'
                           "You can't set this parameter if `ui_mode` is `custom`.",
            'name': 'name_collection'},
           {'annotation': list,
            'default': None,
            'description': 'A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring [Prices](https://docs.stripe.com/api/prices).\n'
                           '\n'
                           'There is a maximum of 10 optional items allowed on a Checkout Session, and the existing limits on the number of line items allowed on a Checkout Session apply to the combined number of line items and optional items.\n'
                           '\n'
                           'For `payment` mode, there is a maximum of 100 combined line items and optional items, however it is recommended to consolidate items if there are more than a few dozen.\n'
                           '\n'
                           'For `subscription` mode, there is a maximum of 20 line items and optional items with recurring Prices and 20 line items and optional items with one-time Prices.\n'
                           '\n'
                           "You can't set this parameter if `ui_mode` is `custom`.",
            'name': 'optional_items'},
           {'annotation': str, 'default': None, 'description': "Where the user is coming from. This informs the optimizations that are applied to the session. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'origin_context'},
           {'annotation': dict, 'default': None, 'description': 'A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in `payment` mode.', 'name': 'payment_intent_data'},
           {'annotation': str,
            'default': None,
            'description': 'Specify whether Checkout should collect a payment method. When set to `if_required`, Checkout will not collect a payment method when the total due for the session is 0.\n'
                           'This may occur if the Checkout Session includes a free trial or a discount.\n'
                           '\n'
                           'Can only be set in `subscription` mode. Defaults to `always`.\n'
                           '\n'
                           "If you'd like information on how to collect a payment method outside of Checkout, read the guide on configuring [subscriptions with a free trial](https://docs.stripe.com/payments/checkout/free-trials).",
            'name': 'payment_method_collection'},
           {'annotation': str, 'default': None, 'description': 'The ID of the payment method configuration to use with this Checkout session.', 'name': 'payment_method_configuration'},
           {'annotation': dict, 'default': None, 'description': 'This parameter allows you to set some attributes on the payment method created during a Checkout session.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment-method-specific configuration.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': 'A list of the types of payment methods (e.g., `card`) this Checkout Session can accept.\n'
                           '\n'
                           'You can omit this attribute to manage your payment methods from the [Stripe Dashboard](https://dashboard.stripe.com/settings/payment_methods).\n'
                           'See [Dynamic Payment Methods](https://docs.stripe.com/payments/payment-methods/integration-options#using-dynamic-payment-methods) for more details.\n'
                           '\n'
                           'Read more about the supported payment methods and their requirements in our [payment\n'
                           'method details guide](/docs/payments/checkout/payment-methods).\n'
                           '\n'
                           'If multiple payment methods are passed, Checkout will dynamically reorder them to\n'
                           "prioritize the most relevant payment methods based on the customer's location and\n"
                           'other characteristics.',
            'name': 'payment_method_types'},
           {'annotation': dict,
            'default': None,
            'description': 'This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object. Can only be set when creating `embedded` or `custom` sessions.\n\nFor specific permissions, please refer to their dedicated subsections, such as `permissions.update_shipping_details`.',
            'name': 'permissions'},
           {'annotation': dict,
            'default': None,
            'description': 'Controls phone number collection settings for the session.\n\nWe recommend that you review your privacy policy and check with your legal contacts\nbefore using this feature. Learn more about [collecting phone numbers with Checkout](https://docs.stripe.com/payments/checkout/phone-numbers).',
            'name': 'phone_number_collection'},
           {'annotation': str, 'default': None, 'description': 'This parameter applies to `ui_mode: embedded`. Learn more about the [redirect behavior](https://docs.stripe.com/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.', 'name': 'redirect_on_completion'},
           {'annotation': str, 'default': None, 'description': "The URL to redirect your customer back to after they authenticate or cancel their payment on the\npayment method's app or site. This parameter is required if `ui_mode` is `embedded` or `custom`\nand redirect-based payment methods are enabled on the session.", 'name': 'return_url'},
           {'annotation': dict, 'default': None, 'description': 'Controls saved payment method settings for the session. Only available in `payment` and `subscription` mode.', 'name': 'saved_payment_method_options'},
           {'annotation': dict, 'default': None, 'description': 'A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in `setup` mode.', 'name': 'setup_intent_data'},
           {'annotation': dict, 'default': None, 'description': 'When set, provides configuration for Checkout to collect a shipping address from a customer.', 'name': 'shipping_address_collection'},
           {'annotation': list, 'default': None, 'description': 'The shipping rate options to apply to this Session. Up to a maximum of 5.', 'name': 'shipping_options'},
           {'annotation': str,
            'default': None,
            'description': "Describes the type of transaction being performed by Checkout in order\nto customize relevant text on the page, such as the submit button.\n `submit_type` can only be specified on Checkout Sessions in\n`payment` or `subscription` mode. If blank or `auto`, `pay` is used.\nYou can't set this parameter if `ui_mode` is `custom`.",
            'name': 'submit_type'},
           {'annotation': dict, 'default': None, 'description': 'A subset of parameters to be passed to subscription creation for Checkout Sessions in `subscription` mode.', 'name': 'subscription_data'},
           {'annotation': str,
            'default': None,
            'description': 'The URL to which Stripe should send customers when payment or setup\n'
                           'is complete.\n'
                           "This parameter is not allowed if ui_mode is `embedded` or `custom`. If you'd like to use\n"
                           'information from the successful Checkout Session on your page, read the\n'
                           'guide on [customizing your success page](https://docs.stripe.com/payments/checkout/custom-success-page).',
            'name': 'success_url'},
           {'annotation': dict, 'default': None, 'description': 'Controls tax ID collection during checkout.', 'name': 'tax_id_collection'},
           {'annotation': str, 'default': None, 'description': 'The UI mode of the Session. Defaults to `hosted`.', 'name': 'ui_mode'},
           {'annotation': dict, 'default': None, 'description': 'Wallet-specific configuration.', 'name': 'wallet_options'}],
  'doc_url': 'https://docs.stripe.com/api/sessions/create',
  'op_id': 'PostCheckoutSessions',
  'path': '/v1/checkout/sessions',
  'qparams': [],
  'summary': 'Create a Checkout Session',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/sessions/delete', 'op_id': 'GetCheckoutSessionsSession', 'path': '/v1/checkout/sessions/{session}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Checkout Session', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Information about the customer collected within the Checkout Session. Can only be set when updating `embedded` or `custom` sessions.', 'name': 'collected_information'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list,
            'default': None,
            'description': 'A list of items the customer is purchasing.\n'
                           '\n'
                           'When updating line items, you must retransmit the entire array of line items.\n'
                           '\n'
                           'To retain an existing line item, specify its `id`.\n'
                           '\n'
                           'To update an existing line item, specify its `id` along with the new values of the fields to update.\n'
                           '\n'
                           'To add a new line item, specify one of `price` or `price_data` and `quantity`.\n'
                           '\n'
                           "To remove an existing line item, omit the line item's ID from the retransmitted array.\n"
                           '\n'
                           'To reorder a line item, specify it at the desired position in the retransmitted array.',
            'name': 'line_items'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The shipping rate options to apply to this Session. Up to a maximum of 5.', 'name': 'shipping_options'}],
  'doc_url': 'https://docs.stripe.com/api/sessions/update',
  'op_id': 'PostCheckoutSessionsSession',
  'path': '/v1/checkout/sessions/{session}',
  'qparams': [],
  'summary': 'Update a Checkout Session',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/expires/update',
  'op_id': 'PostCheckoutSessionsSessionExpire',
  'path': '/v1/checkout/sessions/{session}/expire',
  'qparams': [],
  'summary': 'Expire a Checkout Session',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/line_items/delete',
  'op_id': 'GetCheckoutSessionsSessionLineItems',
  'path': '/v1/checkout/sessions/{session}/line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a Checkout Session's line items",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/orders/list',
  'op_id': 'GetClimateOrders',
  'path': '/v1/climate/orders',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List orders',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Requested amount of carbon removal units. Either this or `metric_tons` must be specified.', 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.', 'name': 'beneficiary'},
           {'annotation': str,
            'default': None,
            'description': "Request currency for the order as a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a supported [settlement currency for your account](https://stripe.com/docs/currencies). If omitted, the account's default currency will be used.",
            'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Requested number of tons for the order. Either this or `amount` must be specified.', 'name': 'metric_tons'},
           {'annotation': str, 'default': None, 'description': 'Unique identifier of the Climate product.', 'name': 'product'}],
  'doc_url': 'https://docs.stripe.com/api/orders/create',
  'op_id': 'PostClimateOrders',
  'path': '/v1/climate/orders',
  'qparams': [],
  'summary': 'Create an order',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/orders/delete', 'op_id': 'GetClimateOrdersOrder', 'path': '/v1/climate/orders/{order}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an order', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.', 'name': 'beneficiary'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/orders/update',
  'op_id': 'PostClimateOrdersOrder',
  'path': '/v1/climate/orders/{order}',
  'qparams': [],
  'summary': 'Update an order',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/cancels/update', 'op_id': 'PostClimateOrdersOrderCancel', 'path': '/v1/climate/orders/{order}/cancel', 'qparams': [], 'summary': 'Cancel an order', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/products/list',
  'op_id': 'GetClimateProducts',
  'path': '/v1/climate/products',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List products',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/products/delete', 'op_id': 'GetClimateProductsProduct', 'path': '/v1/climate/products/{product}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a product', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/suppliers/list',
  'op_id': 'GetClimateSuppliers',
  'path': '/v1/climate/suppliers',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List suppliers',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/suppliers/delete', 'op_id': 'GetClimateSuppliersSupplier', 'path': '/v1/climate/suppliers/{supplier}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a supplier', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/confirmation_tokens/delete',
  'op_id': 'GetConfirmationTokensConfirmationToken',
  'path': '/v1/confirmation_tokens/{confirmation_token}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a ConfirmationToken',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/country_specs/list',
  'op_id': 'GetCountrySpecs',
  'path': '/v1/country_specs',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Country Specs',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/country_specs/delete', 'op_id': 'GetCountrySpecsCountry', 'path': '/v1/country_specs/{country}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Country Spec', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/coupons/list',
  'op_id': 'GetCoupons',
  'path': '/v1/coupons',
  'qparams': [{'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all coupons',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer representing the amount to subtract from an invoice total (required if `percent_off` is not passed).', 'name': 'amount_off'},
           {'annotation': dict, 'default': None, 'description': 'A hash containing directions for what this Coupon will apply discounts to.', 'name': 'applies_to'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO code for the currency](https://stripe.com/docs/currencies) of the `amount_off` parameter (required if `amount_off` is passed).', 'name': 'currency'},
           {'annotation': dict, 'default': None, 'description': 'Coupons defined in each available currency option (only supported if `amount_off` is passed). Each key must be a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html) and a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency_options'},
           {'annotation': str, 'default': None, 'description': 'Specifies how long the discount will be in effect if used on a subscription. Defaults to `once`.', 'name': 'duration'},
           {'annotation': int, 'default': None, 'description': 'Required only if `duration` is `repeating`, in which case it must be a positive integer that specifies the number of months the discount will be in effect.', 'name': 'duration_in_months'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "Unique string of your choice that will be used to identify this coupon when applying it to a customer. If you don't want to specify a particular code, you can leave the ID blank and we'll generate a random code for you.", 'name': 'id'},
           {'annotation': int, 'default': None, 'description': "A positive integer specifying the number of times the coupon can be redeemed before it's no longer valid. For example, you might have a 50% off coupon that the first 20 readers of your blog can use.", 'name': 'max_redemptions'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the `id` is shown if `name` is not set.', 'name': 'name'},
           {'annotation': int, 'default': None, 'description': 'A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if `amount_off` is not passed).', 'name': 'percent_off'},
           {'annotation': int, 'default': None, 'description': 'Unix timestamp specifying the last time at which the coupon can be redeemed (cannot be set to more than 5 years in the future). After the redeem_by date, the coupon can no longer be applied to new customers.', 'name': 'redeem_by'}],
  'doc_url': 'https://docs.stripe.com/api/coupons/create',
  'op_id': 'PostCoupons',
  'path': '/v1/coupons',
  'qparams': [],
  'summary': 'Create a coupon',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/coupons/delete', 'op_id': 'DeleteCouponsCoupon', 'path': '/v1/coupons/{coupon}', 'qparams': [], 'summary': 'Delete a coupon', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/coupons/delete', 'op_id': 'GetCouponsCoupon', 'path': '/v1/coupons/{coupon}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a coupon', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Coupons defined in each available currency option (only supported if the coupon is amount-based). Each key must be a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html) and a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency_options'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the `id` is shown if `name` is not set.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/coupons/update',
  'op_id': 'PostCouponsCoupon',
  'path': '/v1/coupons/{coupon}',
  'qparams': [],
  'summary': 'Update a coupon',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_notes/list',
  'op_id': 'GetCreditNotes',
  'path': '/v1/credit_notes',
  'qparams': [{'annotation': 'str', 'description': 'Only return credit notes that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return credit notes for the customer specified by this customer ID.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return credit notes for the account representing the customer specified by this account ID.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return credit notes for the invoice specified by this invoice ID.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all credit notes',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'amount'},
           {'annotation': int, 'default': None, 'description': "The integer amount in cents (or local equivalent) representing the amount to credit the customer's balance, which will be automatically applied to their next invoice.", 'name': 'credit_amount'},
           {'annotation': int, 'default': None, 'description': "The date when this credit note is in effect. Same as `created` unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the credit note PDF.", 'name': 'effective_at'},
           {'annotation': str, 'default': None, 'description': 'Type of email to send to the customer, one of `credit_note` or `none` and the default is `credit_note`.', 'name': 'email_type'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'ID of the invoice.', 'name': 'invoice'},
           {'annotation': list, 'default': None, 'description': 'Line items that make up the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'lines'},
           {'annotation': str, 'default': None, 'description': "The credit note's memo appears on the credit note PDF.", 'name': 'memo'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': int, 'default': None, 'description': 'The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.', 'name': 'out_of_band_amount'},
           {'annotation': str, 'default': None, 'description': 'Reason for issuing this credit note, one of `duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`', 'name': 'reason'},
           {'annotation': int, 'default': None, 'description': 'The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.', 'name': 'refund_amount'},
           {'annotation': list, 'default': None, 'description': 'Refunds to link to this credit note.', 'name': 'refunds'},
           {'annotation': dict, 'default': None, 'description': 'When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'shipping_cost'}],
  'doc_url': 'https://docs.stripe.com/api/credit_notes/create',
  'op_id': 'PostCreditNotes',
  'path': '/v1/credit_notes',
  'qparams': [],
  'summary': 'Create a credit note',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/previews/retrieve',
  'op_id': 'GetCreditNotesPreview',
  'path': '/v1/credit_notes/preview',
  'qparams': [{'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'amount'},
              {'annotation': 'str', 'description': "The integer amount in cents (or local equivalent) representing the amount to credit the customer's balance, which will be automatically applied to their next invoice.", 'name': 'credit_amount'},
              {'annotation': 'str', 'description': "The date when this credit note is in effect. Same as `created` unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the credit note PDF.", 'name': 'effective_at'},
              {'annotation': 'str', 'description': 'Type of email to send to the customer, one of `credit_note` or `none` and the default is `credit_note`.', 'name': 'email_type'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'ID of the invoice.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'Line items that make up the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'lines'},
              {'annotation': 'str', 'description': "The credit note's memo appears on the credit note PDF.", 'name': 'memo'},
              {'annotation': 'str',
               'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
               'name': 'metadata'},
              {'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.', 'name': 'out_of_band_amount'},
              {'annotation': 'str', 'description': 'Reason for issuing this credit note, one of `duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`', 'name': 'reason'},
              {'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.', 'name': 'refund_amount'},
              {'annotation': 'str', 'description': 'Refunds to link to this credit note.', 'name': 'refunds'},
              {'annotation': 'str', 'description': 'When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'shipping_cost'}],
  'summary': 'Preview a credit note',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/lines/list',
  'op_id': 'GetCreditNotesPreviewLines',
  'path': '/v1/credit_notes/preview/lines',
  'qparams': [{'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the total amount of the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'amount'},
              {'annotation': 'str', 'description': "The integer amount in cents (or local equivalent) representing the amount to credit the customer's balance, which will be automatically applied to their next invoice.", 'name': 'credit_amount'},
              {'annotation': 'str', 'description': "The date when this credit note is in effect. Same as `created` unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the credit note PDF.", 'name': 'effective_at'},
              {'annotation': 'str', 'description': 'Type of email to send to the customer, one of `credit_note` or `none` and the default is `credit_note`.', 'name': 'email_type'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'ID of the invoice.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Line items that make up the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'lines'},
              {'annotation': 'str', 'description': "The credit note's memo appears on the credit note PDF.", 'name': 'memo'},
              {'annotation': 'str',
               'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
               'name': 'metadata'},
              {'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.', 'name': 'out_of_band_amount'},
              {'annotation': 'str', 'description': 'Reason for issuing this credit note, one of `duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`', 'name': 'reason'},
              {'annotation': 'str', 'description': 'The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.', 'name': 'refund_amount'},
              {'annotation': 'str', 'description': 'Refunds to link to this credit note.', 'name': 'refunds'},
              {'annotation': 'str', 'description': 'When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note. One of `amount`, `lines`, or `shipping_cost` must be provided.', 'name': 'shipping_cost'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a credit note preview's line items",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/lines/delete',
  'op_id': 'GetCreditNotesCreditNoteLines',
  'path': '/v1/credit_notes/{credit_note}/lines',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a credit note's line items",
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/credit_notes/delete', 'op_id': 'GetCreditNotesId', 'path': '/v1/credit_notes/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a credit note', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Credit note memo.', 'name': 'memo'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/credit_notes/update',
  'op_id': 'PostCreditNotesId',
  'path': '/v1/credit_notes/{id}',
  'qparams': [],
  'summary': 'Update a credit note',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/voids/update', 'op_id': 'PostCreditNotesIdVoid', 'path': '/v1/credit_notes/{id}/void', 'qparams': [], 'summary': 'Void a credit note', 'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Configuration for each component. At least 1 component must be enabled.', 'name': 'components'},
           {'annotation': str, 'default': None, 'description': 'The ID of an existing customer for which to create the Customer Session.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of an existing Account for which to create the Customer Session.', 'name': 'customer_account'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/customer_sessions/create',
  'op_id': 'PostCustomerSessions',
  'path': '/v1/customer_sessions',
  'qparams': [],
  'summary': 'Create a Customer Session',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/customers/list',
  'op_id': 'GetCustomers',
  'path': '/v1/customers',
  'qparams': [{'annotation': 'str', 'description': 'Only return customers that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': "A case-sensitive filter on the list based on the customer's `email` field. The value must be a string.", 'name': 'email'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Provides a list of customers that are associated with the specified test clock. The response will not include customers with test clocks if this parameter is not set.', 'name': 'test_clock'}],
  'summary': 'List all customers',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': "The customer's address. Learn about [country-specific requirements for calculating tax](https://docs.stripe.com/invoicing/taxes?dashboard-or-api=dashboard#set-up-customer).", 'name': 'address'},
           {'annotation': int,
            'default': None,
            'description': "An integer amount in cents (or local equivalent) that represents the customer's current balance, which affect the customer's future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.",
            'name': 'balance'},
           {'annotation': object, 'default': None, 'description': "The customer's business name. This may be up to *150 characters*.", 'name': 'business_name'},
           {'annotation': dict, 'default': None, 'description': 'Balance information and default balance settings for this customer.', 'name': 'cash_balance'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': "Customer's email address. It's displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': "The customer's full name. This may be up to *150 characters*.", 'name': 'individual_name'},
           {'annotation': str, 'default': None, 'description': 'The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.', 'name': 'invoice_prefix'},
           {'annotation': dict, 'default': None, 'description': 'Default invoice settings for this customer.', 'name': 'invoice_settings'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The customer's full name or business name.", 'name': 'name'},
           {'annotation': int, 'default': None, 'description': "The sequence to be used on the customer's next invoice. Defaults to 1.", 'name': 'next_invoice_sequence'},
           {'annotation': str, 'default': None, 'description': '', 'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': "The customer's phone number.", 'name': 'phone'},
           {'annotation': list, 'default': None, 'description': "Customer's preferred languages, ordered by preference.", 'name': 'preferred_locales'},
           {'annotation': object, 'default': None, 'description': "The customer's shipping information. Appears on invoices emailed to this customer.", 'name': 'shipping'},
           {'annotation': str, 'default': None, 'description': '', 'name': 'source'},
           {'annotation': dict, 'default': None, 'description': 'Tax details about the customer.', 'name': 'tax'},
           {'annotation': str, 'default': None, 'description': "The customer's tax exemption. One of `none`, `exempt`, or `reverse`.", 'name': 'tax_exempt'},
           {'annotation': list, 'default': None, 'description': "The customer's tax IDs.", 'name': 'tax_id_data'},
           {'annotation': str, 'default': None, 'description': 'ID of the test clock to attach to the customer.', 'name': 'test_clock'}],
  'doc_url': 'https://docs.stripe.com/api/customers/create',
  'op_id': 'PostCustomers',
  'path': '/v1/customers',
  'qparams': [],
  'summary': 'Create a customer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetCustomersSearch',
  'path': '/v1/customers/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for customers](https://docs.stripe.com/search#query-fields-for-customers).', 'name': 'query'}],
  'summary': 'Search customers',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/customers/delete', 'op_id': 'DeleteCustomersCustomer', 'path': '/v1/customers/{customer}', 'qparams': [], 'summary': 'Delete a customer', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/customers/delete', 'op_id': 'GetCustomersCustomer', 'path': '/v1/customers/{customer}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a customer', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': "The customer's address. Learn about [country-specific requirements for calculating tax](https://docs.stripe.com/invoicing/taxes?dashboard-or-api=dashboard#set-up-customer).", 'name': 'address'},
           {'annotation': int,
            'default': None,
            'description': "An integer amount in cents (or local equivalent) that represents the customer's current balance, which affect the customer's future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.",
            'name': 'balance'},
           {'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': object, 'default': None, 'description': "The customer's business name. This may be up to *150 characters*.", 'name': 'business_name'},
           {'annotation': object, 'default': None, 'description': 'A token, like the ones returned by [Stripe.js](https://stripe.com/docs/js).', 'name': 'card'},
           {'annotation': dict, 'default': None, 'description': 'Balance information and default balance settings for this customer.', 'name': 'cash_balance'},
           {'annotation': str, 'default': None, 'description': "ID of Alipay account to make the customer's new default for invoice payments.", 'name': 'default_alipay_account'},
           {'annotation': str, 'default': None, 'description': "ID of bank account to make the customer's new default for invoice payments.", 'name': 'default_bank_account'},
           {'annotation': str, 'default': None, 'description': "ID of card to make the customer's new default for invoice payments.", 'name': 'default_card'},
           {'annotation': str,
            'default': None,
            'description': 'If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.\n'
                           '\n'
                           "Provide the ID of a payment source already attached to this customer to make it this customer's default payment source.\n"
                           '\n'
                           'If you want to add a new payment source and make it the default, see the [source](https://docs.stripe.com/api/customers/update#update_customer-source) property.',
            'name': 'default_source'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': "Customer's email address. It's displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': "The customer's full name. This may be up to *150 characters*.", 'name': 'individual_name'},
           {'annotation': str, 'default': None, 'description': 'The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.', 'name': 'invoice_prefix'},
           {'annotation': dict, 'default': None, 'description': 'Default invoice settings for this customer.', 'name': 'invoice_settings'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The customer's full name or business name.", 'name': 'name'},
           {'annotation': int, 'default': None, 'description': "The sequence to be used on the customer's next invoice. Defaults to 1.", 'name': 'next_invoice_sequence'},
           {'annotation': str, 'default': None, 'description': "The customer's phone number.", 'name': 'phone'},
           {'annotation': list, 'default': None, 'description': "Customer's preferred languages, ordered by preference.", 'name': 'preferred_locales'},
           {'annotation': object, 'default': None, 'description': "The customer's shipping information. Appears on invoices emailed to this customer.", 'name': 'shipping'},
           {'annotation': str, 'default': None, 'description': '', 'name': 'source'},
           {'annotation': dict, 'default': None, 'description': 'Tax details about the customer.', 'name': 'tax'},
           {'annotation': str, 'default': None, 'description': "The customer's tax exemption. One of `none`, `exempt`, or `reverse`.", 'name': 'tax_exempt'}],
  'doc_url': 'https://docs.stripe.com/api/customers/update',
  'op_id': 'PostCustomersCustomer',
  'path': '/v1/customers/{customer}',
  'qparams': [],
  'summary': 'Update a customer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/balance_transactions/delete',
  'op_id': 'GetCustomersCustomerBalanceTransactions',
  'path': '/v1/customers/{customer}/balance_transactions',
  'qparams': [{'annotation': 'str', 'description': 'Only return customer balance transactions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return transactions that are related to the specified invoice.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List customer balance transactions',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': "The integer amount in **cents (or local equivalent)** to apply to the customer's credit balance.", 'name': 'amount'},
           {'annotation': str,
            'default': None,
            'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies). Specifies the [`invoice_credit_balance`](https://docs.stripe.com/api/customers/object#customer_object-invoice_credit_balance) that this transaction will apply to. '
                           "If the customer's `currency` is not set, it will be updated to this value.",
            'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/balance_transactions/update',
  'op_id': 'PostCustomersCustomerBalanceTransactions',
  'path': '/v1/customers/{customer}/balance_transactions',
  'qparams': [],
  'summary': 'Create a customer balance transaction',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/balance_transactions/delete',
  'op_id': 'GetCustomersCustomerBalanceTransactionsTransaction',
  'path': '/v1/customers/{customer}/balance_transactions/{transaction}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a customer balance transaction',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/balance_transactions/update',
  'op_id': 'PostCustomersCustomerBalanceTransactionsTransaction',
  'path': '/v1/customers/{customer}/balance_transactions/{transaction}',
  'qparams': [],
  'summary': 'Update a customer credit balance transaction',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/delete',
  'op_id': 'GetCustomersCustomerBankAccounts',
  'path': '/v1/customers/{customer}/bank_accounts',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all bank accounts',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'A token returned by [Stripe.js](https://stripe.com/docs/js) representing the user’s Alipay account details.', 'name': 'alipay_account'},
           {'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': object, 'default': None, 'description': 'A token, like the ones returned by [Stripe.js](https://stripe.com/docs/js).', 'name': 'card'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Please refer to full [documentation](https://api.stripe.com) instead.', 'name': 'source'}],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/update',
  'op_id': 'PostCustomersCustomerBankAccounts',
  'path': '/v1/customers/{customer}/bank_accounts',
  'qparams': [],
  'summary': 'Create a card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/delete',
  'op_id': 'DeleteCustomersCustomerBankAccountsId',
  'path': '/v1/customers/{customer}/bank_accounts/{id}',
  'qparams': [],
  'summary': 'Delete a customer source',
  'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/delete',
  'op_id': 'GetCustomersCustomerBankAccountsId',
  'path': '/v1/customers/{customer}/bank_accounts/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a bank account',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': '', 'name': 'owner'}],
  'doc_url': 'https://docs.stripe.com/api/bank_accounts/update',
  'op_id': 'PostCustomersCustomerBankAccountsId',
  'path': '/v1/customers/{customer}/bank_accounts/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Two positive integers, in *cents*, equal to the values of the microdeposits sent to the bank account.', 'name': 'amounts'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/verifys/update',
  'op_id': 'PostCustomersCustomerBankAccountsIdVerify',
  'path': '/v1/customers/{customer}/bank_accounts/{id}/verify',
  'qparams': [],
  'summary': 'Verify a bank account',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/cards/delete',
  'op_id': 'GetCustomersCustomerCards',
  'path': '/v1/customers/{customer}/cards',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all cards',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'A token returned by [Stripe.js](https://stripe.com/docs/js) representing the user’s Alipay account details.', 'name': 'alipay_account'},
           {'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': object, 'default': None, 'description': 'A token, like the ones returned by [Stripe.js](https://stripe.com/docs/js).', 'name': 'card'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Please refer to full [documentation](https://api.stripe.com) instead.', 'name': 'source'}],
  'doc_url': 'https://docs.stripe.com/api/cards/update',
  'op_id': 'PostCustomersCustomerCards',
  'path': '/v1/customers/{customer}/cards',
  'qparams': [],
  'summary': 'Create a card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cards/delete',
  'op_id': 'DeleteCustomersCustomerCardsId',
  'path': '/v1/customers/{customer}/cards/{id}',
  'qparams': [],
  'summary': 'Delete a customer source',
  'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/cards/delete', 'op_id': 'GetCustomersCustomerCardsId', 'path': '/v1/customers/{customer}/cards/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a card', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': '', 'name': 'owner'}],
  'doc_url': 'https://docs.stripe.com/api/cards/update',
  'op_id': 'PostCustomersCustomerCardsId',
  'path': '/v1/customers/{customer}/cards/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/cash_balances/retrieve', 'op_id': 'GetCustomersCustomerCashBalance', 'path': '/v1/customers/{customer}/cash_balance', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a cash balance', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'A hash of settings for this cash balance.', 'name': 'settings'}],
  'doc_url': 'https://docs.stripe.com/api/cash_balances/update',
  'op_id': 'PostCustomersCustomerCashBalance',
  'path': '/v1/customers/{customer}/cash_balance',
  'qparams': [],
  'summary': "Update a cash balance's settings",
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/cash_balance_transactions/delete',
  'op_id': 'GetCustomersCustomerCashBalanceTransactions',
  'path': '/v1/customers/{customer}/cash_balance_transactions',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List cash balance transactions',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/cash_balance_transactions/delete',
  'op_id': 'GetCustomersCustomerCashBalanceTransactionsTransaction',
  'path': '/v1/customers/{customer}/cash_balance_transactions/{transaction}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a cash balance transaction',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/discounts/delete', 'op_id': 'DeleteCustomersCustomerDiscount', 'path': '/v1/customers/{customer}/discount', 'qparams': [], 'summary': 'Delete a customer discount', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/discounts/retrieve', 'op_id': 'GetCustomersCustomerDiscount', 'path': '/v1/customers/{customer}/discount', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': '', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Additional parameters for `bank_transfer` funding types', 'name': 'bank_transfer'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The `funding_type` to get the instructions for.', 'name': 'funding_type'}],
  'doc_url': 'https://docs.stripe.com/api/funding_instructions/update',
  'op_id': 'PostCustomersCustomerFundingInstructions',
  'path': '/v1/customers/{customer}/funding_instructions',
  'qparams': [],
  'summary': 'Create or retrieve funding instructions for a customer cash balance',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_methods/delete',
  'op_id': 'GetCustomersCustomerPaymentMethods',
  'path': '/v1/customers/{customer}/payment_methods',
  'qparams': [{'annotation': 'str', 'description': 'This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.', 'name': 'allow_redisplay'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'An optional filter on the list, based on the object `type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.', 'name': 'type'}],
  'summary': "List a Customer's PaymentMethods",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_methods/delete',
  'op_id': 'GetCustomersCustomerPaymentMethodsPaymentMethod',
  'path': '/v1/customers/{customer}/payment_methods/{payment_method}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': "Retrieve a Customer's PaymentMethod",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/sources/delete',
  'op_id': 'GetCustomersCustomerSources',
  'path': '/v1/customers/{customer}/sources',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Filter sources according to a particular object type.', 'name': 'object'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': '',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'A token returned by [Stripe.js](https://stripe.com/docs/js) representing the user’s Alipay account details.', 'name': 'alipay_account'},
           {'annotation': object, 'default': None, 'description': "Either a token, like the ones returned by [Stripe.js](https://stripe.com/docs/js), or a dictionary containing a user's bank account details.", 'name': 'bank_account'},
           {'annotation': object, 'default': None, 'description': 'A token, like the ones returned by [Stripe.js](https://stripe.com/docs/js).', 'name': 'card'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Please refer to full [documentation](https://api.stripe.com) instead.', 'name': 'source'}],
  'doc_url': 'https://docs.stripe.com/api/sources/update',
  'op_id': 'PostCustomersCustomerSources',
  'path': '/v1/customers/{customer}/sources',
  'qparams': [],
  'summary': 'Create a card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/sources/delete',
  'op_id': 'DeleteCustomersCustomerSourcesId',
  'path': '/v1/customers/{customer}/sources/{id}',
  'qparams': [],
  'summary': 'Delete a customer source',
  'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/sources/delete', 'op_id': 'GetCustomersCustomerSourcesId', 'path': '/v1/customers/{customer}/sources/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': '', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': '', 'name': 'owner'}],
  'doc_url': 'https://docs.stripe.com/api/sources/update',
  'op_id': 'PostCustomersCustomerSourcesId',
  'path': '/v1/customers/{customer}/sources/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Two positive integers, in *cents*, equal to the values of the microdeposits sent to the bank account.', 'name': 'amounts'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/verifys/update',
  'op_id': 'PostCustomersCustomerSourcesIdVerify',
  'path': '/v1/customers/{customer}/sources/{id}/verify',
  'qparams': [],
  'summary': 'Verify a bank account',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/delete',
  'op_id': 'GetCustomersCustomerSubscriptions',
  'path': '/v1/customers/{customer}/subscriptions',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List active subscriptions',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.', 'name': 'add_invoice_items'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For "
                           'more information, see the application fees [documentation](https://stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).',
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Automatic tax settings for this subscription.', 'name': 'automatic_tax'},
           {'annotation': int, 'default': None, 'description': "A past timestamp to backdate the subscription's start date to. If set, the first invoice will contain line items for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.", 'name': 'backdate_start_date'},
           {'annotation': int,
            'default': None,
            'description': "A future timestamp in UTC format to anchor the subscription's [billing cycle](https://docs.stripe.com/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for `week` intervals, the day of month for `month` and `year` intervals, and the month of year for "
                           '`year` intervals.',
            'name': 'billing_cycle_anchor'},
           {'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object,
            'default': None,
            'description': 'A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using `proration_behavior`. If set during a future period, this will always cause a proration for that period.',
            'name': 'cancel_at'},
           {'annotation': bool, 'default': None, 'description': 'Indicate whether this subscription should cancel at the end of the current period (`current_period_end`). Defaults to `false`.', 'name': 'cancel_at_period_end'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as '
                           '`active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': int, 'default': None, 'description': 'Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where `collection_method` is set to `send_invoice`.', 'name': 'days_until_due'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over `default_source`. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_payment_method'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If `default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_source'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any subscription item that does not have `tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.', 'name': 'default_tax_rates'},
           {'annotation': object, 'default': None, 'description': "The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription's customer.", 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 20 subscription items, each with an attached price.', 'name': 'items'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `false` (on-session).', 'name': 'off_session'},
           {'annotation': str,
            'default': None,
            'description': 'Only applies to subscriptions with `collection_method=charge_automatically`.\n'
                           '\n'
                           "Use `allow_incomplete` to create Subscriptions with `status=incomplete` if the first invoice can't be paid. Creating Subscriptions with this status allows you to manage scenarios where additional customer actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete "
                           'payment. See the [SCA Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           'Use `default_incomplete` to create Subscriptions with `status=incomplete` when the first invoice requires payment, otherwise start as active. Subscriptions transition to `status=active` when successfully confirming the PaymentIntent on the first invoice. This allows simpler management of scenarios where additional customer '
                           'actions are needed to pay a subscription’s invoice, such as failed payments, [SCA regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method. If the PaymentIntent is not confirmed within 23 hours Subscriptions transition to '
                           '`status=incomplete_expired`, which is a terminal state.\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's first invoice can't be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further customer action is needed, this parameter doesn't create a Subscription and returns an error instead. This "
                           'was the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/upgrades#2019-03-14) to learn more.\n'
                           '\n'
                           '`pending_if_incomplete` is only used with updates and cannot be passed when creating a Subscription.\n'
                           '\n'
                           'Subscriptions with `collection_method=send_invoice` are automatically activated regardless of the first Invoice status.',
            'name': 'payment_behavior'},
           {'annotation': dict, 'default': None, 'description': 'Payment settings to pass to invoices created by the subscription.', 'name': 'payment_settings'},
           {'annotation': object, 'default': None, 'description': 'Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](https://docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.', 'name': 'pending_invoice_item_interval'},
           {'annotation': str, 'default': None, 'description': 'Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) resulting from the `billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.', 'name': 'proration_behavior'},
           {'annotation': dict, 'default': None, 'description': "If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.", 'name': 'transfer_data'},
           {'annotation': object,
            'default': None,
            'description': "Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value `now` can be provided to end the customer's trial immediately. Can be at most two years "
                           'from `billing_cycle_anchor`. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) to learn more.',
            'name': 'trial_end'},
           {'annotation': bool,
            'default': None,
            'description': "Indicates if a plan's `trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) "
                           'to learn more.',
            'name': 'trial_from_plan'},
           {'annotation': int,
            'default': None,
            'description': 'Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) to learn more.',
            'name': 'trial_period_days'},
           {'annotation': dict, 'default': None, 'description': 'Settings related to subscription trials.', 'name': 'trial_settings'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/update',
  'op_id': 'PostCustomersCustomerSubscriptions',
  'path': '/v1/customers/{customer}/subscriptions',
  'qparams': [],
  'summary': 'Create a subscription',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool, 'default': None, 'description': 'Can be set to `true` if `at_period_end` is not set to `true`. Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items.', 'name': 'invoice_now'},
           {'annotation': bool, 'default': None, 'description': 'Can be set to `true` if `at_period_end` is not set to `true`. Will generate a proration invoice item that credits remaining unused time until the subscription period end.', 'name': 'prorate'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/delete',
  'op_id': 'DeleteCustomersCustomerSubscriptionsSubscriptionExposedId',
  'path': '/v1/customers/{customer}/subscriptions/{subscription_exposed_id}',
  'qparams': [],
  'summary': 'Cancel a subscription',
  'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/delete',
  'op_id': 'GetCustomersCustomerSubscriptionsSubscriptionExposedId',
  'path': '/v1/customers/{customer}/subscriptions/{subscription_exposed_id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a subscription',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.', 'name': 'add_invoice_items'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For "
                           'more information, see the application fees [documentation](https://stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).',
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': "Either `now` or `unchanged`. Setting the value to `now` resets the subscription's billing cycle anchor to the current time. For more information, see the billing cycle [documentation](https://docs.stripe.com/billing/subscriptions/billing-cycle).", 'name': 'billing_cycle_anchor'},
           {'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object,
            'default': None,
            'description': 'A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using `proration_behavior`. If set during a future period, this will always cause a proration for that period.',
            'name': 'cancel_at'},
           {'annotation': bool, 'default': None, 'description': 'Indicate whether this subscription should cancel at the end of the current period (`current_period_end`). Defaults to `false`.', 'name': 'cancel_at_period_end'},
           {'annotation': dict, 'default': None, 'description': 'Details about why this subscription was cancelled', 'name': 'cancellation_details'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as '
                           '`active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': int, 'default': None, 'description': 'Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where `collection_method` is set to `send_invoice`.', 'name': 'days_until_due'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over `default_source`. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_payment_method'},
           {'annotation': object,
            'default': None,
            'description': "ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If `default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_source'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any subscription item that does not have `tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription. Pass an empty string to remove previously-defined tax rates.', 'name': 'default_tax_rates'},
           {'annotation': object, 'default': None, 'description': "The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription's customer.", 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 20 subscription items, each with an attached price.', 'name': 'items'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `false` (on-session).', 'name': 'off_session'},
           {'annotation': object, 'default': None, 'description': 'If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to `paused`. Learn more about [pausing collection](https://docs.stripe.com/billing/subscriptions/pause-payment).', 'name': 'pause_collection'},
           {'annotation': str,
            'default': None,
            'description': "Use `allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA "
                           'Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           "Use `default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice's payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA "
                           'regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.\n'
                           '\n'
                           'Use `pending_if_incomplete` to update the subscription using [pending updates](https://docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](https://docs.stripe.com/billing/pending-updates-reference#supported-attributes).\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was "
                           'the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/changelog/2019-03-14) to learn more.',
            'name': 'payment_behavior'},
           {'annotation': dict, 'default': None, 'description': 'Payment settings to pass to invoices created by the subscription.', 'name': 'payment_settings'},
           {'annotation': object, 'default': None, 'description': 'Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](https://docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.', 'name': 'pending_invoice_item_interval'},
           {'annotation': str,
            'default': None,
            'description': "Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting `billing_cycle_anchor=now`, or starting a trial), or if an item's `quantity` changes. The default value is `create_prorations`.",
            'name': 'proration_behavior'},
           {'annotation': int,
            'default': None,
            'description': 'If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](https://stripe.com/docs/api/invoices/create_preview) endpoint. `proration_date` can also be used to implement custom proration logic, '
                           'such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.',
            'name': 'proration_date'},
           {'annotation': object, 'default': None, 'description': "If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.", 'name': 'transfer_data'},
           {'annotation': object,
            'default': None,
            'description': 'Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value `now` can '
                           "be provided to end the customer's trial immediately. Can be at most two years from `billing_cycle_anchor`.",
            'name': 'trial_end'},
           {'annotation': bool,
            'default': None,
            'description': "Indicates if a plan's `trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) "
                           'to learn more.',
            'name': 'trial_from_plan'},
           {'annotation': dict, 'default': None, 'description': 'Settings related to subscription trials.', 'name': 'trial_settings'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/update',
  'op_id': 'PostCustomersCustomerSubscriptionsSubscriptionExposedId',
  'path': '/v1/customers/{customer}/subscriptions/{subscription_exposed_id}',
  'qparams': [],
  'summary': 'Update a subscription on a customer',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/discounts/delete', 'op_id': 'DeleteCustomersCustomerSubscriptionsSubscriptionExposedIdDiscount', 'path': '/v1/customers/{customer}/subscriptions/{subscription_exposed_id}/discount', 'qparams': [], 'summary': 'Delete a customer discount', 'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/discounts/retrieve',
  'op_id': 'GetCustomersCustomerSubscriptionsSubscriptionExposedIdDiscount',
  'path': '/v1/customers/{customer}/subscriptions/{subscription_exposed_id}/discount',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': '',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/tax_ids/delete',
  'op_id': 'GetCustomersCustomerTaxIds',
  'path': '/v1/customers/{customer}/tax_ids',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all Customer tax IDs',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'Type of the tax ID, one of `ad_nrt`, `ae_trn`, `al_tin`, `am_tin`, `ao_tin`, `ar_cuit`, `au_abn`, `au_arn`, `aw_tin`, `az_tin`, `ba_tin`, `bb_tin`, `bd_bin`, `bf_ifu`, `bg_uic`, `bh_vat`, `bj_ifu`, `bo_tin`, `br_cnpj`, `br_cpf`, `bs_tin`, `by_tin`, `ca_bn`, `ca_gst_hst`, `ca_pst_bc`, `ca_pst_mb`, `ca_pst_sk`, `ca_qst`, `cd_nif`, '
                           '`ch_uid`, `ch_vat`, `cl_tin`, `cm_niu`, `cn_tin`, `co_nit`, `cr_tin`, `cv_nif`, `de_stn`, `do_rcn`, `ec_ruc`, `eg_tin`, `es_cif`, `et_tin`, `eu_oss_vat`, `eu_vat`, `gb_vat`, `ge_vat`, `gn_nif`, `hk_br`, `hr_oib`, `hu_tin`, `id_npwp`, `il_vat`, `in_gst`, `is_vat`, `jp_cn`, `jp_rn`, `jp_trn`, `ke_pin`, `kg_tin`, `kh_tin`, '
                           '`kr_brn`, `kz_bin`, `la_tin`, `li_uid`, `li_vat`, `ma_vat`, `md_vat`, `me_pib`, `mk_vat`, `mr_nif`, `mx_rfc`, `my_frp`, `my_itn`, `my_sst`, `ng_tin`, `no_vat`, `no_voec`, `np_pan`, `nz_gst`, `om_vat`, `pe_ruc`, `ph_tin`, `pl_nip`, `ro_tin`, `rs_pib`, `ru_inn`, `ru_kpp`, `sa_vat`, `sg_gst`, `sg_uen`, `si_tin`, `sn_ninea`, '
                           '`sr_fin`, `sv_nit`, `th_vat`, `tj_tin`, `tr_tin`, `tw_vat`, `tz_vat`, `ua_vat`, `ug_tin`, `us_ein`, `uy_ruc`, `uz_tin`, `uz_vat`, `ve_rif`, `vn_tin`, `za_vat`, `zm_tin`, or `zw_tin`',
            'name': 'type'},
           {'annotation': str, 'default': None, 'description': 'Value of the tax ID.', 'name': 'value'}],
  'doc_url': 'https://docs.stripe.com/api/tax_ids/update',
  'op_id': 'PostCustomersCustomerTaxIds',
  'path': '/v1/customers/{customer}/tax_ids',
  'qparams': [],
  'summary': 'Create a Customer tax ID',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_ids/delete', 'op_id': 'DeleteCustomersCustomerTaxIdsId', 'path': '/v1/customers/{customer}/tax_ids/{id}', 'qparams': [], 'summary': 'Delete a Customer tax ID', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_ids/delete', 'op_id': 'GetCustomersCustomerTaxIdsId', 'path': '/v1/customers/{customer}/tax_ids/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Customer tax ID', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/disputes/list',
  'op_id': 'GetDisputes',
  'path': '/v1/disputes',
  'qparams': [{'annotation': 'str', 'description': 'Only return disputes associated to the charge specified by this charge ID.', 'name': 'charge'},
              {'annotation': 'str', 'description': 'Only return disputes that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return disputes associated to the PaymentIntent specified by this PaymentIntent ID.', 'name': 'payment_intent'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all disputes',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/disputes/delete', 'op_id': 'GetDisputesDispute', 'path': '/v1/disputes/{dispute}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a dispute', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Evidence to upload, to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review. The combined character count of all fields is limited to 150,000.', 'name': 'evidence'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Whether to immediately submit evidence to the bank. If `false`, evidence is staged on the dispute. Staged evidence is visible in the API and Dashboard, and can be submitted to the bank by making another request with this attribute set to `true` (the default).', 'name': 'submit'}],
  'doc_url': 'https://docs.stripe.com/api/disputes/update',
  'op_id': 'PostDisputesDispute',
  'path': '/v1/disputes/{dispute}',
  'qparams': [],
  'summary': 'Update a dispute',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/closes/update', 'op_id': 'PostDisputesDisputeClose', 'path': '/v1/disputes/{dispute}/close', 'qparams': [], 'summary': 'Close a dispute', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/active_entitlements/list',
  'op_id': 'GetEntitlementsActiveEntitlements',
  'path': '/v1/entitlements/active_entitlements',
  'qparams': [{'annotation': 'str', 'description': 'The ID of the customer.', 'name': 'customer'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all active entitlements',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/active_entitlements/delete',
  'op_id': 'GetEntitlementsActiveEntitlementsId',
  'path': '/v1/entitlements/active_entitlements/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an active entitlement',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/features/list',
  'op_id': 'GetEntitlementsFeatures',
  'path': '/v1/entitlements/features',
  'qparams': [{'annotation': 'str', 'description': 'If set, filter results to only include features with the given archive status.', 'name': 'archived'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'If set, filter results to only include features with the given lookup_key.', 'name': 'lookup_key'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all features',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'A unique key you provide as your own system identifier. This may be up to 80 characters.', 'name': 'lookup_key'},
           {'annotation': dict, 'default': None, 'description': 'Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.', 'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The feature's name, for your own purpose, not meant to be displayable to the customer.", 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/features/create',
  'op_id': 'PostEntitlementsFeatures',
  'path': '/v1/entitlements/features',
  'qparams': [],
  'summary': 'Create a feature',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/features/delete', 'op_id': 'GetEntitlementsFeaturesId', 'path': '/v1/entitlements/features/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a feature', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Inactive features cannot be attached to new products and will not be returned from the features list endpoint.', 'name': 'active'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.', 'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The feature's name, for your own purpose, not meant to be displayable to the customer.", 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/features/update',
  'op_id': 'PostEntitlementsFeaturesId',
  'path': '/v1/entitlements/features/{id}',
  'qparams': [],
  'summary': 'Updates a feature',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': "The ID of the Customer you'd like to modify using the resulting ephemeral key.", 'name': 'customer'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': "The ID of the Issuing Card you'd like to access using the resulting ephemeral key.", 'name': 'issuing_card'},
           {'annotation': str, 'default': None, 'description': 'A single-use token, created by Stripe.js, used for creating ephemeral keys for Issuing Cards without exchanging sensitive information.', 'name': 'nonce'},
           {'annotation': str, 'default': None, 'description': "The ID of the Identity VerificationSession you'd like to access using the resulting ephemeral key", 'name': 'verification_session'}],
  'doc_url': 'https://docs.stripe.com/api/ephemeral_keys/create',
  'op_id': 'PostEphemeralKeys',
  'path': '/v1/ephemeral_keys',
  'qparams': [],
  'summary': 'Create an ephemeral key',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/ephemeral_keys/delete',
  'op_id': 'DeleteEphemeralKeysKey',
  'path': '/v1/ephemeral_keys/{key}',
  'qparams': [],
  'summary': 'Immediately invalidate an ephemeral key',
  'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/events/list',
  'op_id': 'GetEvents',
  'path': '/v1/events',
  'qparams': [{'annotation': 'str', 'description': 'Only return events that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Filter events by whether all webhooks were successfully delivered. If false, events which are still pending or have failed all delivery attempts to a webhook endpoint will be returned.', 'name': 'delivery_success'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'A string containing a specific event name, or group of events using * as a wildcard. The list will be filtered to include only events with a matching event property.', 'name': 'type'},
              {'annotation': 'str', 'description': 'An array of up to 20 strings containing specific event names. The list will be filtered to include only events with a matching event property. You may pass either `type` or `types`, but not both.', 'name': 'types'}],
  'summary': 'List all events',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/events/delete', 'op_id': 'GetEventsId', 'path': '/v1/events/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an event', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/exchange_rates/list',
  'op_id': 'GetExchangeRates',
  'path': '/v1/exchange_rates',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is the currency that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with the exchange rate for currency X your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and total number of supported payout currencies, and the default is the max.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is the currency that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with the exchange rate for currency X, your subsequent call can include `starting_after=X` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all exchange rates',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/exchange_rates/delete', 'op_id': 'GetExchangeRatesRateId', 'path': '/v1/exchange_rates/{rate_id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an exchange rate', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the person or business that owns the bank account.', 'name': 'account_holder_name'},
           {'annotation': str, 'default': None, 'description': 'The type of entity that holds the account. This can be either `individual` or `company`.', 'name': 'account_holder_type'},
           {'annotation': str, 'default': None, 'description': 'The bank account type. This can only be `checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.', 'name': 'account_type'},
           {'annotation': str, 'default': None, 'description': 'City/District/Suburb/Town/Village.', 'name': 'address_city'},
           {'annotation': str, 'default': None, 'description': 'Billing address country, if provided when creating card.', 'name': 'address_country'},
           {'annotation': str, 'default': None, 'description': 'Address line 1 (Street address/PO Box/Company name).', 'name': 'address_line1'},
           {'annotation': str, 'default': None, 'description': 'Address line 2 (Apartment/Suite/Unit/Building).', 'name': 'address_line2'},
           {'annotation': str, 'default': None, 'description': 'State/County/Province/Region.', 'name': 'address_state'},
           {'annotation': str, 'default': None, 'description': 'ZIP or postal code.', 'name': 'address_zip'},
           {'annotation': bool, 'default': None, 'description': 'When set to true, this becomes the default external account for its currency.', 'name': 'default_for_currency'},
           {'annotation': dict, 'default': None, 'description': 'Documents that may be submitted to satisfy various informational requests.', 'name': 'documents'},
           {'annotation': str, 'default': None, 'description': 'Two digit number representing the card’s expiration month.', 'name': 'exp_month'},
           {'annotation': str, 'default': None, 'description': 'Four digit number representing the card’s expiration year.', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Cardholder name.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/external_accounts/update',
  'op_id': 'PostExternalAccountsId',
  'path': '/v1/external_accounts/{id}',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/integration_configs/retrieve',
  'op_id': 'GetFabricServiceIntegrationConfig',
  'path': '/v1/fabric/service/integration_config',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': 'str', 'description': '', 'name': 'service_name'}],
  'summary': '',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': str, 'default': None, 'description': '', 'name': 'service_name'}],
  'doc_url': 'https://docs.stripe.com/api/subscribes/create',
  'op_id': 'PostFabricServiceSubscribe',
  'path': '/v1/fabric/service/subscribe',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/file_links/list',
  'op_id': 'GetFileLinks',
  'path': '/v1/file_links',
  'qparams': [{'annotation': 'str', 'description': 'Only return links that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Filter links by their expiration status. By default, Stripe returns all links.', 'name': 'expired'},
              {'annotation': 'str', 'description': 'Only return links for the given file.', 'name': 'file'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all file links',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': "The link isn't usable after this future timestamp.", 'name': 'expires_at'},
           {'annotation': str,
            'default': None,
            'description': "The ID of the file. The file's `purpose` must be one of the following: `business_icon`, `business_logo`, `customer_signature`, `dispute_evidence`, `finance_report_run`, `financial_account_statement`, `identity_document_downloadable`, `issuing_regulatory_reporting`, `pci_document`, `selfie`, `sigma_scheduled_query`, "
                           '`tax_document_user_upload`, `terminal_android_apk`, or `terminal_reader_splashscreen`.',
            'name': 'file'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/file_links/create',
  'op_id': 'PostFileLinks',
  'path': '/v1/file_links',
  'qparams': [],
  'summary': 'Create a file link',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/file_links/delete', 'op_id': 'GetFileLinksLink', 'path': '/v1/file_links/{link}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a file link', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'A future timestamp after which the link will no longer be usable, or `now` to expire the link immediately.', 'name': 'expires_at'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/file_links/update',
  'op_id': 'PostFileLinksLink',
  'path': '/v1/file_links/{link}',
  'qparams': [],
  'summary': 'Update a file link',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/files/list',
  'op_id': 'GetFiles',
  'path': '/v1/files',
  'qparams': [{'annotation': 'str', 'description': 'Only return files that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "Filter queries by the file purpose. If you don't provide a purpose, the queries return unfiltered files.", 'name': 'purpose'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all files',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/files/create', 'op_id': 'PostFiles', 'path': '/v1/files', 'qparams': [], 'summary': 'Create a file', 'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/files/delete', 'op_id': 'GetFilesFile', 'path': '/v1/files/{file}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a file', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/accounts/list',
  'op_id': 'GetFinancialConnectionsAccounts',
  'path': '/v1/financial_connections/accounts',
  'qparams': [{'annotation': 'str', 'description': 'If present, only return accounts that belong to the specified account holder. `account_holder[customer]` and `account_holder[account]` are mutually exclusive.', 'name': 'account_holder'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'If present, only return accounts that were collected as part of the given session.', 'name': 'session'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Accounts',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/accounts/delete', 'op_id': 'GetFinancialConnectionsAccountsAccount', 'path': '/v1/financial_connections/accounts/{account}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an Account', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/disconnects/update',
  'op_id': 'PostFinancialConnectionsAccountsAccountDisconnect',
  'path': '/v1/financial_connections/accounts/{account}/disconnect',
  'qparams': [],
  'summary': 'Disconnect an Account',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/owners/delete',
  'op_id': 'GetFinancialConnectionsAccountsAccountOwners',
  'path': '/v1/financial_connections/accounts/{account}/owners',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The ID of the ownership object to fetch owners from.', 'name': 'ownership'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Account Owners',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': list, 'default': None, 'description': 'The list of account features that you would like to refresh.', 'name': 'features'}],
  'doc_url': 'https://docs.stripe.com/api/refreshs/update',
  'op_id': 'PostFinancialConnectionsAccountsAccountRefresh',
  'path': '/v1/financial_connections/accounts/{account}/refresh',
  'qparams': [],
  'summary': 'Refresh Account data',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': list, 'default': None, 'description': 'The list of account features to which you would like to subscribe.', 'name': 'features'}],
  'doc_url': 'https://docs.stripe.com/api/subscribes/update',
  'op_id': 'PostFinancialConnectionsAccountsAccountSubscribe',
  'path': '/v1/financial_connections/accounts/{account}/subscribe',
  'qparams': [],
  'summary': 'Subscribe to data refreshes for an Account',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': list, 'default': None, 'description': 'The list of account features from which you would like to unsubscribe.', 'name': 'features'}],
  'doc_url': 'https://docs.stripe.com/api/unsubscribes/update',
  'op_id': 'PostFinancialConnectionsAccountsAccountUnsubscribe',
  'path': '/v1/financial_connections/accounts/{account}/unsubscribe',
  'qparams': [],
  'summary': 'Unsubscribe from data refreshes for an Account',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The account holder to link accounts for.', 'name': 'account_holder'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Filters to restrict the kinds of accounts to collect.', 'name': 'filters'},
           {'annotation': list, 'default': None, 'description': 'List of data features that you would like to request access to.\n\nPossible values are `balances`, `transactions`, `ownership`, and `payment_method`.', 'name': 'permissions'},
           {'annotation': list, 'default': None, 'description': 'List of data features that you would like to retrieve upon account creation.', 'name': 'prefetch'},
           {'annotation': str, 'default': None, 'description': 'For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.', 'name': 'return_url'}],
  'doc_url': 'https://docs.stripe.com/api/sessions/create',
  'op_id': 'PostFinancialConnectionsSessions',
  'path': '/v1/financial_connections/sessions',
  'qparams': [],
  'summary': 'Create a Session',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/sessions/delete', 'op_id': 'GetFinancialConnectionsSessionsSession', 'path': '/v1/financial_connections/sessions/{session}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Session', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transactions/list',
  'op_id': 'GetFinancialConnectionsTransactions',
  'path': '/v1/financial_connections/transactions',
  'qparams': [{'annotation': 'str', 'description': 'The ID of the Financial Connections Account whose transactions will be retrieved.', 'name': 'account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'A filter on the list based on the object `transacted_at` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with the following options:', 'name': 'transacted_at'},
              {'annotation': 'str', 'description': 'A filter on the list based on the object `transaction_refresh` field. The value can be a dictionary with the following options:', 'name': 'transaction_refresh'}],
  'summary': 'List Transactions',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transactions/delete',
  'op_id': 'GetFinancialConnectionsTransactionsTransaction',
  'path': '/v1/financial_connections/transactions/{transaction}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a Transaction',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/requests/list',
  'op_id': 'GetForwardingRequests',
  'path': '/v1/forwarding/requests',
  'qparams': [{'annotation': 'str', 'description': 'Similar to other List endpoints, filters results based on created timestamp. You can pass gt, gte, lt, and lte timestamp values.', 'name': 'created'},
              {'annotation': 'str', 'description': 'A pagination cursor to fetch the previous page of the list. The value must be a ForwardingRequest ID.', 'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'A pagination cursor to fetch the next page of the list. The value must be a ForwardingRequest ID.', 'name': 'starting_after'}],
  'summary': 'List all ForwardingRequests',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The PaymentMethod to insert into the forwarded request. Forwarding previously consumed PaymentMethods is allowed.', 'name': 'payment_method'},
           {'annotation': list, 'default': None, 'description': 'The field kinds to be replaced in the forwarded request.', 'name': 'replacements'},
           {'annotation': dict, 'default': None, 'description': 'The request body and headers to be sent to the destination endpoint.', 'name': 'request'},
           {'annotation': str, 'default': None, 'description': 'The destination URL for the forwarded request. Must be supported by the config.', 'name': 'url'}],
  'doc_url': 'https://docs.stripe.com/api/requests/create',
  'op_id': 'PostForwardingRequests',
  'path': '/v1/forwarding/requests',
  'qparams': [],
  'summary': 'Create a ForwardingRequest',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/requests/delete', 'op_id': 'GetForwardingRequestsId', 'path': '/v1/forwarding/requests/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a ForwardingRequest', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/verification_reports/list',
  'op_id': 'GetIdentityVerificationReports',
  'path': '/v1/identity/verification_reports',
  'qparams': [{'annotation': 'str', 'description': 'A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.', 'name': 'client_reference_id'},
              {'annotation': 'str', 'description': 'Only return VerificationReports that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return VerificationReports of this type', 'name': 'type'},
              {'annotation': 'str', 'description': 'Only return VerificationReports created by this VerificationSession ID. It is allowed to provide a VerificationIntent ID.', 'name': 'verification_session'}],
  'summary': 'List VerificationReports',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/verification_reports/delete',
  'op_id': 'GetIdentityVerificationReportsReport',
  'path': '/v1/identity/verification_reports/{report}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a VerificationReport',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/verification_sessions/list',
  'op_id': 'GetIdentityVerificationSessions',
  'path': '/v1/identity/verification_sessions',
  'qparams': [{'annotation': 'str', 'description': 'A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.', 'name': 'client_reference_id'},
              {'annotation': 'str', 'description': 'Only return VerificationSessions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Customer ID', 'name': 'related_customer'},
              {'annotation': 'str', 'description': 'The ID of the Account representing a customer.', 'name': 'related_customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return VerificationSessions with this status. [Learn more about the lifecycle of sessions](https://docs.stripe.com/identity/how-sessions-work).', 'name': 'status'}],
  'summary': 'List VerificationSessions',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.', 'name': 'client_reference_id'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'A set of options for the session’s verification checks.', 'name': 'options'},
           {'annotation': dict, 'default': None, 'description': 'Details provided about the user being verified. These details may be shown to the user.', 'name': 'provided_details'},
           {'annotation': str, 'default': None, 'description': 'Customer ID', 'name': 'related_customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of the Account representing a customer.', 'name': 'related_customer_account'},
           {'annotation': dict, 'default': None, 'description': "Tokens referencing a Person resource and it's associated account.", 'name': 'related_person'},
           {'annotation': str, 'default': None, 'description': 'The URL that the user will be redirected to upon completing the verification flow.', 'name': 'return_url'},
           {'annotation': str, 'default': None, 'description': 'The type of [verification check](https://docs.stripe.com/identity/verification-checks) to be performed. You must provide a `type` if not passing `verification_flow`.', 'name': 'type'},
           {'annotation': str, 'default': None, 'description': 'The ID of a verification flow from the Dashboard. See https://docs.stripe.com/identity/verification-flows.', 'name': 'verification_flow'}],
  'doc_url': 'https://docs.stripe.com/api/verification_sessions/create',
  'op_id': 'PostIdentityVerificationSessions',
  'path': '/v1/identity/verification_sessions',
  'qparams': [],
  'summary': 'Create a VerificationSession',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/verification_sessions/delete',
  'op_id': 'GetIdentityVerificationSessionsSession',
  'path': '/v1/identity/verification_sessions/{session}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a VerificationSession',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'A set of options for the session’s verification checks.', 'name': 'options'},
           {'annotation': dict, 'default': None, 'description': 'Details provided about the user being verified. These details may be shown to the user.', 'name': 'provided_details'},
           {'annotation': str, 'default': None, 'description': 'The type of [verification check](https://docs.stripe.com/identity/verification-checks) to be performed.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/verification_sessions/update',
  'op_id': 'PostIdentityVerificationSessionsSession',
  'path': '/v1/identity/verification_sessions/{session}',
  'qparams': [],
  'summary': 'Update a VerificationSession',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostIdentityVerificationSessionsSessionCancel',
  'path': '/v1/identity/verification_sessions/{session}/cancel',
  'qparams': [],
  'summary': 'Cancel a VerificationSession',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/redacts/update',
  'op_id': 'PostIdentityVerificationSessionsSessionRedact',
  'path': '/v1/identity/verification_sessions/{session}/redact',
  'qparams': [],
  'summary': 'Redact a VerificationSession',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoice_payments/list',
  'op_id': 'GetInvoicePayments',
  'path': '/v1/invoice_payments',
  'qparams': [{'annotation': 'str', 'description': 'Only return invoice payments that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'The identifier of the invoice whose payments to return.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The payment details of the invoice payments to return.', 'name': 'payment'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'The status of the invoice payments to return.', 'name': 'status'}],
  'summary': 'List all payments for an invoice',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoice_payments/delete',
  'op_id': 'GetInvoicePaymentsInvoicePayment',
  'path': '/v1/invoice_payments/{invoice_payment}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an InvoicePayment',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoice_rendering_templates/list',
  'op_id': 'GetInvoiceRenderingTemplates',
  'path': '/v1/invoice_rendering_templates',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': '', 'name': 'status'}],
  'summary': 'List all invoice rendering templates',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoice_rendering_templates/delete',
  'op_id': 'GetInvoiceRenderingTemplatesTemplate',
  'path': '/v1/invoice_rendering_templates/{template}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': 'str', 'description': '', 'name': 'version'}],
  'summary': 'Retrieve an invoice rendering template',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/archives/update',
  'op_id': 'PostInvoiceRenderingTemplatesTemplateArchive',
  'path': '/v1/invoice_rendering_templates/{template}/archive',
  'qparams': [],
  'summary': 'Archive an invoice rendering template',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/unarchives/update',
  'op_id': 'PostInvoiceRenderingTemplatesTemplateUnarchive',
  'path': '/v1/invoice_rendering_templates/{template}/unarchive',
  'qparams': [],
  'summary': 'Unarchive an invoice rendering template',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoiceitems/list',
  'op_id': 'GetInvoiceitems',
  'path': '/v1/invoiceitems',
  'qparams': [{'annotation': 'str', 'description': 'Only return invoice items that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'The identifier of the customer whose invoice items to return. If none is provided, returns all invoice items.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'The identifier of the account representing the customer whose invoice items to return. If none is provided, returns all invoice items.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.', 'name': 'invoice'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Set to `true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.', 'name': 'pending'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all invoice items',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. Passing in a negative `amount` will reduce the `amount_due` on the invoice.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'The ID of the customer to bill for this invoice item.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of the account representing the customer to bill for this invoice item.', 'name': 'customer_account'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.', 'name': 'description'},
           {'annotation': bool, 'default': None, 'description': 'Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items.', 'name': 'discountable'},
           {'annotation': object, 'default': None, 'description': 'The coupons and promotion codes to redeem into discounts for the invoice item or invoice line item.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': "The ID of an existing invoice to add this invoice item to. For subscription invoices, when left blank, the invoice item will be added to the next upcoming scheduled invoice. For standalone invoices, the invoice item won't be automatically added unless you pass `pending_invoice_item_behavior: 'include'` when creating the invoice. "
                           'This is useful when adding invoice items in response to an invoice.created webhook. You can only add invoice items to draft invoices and there is a maximum of 250 items per invoice.',
            'name': 'invoice'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict,
            'default': None,
            'description': 'The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](https://docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition '
                           'documentation](https://docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.',
            'name': 'period'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object inline.', 'name': 'price_data'},
           {'annotation': dict, 'default': None, 'description': 'The pricing information for the invoice item.', 'name': 'pricing'},
           {'annotation': int, 'default': None, 'description': 'Non-negative integer. The quantity of units for the invoice item.', 'name': 'quantity'},
           {'annotation': str,
            'default': None,
            'description': 'The ID of a subscription to add this invoice item to. When left blank, the invoice item is added to the next upcoming scheduled invoice. When set, scheduled invoices for subscriptions other than the specified subscription will ignore the invoice item. Use this when you want to express that an invoice item has been accrued within '
                           'the context of a particular subscription.',
            'name': 'subscription'},
           {'annotation': str,
            'default': None,
            'description': 'Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or '
                           '`unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.',
            'name': 'tax_behavior'},
           {'annotation': object, 'default': None, 'description': 'A [tax code](https://docs.stripe.com/tax/tax-categories) ID.', 'name': 'tax_code'},
           {'annotation': list, 'default': None, 'description': 'The tax rates which apply to the invoice item. When set, the `default_tax_rates` on the invoice do not apply to this invoice item.', 'name': 'tax_rates'},
           {'annotation': str,
            'default': None,
            'description': 'The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This `unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.',
            'name': 'unit_amount_decimal'}],
  'doc_url': 'https://docs.stripe.com/api/invoiceitems/create',
  'op_id': 'PostInvoiceitems',
  'path': '/v1/invoiceitems',
  'qparams': [],
  'summary': 'Create an invoice item',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/invoiceitems/delete', 'op_id': 'DeleteInvoiceitemsInvoiceitem', 'path': '/v1/invoiceitems/{invoiceitem}', 'qparams': [], 'summary': 'Delete an invoice item', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/invoiceitems/delete', 'op_id': 'GetInvoiceitemsInvoiceitem', 'path': '/v1/invoiceitems/{invoiceitem}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an invoice item', 'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': "The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer's account, pass a negative amount.", 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.', 'name': 'description'},
           {'annotation': bool, 'default': None, 'description': 'Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.', 'name': 'discountable'},
           {'annotation': object, 'default': None, 'description': 'The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict,
            'default': None,
            'description': 'The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](https://docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition '
                           'documentation](https://docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.',
            'name': 'period'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object inline.', 'name': 'price_data'},
           {'annotation': dict, 'default': None, 'description': 'The pricing information for the invoice item.', 'name': 'pricing'},
           {'annotation': int, 'default': None, 'description': 'Non-negative integer. The quantity of units for the invoice item.', 'name': 'quantity'},
           {'annotation': str,
            'default': None,
            'description': 'Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or '
                           '`unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.',
            'name': 'tax_behavior'},
           {'annotation': object, 'default': None, 'description': 'A [tax code](https://docs.stripe.com/tax/tax-categories) ID.', 'name': 'tax_code'},
           {'annotation': object, 'default': None, 'description': 'The tax rates which apply to the invoice item. When set, the `default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.', 'name': 'tax_rates'},
           {'annotation': str,
            'default': None,
            'description': 'The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This `unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.',
            'name': 'unit_amount_decimal'}],
  'doc_url': 'https://docs.stripe.com/api/invoiceitems/update',
  'op_id': 'PostInvoiceitemsInvoiceitem',
  'path': '/v1/invoiceitems/{invoiceitem}',
  'qparams': [],
  'summary': 'Update an invoice item',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/invoices/list',
  'op_id': 'GetInvoices',
  'path': '/v1/invoices',
  'qparams': [{'annotation': 'str', 'description': 'The collection method of the invoice to retrieve. Either `charge_automatically` or `send_invoice`.', 'name': 'collection_method'},
              {'annotation': 'str', 'description': 'Only return invoices that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return invoices for the customer specified by this customer ID.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return invoices for the account representing the customer specified by this account ID.', 'name': 'customer_account'},
              {'annotation': 'str', 'description': '', 'name': 'due_date'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'The status of the invoice, one of `draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](https://docs.stripe.com/billing/invoices/workflow#workflow-overview)', 'name': 'status'},
              {'annotation': 'str', 'description': 'Only return invoices for the subscription specified by this subscription ID.', 'name': 'subscription'}],
  'summary': 'List all invoices',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'The account tax IDs associated with the invoice. Only editable when the invoice is a draft.', 'name': 'account_tax_ids'},
           {'annotation': int,
            'default': None,
            'description': "A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner's Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees "
                           '[documentation](https://docs.stripe.com/billing/invoices/connect#collecting-fees).',
            'name': 'application_fee_amount'},
           {'annotation': bool, 'default': None, 'description': "Controls whether Stripe performs [automatic collection](https://docs.stripe.com/invoicing/integration/automatic-advancement-collection) of the invoice. If `false`, the invoice's state doesn't automatically advance without an explicit action. Defaults to false.", 'name': 'auto_advance'},
           {'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this invoice.', 'name': 'automatic_tax'},
           {'annotation': int, 'default': None, 'description': "The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it's still in draft state.", 'name': 'automatically_finalizes_at'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': str, 'default': None, 'description': 'The currency to create this invoice in. Defaults to that of `customer` if not specified.', 'name': 'currency'},
           {'annotation': object, 'default': None, 'description': 'A list of up to 4 custom fields to be displayed on the invoice.', 'name': 'custom_fields'},
           {'annotation': str, 'default': None, 'description': 'The ID of the customer to bill.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of the account to bill.', 'name': 'customer_account'},
           {'annotation': int, 'default': None, 'description': 'The number of days from when the invoice is created until it is due. Valid only for invoices where `collection_method=send_invoice`.', 'name': 'days_until_due'},
           {'annotation': str, 'default': None, 'description': "ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription's default payment method, if any, or to the default payment method in the customer's invoice settings.", 'name': 'default_payment_method'},
           {'annotation': str, 'default': None, 'description': "ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription's default source, if any, or to the customer's default source.", 'name': 'default_source'},
           {'annotation': list, 'default': None, 'description': 'The tax rates that will apply to any line item that does not have `tax_rates` set.', 'name': 'default_tax_rates'},
           {'annotation': str, 'default': None, 'description': "An arbitrary string attached to the object. Often useful for displaying to users. Referenced as 'memo' in the Dashboard.", 'name': 'description'},
           {'annotation': object, 'default': None, 'description': "The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice's customer. Pass an empty string to avoid inheriting any discounts.", 'name': 'discounts'},
           {'annotation': int, 'default': None, 'description': 'The date on which payment for this invoice is due. Valid only for invoices where `collection_method=send_invoice`.', 'name': 'due_date'},
           {'annotation': int, 'default': None, 'description': "The date when this invoice is in effect. Same as `finalized_at` unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the invoice PDF and receipt.", 'name': 'effective_at'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Footer to be displayed on the invoice.', 'name': 'footer'},
           {'annotation': dict, 'default': None, 'description': 'Revise an existing invoice. The new invoice will be created in `status=draft`. See the [revision documentation](https://docs.stripe.com/invoicing/invoice-revisions) for more details.', 'name': 'from_invoice'},
           {'annotation': dict, 'default': None, 'description': 'The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.', 'name': 'issuer'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that '
                           'you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.',
            'name': 'number'},
           {'annotation': str,
            'default': None,
            'description': 'The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](https://docs.stripe.com/billing/invoices/connect) documentation for details.',
            'name': 'on_behalf_of'},
           {'annotation': dict, 'default': None, 'description': 'Configuration settings for the PaymentIntent that is generated when the invoice is finalized.', 'name': 'payment_settings'},
           {'annotation': str, 'default': None, 'description': 'How to handle pending invoice items on invoice creation. Defaults to `exclude` if the parameter is omitted.', 'name': 'pending_invoice_items_behavior'},
           {'annotation': dict, 'default': None, 'description': 'The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.', 'name': 'rendering'},
           {'annotation': dict, 'default': None, 'description': 'Settings for the cost of shipping for this invoice.', 'name': 'shipping_cost'},
           {'annotation': dict, 'default': None, 'description': 'Shipping details for the invoice. The Invoice PDF will use the `shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.', 'name': 'shipping_details'},
           {'annotation': str,
            'default': None,
            'description': "Extra information about a charge for the customer's credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default `statement_descriptor` will be set to the first subscription item's product's `statement_descriptor`.",
            'name': 'statement_descriptor'},
           {'annotation': str, 'default': None, 'description': "The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription's billing cycle and regular subscription events won't be affected.", 'name': 'subscription'},
           {'annotation': dict, 'default': None, 'description': "If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice's charge.", 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/invoices/create',
  'op_id': 'PostInvoices',
  'path': '/v1/invoices',
  'qparams': [],
  'summary': 'Create an invoice',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this invoice preview.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': 'The currency to preview this invoice in. Defaults to that of `customer` if not specified.', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': "The identifier of the customer whose upcoming invoice you're retrieving. If `automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.", 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': "The identifier of the account representing the customer whose upcoming invoice you're retrieving. If `automatic_tax` is enabled then one of `customer`, `customer_account`, `customer_details`, `subscription`, or `schedule` must be set.", 'name': 'customer_account'},
           {'annotation': dict, 'default': None, 'description': 'Details about the customer you want to invoice or overrides for an existing customer. If `automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.', 'name': 'customer_details'},
           {'annotation': object,
            'default': None,
            'description': 'The coupons to redeem into discounts for the invoice preview. If not specified, inherits the discount from the subscription or customer. This works for both coupons directly applied to an invoice and coupons applied to a subscription. Pass an empty string to avoid inheriting any discounts.',
            'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list, 'default': None, 'description': 'List of invoice items to add or update in the upcoming invoice preview (up to 250).', 'name': 'invoice_items'},
           {'annotation': dict, 'default': None, 'description': 'The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.', 'name': 'issuer'},
           {'annotation': object,
            'default': None,
            'description': 'The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](https://docs.stripe.com/billing/invoices/connect) documentation for details.',
            'name': 'on_behalf_of'},
           {'annotation': str, 'default': None, 'description': 'Customizes the types of values to include when calculating the invoice. Defaults to `next` if unspecified.', 'name': 'preview_mode'},
           {'annotation': str, 'default': None, 'description': "The identifier of the schedule whose upcoming invoice you'd like to retrieve. Cannot be used with subscription or subscription fields.", 'name': 'schedule'},
           {'annotation': dict, 'default': None, 'description': 'The schedule creation or modification params to apply as a preview. Cannot be used with `subscription` or `subscription_` prefixed fields.', 'name': 'schedule_details'},
           {'annotation': str,
            'default': None,
            'description': "The identifier of the subscription for which you'd like to retrieve the upcoming invoice. If not provided, but a `subscription_details.items` is provided, you will preview creating a subscription with those items. If neither `subscription` nor `subscription_details.items` is provided, you will retrieve the next upcoming invoice "
                           "from among the customer's subscriptions.",
            'name': 'subscription'},
           {'annotation': dict, 'default': None, 'description': 'The subscription creation or modification params to apply as a preview. Cannot be used with `schedule` or `schedule_details` fields.', 'name': 'subscription_details'}],
  'doc_url': 'https://docs.stripe.com/api/create_previews/create',
  'op_id': 'PostInvoicesCreatePreview',
  'path': '/v1/invoices/create_preview',
  'qparams': [],
  'summary': 'Create a preview invoice',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetInvoicesSearch',
  'path': '/v1/invoices/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for invoices](https://docs.stripe.com/search#query-fields-for-invoices).', 'name': 'query'}],
  'summary': 'Search invoices',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/invoices/delete', 'op_id': 'DeleteInvoicesInvoice', 'path': '/v1/invoices/{invoice}', 'qparams': [], 'summary': 'Delete a draft invoice', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/invoices/delete', 'op_id': 'GetInvoicesInvoice', 'path': '/v1/invoices/{invoice}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an invoice', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'The account tax IDs associated with the invoice. Only editable when the invoice is a draft.', 'name': 'account_tax_ids'},
           {'annotation': int,
            'default': None,
            'description': "A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner's Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees "
                           '[documentation](https://docs.stripe.com/billing/invoices/connect#collecting-fees).',
            'name': 'application_fee_amount'},
           {'annotation': bool, 'default': None, 'description': 'Controls whether Stripe performs [automatic collection](https://docs.stripe.com/invoicing/integration/automatic-advancement-collection) of the invoice.', 'name': 'auto_advance'},
           {'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this invoice.', 'name': 'automatic_tax'},
           {'annotation': int, 'default': None, 'description': "The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it's still in draft state. To turn off automatic finalization, set `auto_advance` to false.", 'name': 'automatically_finalizes_at'},
           {'annotation': str, 'default': None, 'description': 'Either `charge_automatically` or `send_invoice`. This field can be updated only on `draft` invoices.', 'name': 'collection_method'},
           {'annotation': object, 'default': None, 'description': 'A list of up to 4 custom fields to be displayed on the invoice. If a value for `custom_fields` is specified, the list specified will replace the existing custom field list on this invoice. Pass an empty string to remove previously-defined fields.', 'name': 'custom_fields'},
           {'annotation': int, 'default': None, 'description': 'The number of days from which the invoice is created until it is due. Only valid for invoices where `collection_method=send_invoice`. This field can only be updated on `draft` invoices.', 'name': 'days_until_due'},
           {'annotation': str, 'default': None, 'description': "ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription's default payment method, if any, or to the default payment method in the customer's invoice settings.", 'name': 'default_payment_method'},
           {'annotation': object, 'default': None, 'description': "ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription's default source, if any, or to the customer's default source.", 'name': 'default_source'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any line item that does not have `tax_rates` set. Pass an empty string to remove previously-defined tax rates.', 'name': 'default_tax_rates'},
           {'annotation': str, 'default': None, 'description': "An arbitrary string attached to the object. Often useful for displaying to users. Referenced as 'memo' in the Dashboard.", 'name': 'description'},
           {'annotation': object, 'default': None, 'description': 'The discounts that will apply to the invoice. Pass an empty string to remove previously-defined discounts.', 'name': 'discounts'},
           {'annotation': int, 'default': None, 'description': 'The date on which payment for this invoice is due. Only valid for invoices where `collection_method=send_invoice`. This field can only be updated on `draft` invoices.', 'name': 'due_date'},
           {'annotation': object, 'default': None, 'description': "The date when this invoice is in effect. Same as `finalized_at` unless overwritten. When defined, this value replaces the system-generated 'Date of issue' printed on the invoice PDF and receipt.", 'name': 'effective_at'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Footer to be displayed on the invoice.', 'name': 'footer'},
           {'annotation': dict, 'default': None, 'description': 'The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.', 'name': 'issuer'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object,
            'default': None,
            'description': 'Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that '
                           'you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.',
            'name': 'number'},
           {'annotation': object,
            'default': None,
            'description': 'The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](https://docs.stripe.com/billing/invoices/connect) documentation for details.',
            'name': 'on_behalf_of'},
           {'annotation': dict, 'default': None, 'description': 'Configuration settings for the PaymentIntent that is generated when the invoice is finalized.', 'name': 'payment_settings'},
           {'annotation': dict, 'default': None, 'description': 'The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.', 'name': 'rendering'},
           {'annotation': object, 'default': None, 'description': 'Settings for the cost of shipping for this invoice.', 'name': 'shipping_cost'},
           {'annotation': object, 'default': None, 'description': 'Shipping details for the invoice. The Invoice PDF will use the `shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.', 'name': 'shipping_details'},
           {'annotation': str,
            'default': None,
            'description': "Extra information about a charge for the customer's credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default `statement_descriptor` will be set to the first subscription item's product's `statement_descriptor`.",
            'name': 'statement_descriptor'},
           {'annotation': object, 'default': None, 'description': "If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice's charge. This will be unset if you POST an empty value.", 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/invoices/update',
  'op_id': 'PostInvoicesInvoice',
  'path': '/v1/invoices/{invoice}',
  'qparams': [],
  'summary': 'Update an invoice',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'invoice_metadata'},
           {'annotation': list, 'default': None, 'description': 'The line items to add.', 'name': 'lines'}],
  'doc_url': 'https://docs.stripe.com/api/add_lines/update',
  'op_id': 'PostInvoicesInvoiceAddLines',
  'path': '/v1/invoices/{invoice}/add_lines',
  'qparams': [],
  'summary': 'Bulk add invoice line items',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The ID of the PaymentIntent to attach to the invoice.', 'name': 'payment_intent'},
           {'annotation': str, 'default': None, 'description': 'The ID of the PaymentRecord to attach to the invoice.', 'name': 'payment_record'}],
  'doc_url': 'https://docs.stripe.com/api/attach_payments/update',
  'op_id': 'PostInvoicesInvoiceAttachPayment',
  'path': '/v1/invoices/{invoice}/attach_payment',
  'qparams': [],
  'summary': 'Attach a payment to an Invoice',
  'verb': 'post'},
 {'data': [{'annotation': bool, 'default': None, 'description': "Controls whether Stripe performs [automatic collection](https://docs.stripe.com/invoicing/integration/automatic-advancement-collection) of the invoice. If `false`, the invoice's state doesn't automatically advance without an explicit action.", 'name': 'auto_advance'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/finalizes/update',
  'op_id': 'PostInvoicesInvoiceFinalize',
  'path': '/v1/invoices/{invoice}/finalize',
  'qparams': [],
  'summary': 'Finalize an invoice',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/lines/delete',
  'op_id': 'GetInvoicesInvoiceLines',
  'path': '/v1/invoices/{invoice}/lines',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve an invoice's line items",
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': "The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer's account, pass a negative amount.", 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.', 'name': 'description'},
           {'annotation': bool, 'default': None, 'description': 'Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.', 'name': 'discountable'},
           {'annotation': object, 'default': None, 'description': 'The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`. For '
                           '[type=subscription](https://docs.stripe.com/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the '
                           'invoice line is merged with the incoming data.',
            'name': 'metadata'},
           {'annotation': dict,
            'default': None,
            'description': 'The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](https://docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition '
                           'documentation](https://docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.',
            'name': 'period'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object inline.', 'name': 'price_data'},
           {'annotation': dict, 'default': None, 'description': 'The pricing information for the invoice item.', 'name': 'pricing'},
           {'annotation': int, 'default': None, 'description': 'Non-negative integer. The quantity of units for the line item.', 'name': 'quantity'},
           {'annotation': object,
            'default': None,
            'description': 'A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](https://docs.stripe.com/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has '
                           '[default_tax_rates](https://docs.stripe.com/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](https://docs.stripe.com/tax/invoicing). Pass an empty string to remove previously defined tax amounts.',
            'name': 'tax_amounts'},
           {'annotation': object, 'default': None, 'description': 'The tax rates which apply to the line item. When set, the `default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.', 'name': 'tax_rates'}],
  'doc_url': 'https://docs.stripe.com/api/lines/update',
  'op_id': 'PostInvoicesInvoiceLinesLineItemId',
  'path': '/v1/invoices/{invoice}/lines/{line_item_id}',
  'qparams': [],
  'summary': "Update an invoice's line item",
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/mark_uncollectibles/update',
  'op_id': 'PostInvoicesInvoiceMarkUncollectible',
  'path': '/v1/invoices/{invoice}/mark_uncollectible',
  'qparams': [],
  'summary': 'Mark an invoice as uncollectible',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool,
            'default': None,
            'description': 'In cases where the source used to pay the invoice has insufficient funds, passing `forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice. This effectively forgives the difference between the amount available on the source and the amount '
                           'due. \n'
                           '\n'
                           "Passing `forgive=false` will fail the charge if the source hasn't been pre-funded with the right amount. An example for this case is with ACH Credit Transfers and wires: if the amount wired is less than the amount due by a small amount, you might want to forgive the difference. Defaults to `false`.",
            'name': 'forgive'},
           {'annotation': object, 'default': None, 'description': "ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the payment_method param or the invoice's default_payment_method or default_source, if set.", 'name': 'mandate'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `true` (off-session).', 'name': 'off_session'},
           {'annotation': bool, 'default': None, 'description': 'Boolean representing whether an invoice is paid outside of Stripe. This will result in no charge being made. Defaults to `false`.', 'name': 'paid_out_of_band'},
           {'annotation': str, 'default': None, 'description': 'A PaymentMethod to be charged. The PaymentMethod must be the ID of a PaymentMethod belonging to the customer associated with the invoice being paid.', 'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': 'A payment source to be charged. The source must be the ID of a source belonging to the customer associated with the invoice being paid.', 'name': 'source'}],
  'doc_url': 'https://docs.stripe.com/api/pays/update',
  'op_id': 'PostInvoicesInvoicePay',
  'path': '/v1/invoices/{invoice}/pay',
  'qparams': [],
  'summary': 'Pay an invoice',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'invoice_metadata'},
           {'annotation': list, 'default': None, 'description': 'The line items to remove.', 'name': 'lines'}],
  'doc_url': 'https://docs.stripe.com/api/remove_lines/update',
  'op_id': 'PostInvoicesInvoiceRemoveLines',
  'path': '/v1/invoices/{invoice}/remove_lines',
  'qparams': [],
  'summary': 'Bulk remove invoice line items',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/sends/update', 'op_id': 'PostInvoicesInvoiceSend', 'path': '/v1/invoices/{invoice}/send', 'qparams': [], 'summary': 'Send an invoice for manual payment', 'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`. For '
                           '[type=subscription](https://docs.stripe.com/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the '
                           'invoice line is merged with the incoming data.',
            'name': 'invoice_metadata'},
           {'annotation': list, 'default': None, 'description': 'The line items to update.', 'name': 'lines'}],
  'doc_url': 'https://docs.stripe.com/api/update_lines/update',
  'op_id': 'PostInvoicesInvoiceUpdateLines',
  'path': '/v1/invoices/{invoice}/update_lines',
  'qparams': [],
  'summary': 'Bulk update invoice line items',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/voids/update', 'op_id': 'PostInvoicesInvoiceVoid', 'path': '/v1/invoices/{invoice}/void', 'qparams': [], 'summary': 'Void an invoice', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/authorizations/list',
  'op_id': 'GetIssuingAuthorizations',
  'path': '/v1/issuing/authorizations',
  'qparams': [{'annotation': 'str', 'description': 'Only return authorizations that belong to the given card.', 'name': 'card'},
              {'annotation': 'str', 'description': 'Only return authorizations that belong to the given cardholder.', 'name': 'cardholder'},
              {'annotation': 'str', 'description': 'Only return authorizations that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return authorizations with the given status. One of `pending`, `closed`, or `reversed`.', 'name': 'status'}],
  'summary': 'List all authorizations',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/authorizations/delete',
  'op_id': 'GetIssuingAuthorizationsAuthorization',
  'path': '/v1/issuing/authorizations/{authorization}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an authorization',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/authorizations/update',
  'op_id': 'PostIssuingAuthorizationsAuthorization',
  'path': '/v1/issuing/authorizations/{authorization}',
  'qparams': [],
  'summary': 'Update an authorization',
  'verb': 'post'},
 {'data': [{'annotation': int,
            'default': None,
            'description': "If the authorization's `pending_request.is_amount_controllable` property is `true`, you may provide this value to control how much to hold for the authorization. Must be positive (use [`decline`](https://docs.stripe.com/api/issuing/authorizations/decline) to decline an authorization request).",
            'name': 'amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/approves/update',
  'op_id': 'PostIssuingAuthorizationsAuthorizationApprove',
  'path': '/v1/issuing/authorizations/{authorization}/approve',
  'qparams': [],
  'summary': 'Approve an authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/declines/update',
  'op_id': 'PostIssuingAuthorizationsAuthorizationDecline',
  'path': '/v1/issuing/authorizations/{authorization}/decline',
  'qparams': [],
  'summary': 'Decline an authorization',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/cardholders/list',
  'op_id': 'GetIssuingCardholders',
  'path': '/v1/issuing/cardholders',
  'qparams': [{'annotation': 'str', 'description': 'Only return cardholders that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return cardholders that have the given email address.', 'name': 'email'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return cardholders that have the given phone number.', 'name': 'phone_number'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return cardholders that have the given status. One of `active`, `inactive`, or `blocked`.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Only return cardholders that have the given type. One of `individual` or `company`.', 'name': 'type'}],
  'summary': 'List all cardholders',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "The cardholder's billing address.", 'name': 'billing'},
           {'annotation': dict, 'default': None, 'description': 'Additional information about a `company` cardholder.', 'name': 'company'},
           {'annotation': str, 'default': None, 'description': "The cardholder's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Additional information about an `individual` cardholder.', 'name': 'individual'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The cardholder's name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.", 'name': 'name'},
           {'annotation': str,
            'default': None,
            'description': "The cardholder's phone number. This will be transformed to [E.164](https://en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](https://docs.stripe.com/issuing/3d-secure#when-is-3d-secure-applied) for more "
                           'details.',
            'name': 'phone_number'},
           {'annotation': list,
            'default': None,
            'description': 'The cardholder’s preferred locales (languages), ordered by preference. Locales can be `de`, `en`, `es`, `fr`, or `it`.\n This changes the language of the [3D Secure flow](https://docs.stripe.com/issuing/3d-secure) and one-time password messages sent to the cardholder.',
            'name': 'preferred_locales'},
           {'annotation': dict, 'default': None, 'description': "Rules that control spending across this cardholder's cards. Refer to our [documentation](https://docs.stripe.com/issuing/controls/spending-controls) for more details.", 'name': 'spending_controls'},
           {'annotation': str, 'default': None, 'description': "Specifies whether to permit authorizations on this cardholder's cards. Defaults to `active`.", 'name': 'status'},
           {'annotation': str, 'default': None, 'description': 'One of `individual` or `company`. See [Choose a cardholder type](https://docs.stripe.com/issuing/other/choose-cardholder) for more details.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/cardholders/create',
  'op_id': 'PostIssuingCardholders',
  'path': '/v1/issuing/cardholders',
  'qparams': [],
  'summary': 'Create a cardholder',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/cardholders/delete', 'op_id': 'GetIssuingCardholdersCardholder', 'path': '/v1/issuing/cardholders/{cardholder}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a cardholder', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "The cardholder's billing address.", 'name': 'billing'},
           {'annotation': dict, 'default': None, 'description': 'Additional information about a `company` cardholder.', 'name': 'company'},
           {'annotation': str, 'default': None, 'description': "The cardholder's email address.", 'name': 'email'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Additional information about an `individual` cardholder.', 'name': 'individual'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The cardholder's phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](https://docs.stripe.com/issuing/3d-secure) for more details.", 'name': 'phone_number'},
           {'annotation': list,
            'default': None,
            'description': 'The cardholder’s preferred locales (languages), ordered by preference. Locales can be `de`, `en`, `es`, `fr`, or `it`.\n This changes the language of the [3D Secure flow](https://docs.stripe.com/issuing/3d-secure) and one-time password messages sent to the cardholder.',
            'name': 'preferred_locales'},
           {'annotation': dict, 'default': None, 'description': "Rules that control spending across this cardholder's cards. Refer to our [documentation](https://docs.stripe.com/issuing/controls/spending-controls) for more details.", 'name': 'spending_controls'},
           {'annotation': str, 'default': None, 'description': "Specifies whether to permit authorizations on this cardholder's cards.", 'name': 'status'}],
  'doc_url': 'https://docs.stripe.com/api/cardholders/update',
  'op_id': 'PostIssuingCardholdersCardholder',
  'path': '/v1/issuing/cardholders/{cardholder}',
  'qparams': [],
  'summary': 'Update a cardholder',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/cards/list',
  'op_id': 'GetIssuingCards',
  'path': '/v1/issuing/cards',
  'qparams': [{'annotation': 'str', 'description': 'Only return cards belonging to the Cardholder with the provided ID.', 'name': 'cardholder'},
              {'annotation': 'str', 'description': 'Only return cards that were issued during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Only return cards that have the given expiration month.', 'name': 'exp_month'},
              {'annotation': 'str', 'description': 'Only return cards that have the given expiration year.', 'name': 'exp_year'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return cards that have the given last four digits.', 'name': 'last4'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': '', 'name': 'personalization_design'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return cards that have the given status. One of `active`, `inactive`, or `canceled`.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Only return cards that have the given type. One of `virtual` or `physical`.', 'name': 'type'}],
  'summary': 'List all cards',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The [Cardholder](https://docs.stripe.com/api#issuing_cardholder_object) object with which the card will be associated.', 'name': 'cardholder'},
           {'annotation': str, 'default': None, 'description': 'The currency for the card.', 'name': 'currency'},
           {'annotation': int, 'default': None, 'description': 'The desired expiration month (1-12) for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).', 'name': 'exp_month'},
           {'annotation': int, 'default': None, 'description': 'The desired 4-digit expiration year for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).', 'name': 'exp_year'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.', 'name': 'financial_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The personalization design object belonging to this card.', 'name': 'personalization_design'},
           {'annotation': dict, 'default': None, 'description': 'The desired PIN for this card.', 'name': 'pin'},
           {'annotation': str, 'default': None, 'description': 'The card this is meant to be a replacement for (if any).', 'name': 'replacement_for'},
           {'annotation': str, 'default': None, 'description': 'If `replacement_for` is specified, this should indicate why that card is being replaced.', 'name': 'replacement_reason'},
           {'annotation': object, 'default': None, 'description': 'The second line to print on the card. Max length: 24 characters.', 'name': 'second_line'},
           {'annotation': dict, 'default': None, 'description': 'The address where the card will be shipped.', 'name': 'shipping'},
           {'annotation': dict, 'default': None, 'description': 'Rules that control spending for this card. Refer to our [documentation](https://docs.stripe.com/issuing/controls/spending-controls) for more details.', 'name': 'spending_controls'},
           {'annotation': str, 'default': None, 'description': 'Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to `inactive`.', 'name': 'status'},
           {'annotation': str, 'default': None, 'description': 'The type of card to issue. Possible values are `physical` or `virtual`.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/cards/create',
  'op_id': 'PostIssuingCards',
  'path': '/v1/issuing/cards',
  'qparams': [],
  'summary': 'Create a card',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/cards/delete', 'op_id': 'GetIssuingCardsCard', 'path': '/v1/issuing/cards/{card}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a card', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'Reason why the `status` of this card is `canceled`.', 'name': 'cancellation_reason'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': '', 'name': 'personalization_design'},
           {'annotation': dict, 'default': None, 'description': 'The desired new PIN for this card.', 'name': 'pin'},
           {'annotation': dict, 'default': None, 'description': 'Updated shipping information for the card.', 'name': 'shipping'},
           {'annotation': dict, 'default': None, 'description': 'Rules that control spending for this card. Refer to our [documentation](https://docs.stripe.com/issuing/controls/spending-controls) for more details.', 'name': 'spending_controls'},
           {'annotation': str,
            'default': None,
            'description': 'Dictates whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to `inactive`. If this card is being canceled because it was lost or stolen, this information should be provided as `cancellation_reason`.',
            'name': 'status'}],
  'doc_url': 'https://docs.stripe.com/api/cards/update',
  'op_id': 'PostIssuingCardsCard',
  'path': '/v1/issuing/cards/{card}',
  'qparams': [],
  'summary': 'Update a card',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/disputes/list',
  'op_id': 'GetIssuingDisputes',
  'path': '/v1/issuing/disputes',
  'qparams': [{'annotation': 'str', 'description': 'Only return Issuing disputes that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Select Issuing disputes with the given status.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Select the Issuing dispute for the given transaction.', 'name': 'transaction'}],
  'summary': 'List all disputes',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': "The dispute amount in the card's currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal). If not set, defaults to the full transaction amount.", 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Evidence provided for the dispute.', 'name': 'evidence'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The ID of the issuing transaction to create a dispute for. For transaction on Treasury FinancialAccounts, use `treasury.received_debit`.', 'name': 'transaction'},
           {'annotation': dict, 'default': None, 'description': 'Params for disputes related to Treasury FinancialAccounts', 'name': 'treasury'}],
  'doc_url': 'https://docs.stripe.com/api/disputes/create',
  'op_id': 'PostIssuingDisputes',
  'path': '/v1/issuing/disputes',
  'qparams': [],
  'summary': 'Create a dispute',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/disputes/delete', 'op_id': 'GetIssuingDisputesDispute', 'path': '/v1/issuing/disputes/{dispute}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a dispute', 'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': "The dispute amount in the card's currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).", 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Evidence provided for the dispute.', 'name': 'evidence'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/disputes/update',
  'op_id': 'PostIssuingDisputesDispute',
  'path': '/v1/issuing/disputes/{dispute}',
  'qparams': [],
  'summary': 'Update a dispute',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/submits/update',
  'op_id': 'PostIssuingDisputesDisputeSubmit',
  'path': '/v1/issuing/disputes/{dispute}/submit',
  'qparams': [],
  'summary': 'Submit a dispute',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/personalization_designs/list',
  'op_id': 'GetIssuingPersonalizationDesigns',
  'path': '/v1/issuing/personalization_designs',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return personalization designs with the given lookup keys.', 'name': 'lookup_keys'},
              {'annotation': 'str', 'description': 'Only return personalization designs with the given preferences.', 'name': 'preferences'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return personalization designs with the given status.', 'name': 'status'}],
  'summary': 'List all personalization designs',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The file for the card logo, for use with physical bundles that support card logos. Must have a `purpose` value of `issuing_logo`.', 'name': 'card_logo'},
           {'annotation': dict, 'default': None, 'description': 'Hash containing carrier text, for use with physical bundles that support carrier text.', 'name': 'carrier_text'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.', 'name': 'lookup_key'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Friendly display name.', 'name': 'name'},
           {'annotation': str, 'default': None, 'description': 'The physical bundle object belonging to this personalization design.', 'name': 'physical_bundle'},
           {'annotation': dict, 'default': None, 'description': 'Information on whether this personalization design is used to create cards when one is not specified.', 'name': 'preferences'},
           {'annotation': bool, 'default': None, 'description': 'If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.', 'name': 'transfer_lookup_key'}],
  'doc_url': 'https://docs.stripe.com/api/personalization_designs/create',
  'op_id': 'PostIssuingPersonalizationDesigns',
  'path': '/v1/issuing/personalization_designs',
  'qparams': [],
  'summary': 'Create a personalization design',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/personalization_designs/delete',
  'op_id': 'GetIssuingPersonalizationDesignsPersonalizationDesign',
  'path': '/v1/issuing/personalization_designs/{personalization_design}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a personalization design',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'The file for the card logo, for use with physical bundles that support card logos. Must have a `purpose` value of `issuing_logo`.', 'name': 'card_logo'},
           {'annotation': object, 'default': None, 'description': 'Hash containing carrier text, for use with physical bundles that support carrier text.', 'name': 'carrier_text'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.', 'name': 'lookup_key'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'Friendly display name. Providing an empty string will set the field to null.', 'name': 'name'},
           {'annotation': str, 'default': None, 'description': 'The physical bundle object belonging to this personalization design.', 'name': 'physical_bundle'},
           {'annotation': dict, 'default': None, 'description': 'Information on whether this personalization design is used to create cards when one is not specified.', 'name': 'preferences'},
           {'annotation': bool, 'default': None, 'description': 'If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.', 'name': 'transfer_lookup_key'}],
  'doc_url': 'https://docs.stripe.com/api/personalization_designs/update',
  'op_id': 'PostIssuingPersonalizationDesignsPersonalizationDesign',
  'path': '/v1/issuing/personalization_designs/{personalization_design}',
  'qparams': [],
  'summary': 'Update a personalization design',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/physical_bundles/list',
  'op_id': 'GetIssuingPhysicalBundles',
  'path': '/v1/issuing/physical_bundles',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return physical bundles with the given status.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Only return physical bundles with the given type.', 'name': 'type'}],
  'summary': 'List all physical bundles',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/physical_bundles/delete',
  'op_id': 'GetIssuingPhysicalBundlesPhysicalBundle',
  'path': '/v1/issuing/physical_bundles/{physical_bundle}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a physical bundle',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/settlements/delete', 'op_id': 'GetIssuingSettlementsSettlement', 'path': '/v1/issuing/settlements/{settlement}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a settlement', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/settlements/update',
  'op_id': 'PostIssuingSettlementsSettlement',
  'path': '/v1/issuing/settlements/{settlement}',
  'qparams': [],
  'summary': 'Update a settlement',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/tokens/list',
  'op_id': 'GetIssuingTokens',
  'path': '/v1/issuing/tokens',
  'qparams': [{'annotation': 'str', 'description': 'The Issuing card identifier to list tokens for.', 'name': 'card'},
              {'annotation': 'str', 'description': 'Only return Issuing tokens that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Select Issuing tokens with the given status.', 'name': 'status'}],
  'summary': 'List all issuing tokens for card',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tokens/delete', 'op_id': 'GetIssuingTokensToken', 'path': '/v1/issuing/tokens/{token}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an issuing token', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': str, 'default': None, 'description': 'Specifies which status the token should be updated to.', 'name': 'status'}],
  'doc_url': 'https://docs.stripe.com/api/tokens/update',
  'op_id': 'PostIssuingTokensToken',
  'path': '/v1/issuing/tokens/{token}',
  'qparams': [],
  'summary': 'Update a token status',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transactions/list',
  'op_id': 'GetIssuingTransactions',
  'path': '/v1/issuing/transactions',
  'qparams': [{'annotation': 'str', 'description': 'Only return transactions that belong to the given card.', 'name': 'card'},
              {'annotation': 'str', 'description': 'Only return transactions that belong to the given cardholder.', 'name': 'cardholder'},
              {'annotation': 'str', 'description': 'Only return transactions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return transactions that have the given type. One of `capture` or `refund`.', 'name': 'type'}],
  'summary': 'List all transactions',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/transactions/delete', 'op_id': 'GetIssuingTransactionsTransaction', 'path': '/v1/issuing/transactions/{transaction}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a transaction', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/transactions/update',
  'op_id': 'PostIssuingTransactionsTransaction',
  'path': '/v1/issuing/transactions/{transaction}',
  'qparams': [],
  'summary': 'Update a transaction',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The account holder to link accounts for.', 'name': 'account_holder'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Filters to restrict the kinds of accounts to collect.', 'name': 'filters'},
           {'annotation': list, 'default': None, 'description': 'List of data features that you would like to request access to.\n\nPossible values are `balances`, `transactions`, `ownership`, and `payment_method`.', 'name': 'permissions'},
           {'annotation': list, 'default': None, 'description': 'List of data features that you would like to retrieve upon account creation.', 'name': 'prefetch'},
           {'annotation': str, 'default': None, 'description': 'For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.', 'name': 'return_url'}],
  'doc_url': 'https://docs.stripe.com/api/link_account_sessions/create',
  'op_id': 'PostLinkAccountSessions',
  'path': '/v1/link_account_sessions',
  'qparams': [],
  'summary': 'Create a Session',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/link_account_sessions/delete', 'op_id': 'GetLinkAccountSessionsSession', 'path': '/v1/link_account_sessions/{session}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Session', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/linked_accounts/list',
  'op_id': 'GetLinkedAccounts',
  'path': '/v1/linked_accounts',
  'qparams': [{'annotation': 'str', 'description': 'If present, only return accounts that belong to the specified account holder. `account_holder[customer]` and `account_holder[account]` are mutually exclusive.', 'name': 'account_holder'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'If present, only return accounts that were collected as part of the given session.', 'name': 'session'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Accounts',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/linked_accounts/delete', 'op_id': 'GetLinkedAccountsAccount', 'path': '/v1/linked_accounts/{account}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an Account', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/disconnects/update',
  'op_id': 'PostLinkedAccountsAccountDisconnect',
  'path': '/v1/linked_accounts/{account}/disconnect',
  'qparams': [],
  'summary': 'Disconnect an Account',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/owners/delete',
  'op_id': 'GetLinkedAccountsAccountOwners',
  'path': '/v1/linked_accounts/{account}/owners',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The ID of the ownership object to fetch owners from.', 'name': 'ownership'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Account Owners',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': list, 'default': None, 'description': 'The list of account features that you would like to refresh.', 'name': 'features'}],
  'doc_url': 'https://docs.stripe.com/api/refreshs/update',
  'op_id': 'PostLinkedAccountsAccountRefresh',
  'path': '/v1/linked_accounts/{account}/refresh',
  'qparams': [],
  'summary': 'Refresh Account data',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/mandates/delete', 'op_id': 'GetMandatesMandate', 'path': '/v1/mandates/{mandate}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Mandate', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_attempt_records/list',
  'op_id': 'GetPaymentAttemptRecords',
  'path': '/v1/payment_attempt_records',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The ID of the Payment Record.', 'name': 'payment_record'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List Payment Attempt Records',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_attempt_records/delete',
  'op_id': 'GetPaymentAttemptRecordsId',
  'path': '/v1/payment_attempt_records/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a Payment Attempt Record',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_intents/list',
  'op_id': 'GetPaymentIntents',
  'path': '/v1/payment_intents',
  'qparams': [{'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return PaymentIntents for the customer that this customer ID specifies.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return PaymentIntents for the account representing the customer that this ID specifies.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all PaymentIntents',
  'verb': 'get'},
 {'data': [{'annotation': int,
            'default': None,
            'description': 'Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge '
                           'currency](https://docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).',
            'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Provides industry-specific information about the amount.', 'name': 'amount_details'},
           {'annotation': int,
            'default': None,
            'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected "
                           'accounts](https://docs.stripe.com/payments/connected-accounts).',
            'name': 'application_fee_amount'},
           {'annotation': dict, 'default': None, 'description': "When you enable this parameter, this PaymentIntent accepts payment methods that you enable in the Dashboard and that are compatible with this PaymentIntent's other parameters.", 'name': 'automatic_payment_methods'},
           {'annotation': str, 'default': None, 'description': "Controls when the funds will be captured from the customer's account.", 'name': 'capture_method'},
           {'annotation': bool,
            'default': None,
            'description': 'Set to `true` to attempt to [confirm this PaymentIntent](https://docs.stripe.com/api/payment_intents/confirm) immediately. This parameter defaults to `false`. When creating and confirming a PaymentIntent at the same time, you can also provide the parameters available in the [Confirm '
                           'API](https://docs.stripe.com/api/payment_intents/confirm).',
            'name': 'confirm'},
           {'annotation': str, 'default': None, 'description': 'Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.', 'name': 'confirmation_method'},
           {'annotation': str, 'default': None, 'description': 'ID of the ConfirmationToken used to confirm this PaymentIntent.\n\nIf the provided ConfirmationToken contains properties that are also being provided in this request, such as `payment_method`, then the values in this request will take precedence.', 'name': 'confirmation_token'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the Customer this PaymentIntent belongs to, if one exists.\n'
                           '\n'
                           'Payment methods attached to other Customers cannot be used with this PaymentIntent.\n'
                           '\n'
                           "If [setup_future_usage](https://api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent's payment method is not `card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is "
                           "`card_present` and isn't a digital wallet, then a [generated_card](https://docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.",
            'name': 'customer'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.\n'
                           '\n'
                           'Payment methods attached to other Accounts cannot be used with this PaymentIntent.\n'
                           '\n'
                           "If [setup_future_usage](https://api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent's payment method is not `card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is "
                           "`card_present` and isn't a digital wallet, then a [generated_card](https://docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.",
            'name': 'customer_account'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': bool,
            'default': None,
            'description': "Set to `true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. Use this parameter for simpler integrations that don't handle customer actions, such as [saving cards without authentication](https://docs.stripe.com/payments/save-card-without-authentication). This parameter can only be used with "
                           '[`confirm=true`](https://docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).',
            'name': 'error_on_requires_action'},
           {'annotation': list, 'default': None, 'description': 'The list of payment method types to exclude from use with this payment.', 'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Automations to be run during the PaymentIntent lifecycle', 'name': 'hooks'},
           {'annotation': str, 'default': None, 'description': "ID of the mandate that's used for this payment. This parameter can only be used with [`confirm=true`](https://docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).", 'name': 'mandate'},
           {'annotation': object, 'default': None, 'description': 'This hash contains details about the Mandate to create. This parameter can only be used with [`confirm=true`](https://docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).', 'name': 'mandate_data'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object,
            'default': None,
            'description': "Set to `true` to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect card details and [charge them later](https://docs.stripe.com/payments/cards/charging-saved-cards). This parameter can only be used with "
                           '[`confirm=true`](https://docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).',
            'name': 'off_session'},
           {'annotation': str, 'default': None, 'description': 'The Stripe account ID that these funds are intended for. Learn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).', 'name': 'on_behalf_of'},
           {'annotation': dict, 'default': None, 'description': 'Provides industry-specific information about the charge.', 'name': 'payment_details'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the payment method (a PaymentMethod, Card, or [compatible Source](https://docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.\n'
                           '\n'
                           "If you omit this parameter with `confirm=true`, `customer.default_source` attaches as this PaymentIntent's payment instrument to improve migration for users of the Charges API. We recommend that you explicitly provide the `payment_method` moving forward.\n"
                           'If the payment method is attached to a Customer, you must also provide the ID of that Customer as the [customer](https://api.stripe.com#create_payment_intent-customer) parameter of this PaymentIntent.',
            'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [payment method configuration](https://docs.stripe.com/api/payment_method_configurations) to use with this PaymentIntent.', 'name': 'payment_method_configuration'},
           {'annotation': dict, 'default': None, 'description': 'If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear\nin the [payment_method](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method)\nproperty on the PaymentIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this PaymentIntent.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': "The list of payment method types (for example, a card) that this PaymentIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](https://dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found "
                           '[here](https://docs.stripe.com/api/payment_methods/object#payment_method_object-type).',
            'name': 'payment_method_types'},
           {'annotation': dict, 'default': None, 'description': 'Options to configure Radar. Learn more about [Radar Sessions](https://docs.stripe.com/radar/radar-session).', 'name': 'radar_options'},
           {'annotation': str, 'default': None, 'description': 'Email address to send the receipt to. If you specify `receipt_email` for a payment in live mode, you send a receipt regardless of your [email settings](https://dashboard.stripe.com/account/emails).', 'name': 'receipt_email'},
           {'annotation': str,
            'default': None,
            'description': "The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with "
                           '[`confirm=true`](https://docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).',
            'name': 'return_url'},
           {'annotation': str,
            'default': None,
            'description': "Indicates that you intend to make future payments with this PaymentIntent's payment method.\n"
                           '\n'
                           "If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still [attach](/api/payment_methods/attach) the "
                           'payment method to a Customer after the transaction completes.\n'
                           '\n'
                           "If the payment method is `card_present` and isn't a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.\n"
                           '\n'
                           'When processing card payments, Stripe uses `setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).',
            'name': 'setup_future_usage'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for this PaymentIntent.', 'name': 'shipping'},
           {'annotation': str,
            'default': None,
            'description': "Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).\n'
                           '\n'
                           'Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](https://docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.',
            'name': 'statement_descriptor'},
           {'annotation': str,
            'default': None,
            'description': "Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement.",
            'name': 'statement_descriptor_suffix'},
           {'annotation': dict, 'default': None, 'description': 'The parameters that you can use to automatically create a Transfer.\nLearn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).', 'name': 'transfer_data'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](https://docs.stripe.com/connect/separate-charges-and-transfers).', 'name': 'transfer_group'},
           {'annotation': bool, 'default': None, 'description': 'Set to `true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.', 'name': 'use_stripe_sdk'}],
  'doc_url': 'https://docs.stripe.com/api/payment_intents/create',
  'op_id': 'PostPaymentIntents',
  'path': '/v1/payment_intents',
  'qparams': [],
  'summary': 'Create a PaymentIntent',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetPaymentIntentsSearch',
  'path': '/v1/payment_intents/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for payment intents](https://docs.stripe.com/search#query-fields-for-payment-intents).', 'name': 'query'}],
  'summary': 'Search PaymentIntents',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_intents/delete',
  'op_id': 'GetPaymentIntentsIntent',
  'path': '/v1/payment_intents/{intent}',
  'qparams': [{'annotation': 'str', 'description': 'The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.', 'name': 'client_secret'}, {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a PaymentIntent',
  'verb': 'get'},
 {'data': [{'annotation': int,
            'default': None,
            'description': 'Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge '
                           'currency](https://docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).',
            'name': 'amount'},
           {'annotation': object, 'default': None, 'description': 'Provides industry-specific information about the amount.', 'name': 'amount_details'},
           {'annotation': object,
            'default': None,
            'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected "
                           'accounts](https://docs.stripe.com/payments/connected-accounts).',
            'name': 'application_fee_amount'},
           {'annotation': str, 'default': None, 'description': "Controls when the funds will be captured from the customer's account.", 'name': 'capture_method'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the Customer this PaymentIntent belongs to, if one exists.\n'
                           '\n'
                           'Payment methods attached to other Customers cannot be used with this PaymentIntent.\n'
                           '\n'
                           "If [setup_future_usage](https://api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent's payment method is not `card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is "
                           "`card_present` and isn't a digital wallet, then a [generated_card](https://docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.",
            'name': 'customer'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.\n'
                           '\n'
                           'Payment methods attached to other Accounts cannot be used with this PaymentIntent.\n'
                           '\n'
                           "If [setup_future_usage](https://api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent's payment method is not `card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is "
                           "`card_present` and isn't a digital wallet, then a [generated_card](https://docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.",
            'name': 'customer_account'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': object, 'default': None, 'description': 'The list of payment method types to exclude from use with this payment.', 'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Automations to be run during the PaymentIntent lifecycle', 'name': 'hooks'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'Provides industry-specific information about the charge.', 'name': 'payment_details'},
           {'annotation': str, 'default': None, 'description': 'ID of the payment method (a PaymentMethod, Card, or [compatible Source](https://docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. To unset this field to null, pass in an empty string.', 'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [payment method configuration](https://docs.stripe.com/api/payment_method_configurations) to use with this PaymentIntent.', 'name': 'payment_method_configuration'},
           {'annotation': dict, 'default': None, 'description': 'If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear\nin the [payment_method](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method)\nproperty on the PaymentIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment-method-specific configuration for this PaymentIntent.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': 'The list of payment method types (for example, card) that this PaymentIntent can use. Use `automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](https://dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found '
                           '[here](https://docs.stripe.com/api/payment_methods/object#payment_method_object-type).',
            'name': 'payment_method_types'},
           {'annotation': object, 'default': None, 'description': 'Email address that the receipt for the resulting payment will be sent to. If `receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](https://dashboard.stripe.com/account/emails).', 'name': 'receipt_email'},
           {'annotation': str,
            'default': None,
            'description': "Indicates that you intend to make future payments with this PaymentIntent's payment method.\n"
                           '\n'
                           "If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still [attach](/api/payment_methods/attach) the "
                           'payment method to a Customer after the transaction completes.\n'
                           '\n'
                           "If the payment method is `card_present` and isn't a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.\n"
                           '\n'
                           'When processing card payments, Stripe uses `setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).\n'
                           '\n'
                           "If you've already set `setup_future_usage` and you're performing a request using a publishable key, you can only update the value from `on_session` to `off_session`.",
            'name': 'setup_future_usage'},
           {'annotation': object, 'default': None, 'description': 'Shipping information for this PaymentIntent.', 'name': 'shipping'},
           {'annotation': str,
            'default': None,
            'description': "Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).\n'
                           '\n'
                           'Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](https://docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.',
            'name': 'statement_descriptor'},
           {'annotation': str,
            'default': None,
            'description': "Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement.",
            'name': 'statement_descriptor_suffix'},
           {'annotation': dict, 'default': None, 'description': 'Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).', 'name': 'transfer_data'},
           {'annotation': str, 'default': None, 'description': "A string that identifies the resulting payment as part of a group. You can only provide `transfer_group` if it hasn't been set. Learn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).", 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/payment_intents/update',
  'op_id': 'PostPaymentIntentsIntent',
  'path': '/v1/payment_intents/{intent}',
  'qparams': [],
  'summary': 'Update a PaymentIntent',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/amount_details_line_items/delete',
  'op_id': 'GetPaymentIntentsIntentAmountDetailsLineItems',
  'path': '/v1/payment_intents/{intent}/amount_details_line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all PaymentIntent LineItems',
  'verb': 'get'},
 {'data': [{'annotation': int,
            'default': None,
            'description': 'Amount that you intend to apply to this PaymentIntent from the customer’s cash balance. If the PaymentIntent was created by an Invoice, the full amount of the PaymentIntent is applied regardless of this parameter.\n'
                           '\n'
                           'A positive integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) (for example, 100 cents to charge 1 USD or 100 to charge 100 JPY, a zero-decimal currency). The maximum amount is the amount of the PaymentIntent.\n'
                           '\n'
                           'When you omit the amount, it defaults to the remaining amount requested on the PaymentIntent.',
            'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/apply_customer_balances/update',
  'op_id': 'PostPaymentIntentsIntentApplyCustomerBalance',
  'path': '/v1/payment_intents/{intent}/apply_customer_balance',
  'qparams': [],
  'summary': 'Reconcile a customer_balance PaymentIntent',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'Reason for canceling this PaymentIntent. Possible values are: `duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`', 'name': 'cancellation_reason'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostPaymentIntentsIntentCancel',
  'path': '/v1/payment_intents/{intent}/cancel',
  'qparams': [],
  'summary': 'Cancel a PaymentIntent',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Provides industry-specific information about the amount.', 'name': 'amount_details'},
           {'annotation': int, 'default': None, 'description': "The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full `amount_capturable` if it's not provided.", 'name': 'amount_to_capture'},
           {'annotation': int,
            'default': None,
            'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected "
                           'accounts](https://docs.stripe.com/payments/connected-accounts).',
            'name': 'application_fee_amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool,
            'default': None,
            'description': "Defaults to `true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they're captured in future requests. You can only use this setting when [multicapture](https://docs.stripe.com/payments/multicapture) is available for "
                           'PaymentIntents.',
            'name': 'final_capture'},
           {'annotation': dict, 'default': None, 'description': 'Automations to be run during the PaymentIntent lifecycle', 'name': 'hooks'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'Provides industry-specific information about the charge.', 'name': 'payment_details'},
           {'annotation': str,
            'default': None,
            'description': "Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).\n'
                           '\n'
                           'Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](https://docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.',
            'name': 'statement_descriptor'},
           {'annotation': str,
            'default': None,
            'description': "Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement.",
            'name': 'statement_descriptor_suffix'},
           {'annotation': dict, 'default': None, 'description': 'The parameters that you can use to automatically create a transfer after the payment\nis captured. Learn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).', 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/captures/update',
  'op_id': 'PostPaymentIntentsIntentCapture',
  'path': '/v1/payment_intents/{intent}/capture',
  'qparams': [],
  'summary': 'Capture a PaymentIntent',
  'verb': 'post'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Provides industry-specific information about the amount.', 'name': 'amount_details'},
           {'annotation': str, 'default': None, 'description': "Controls when the funds will be captured from the customer's account.", 'name': 'capture_method'},
           {'annotation': str, 'default': None, 'description': 'The client secret of the PaymentIntent.', 'name': 'client_secret'},
           {'annotation': str, 'default': None, 'description': 'ID of the ConfirmationToken used to confirm this PaymentIntent.\n\nIf the provided ConfirmationToken contains properties that are also being provided in this request, such as `payment_method`, then the values in this request will take precedence.', 'name': 'confirmation_token'},
           {'annotation': bool,
            'default': None,
            'description': 'Set to `true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](https://docs.stripe.com/payments/save-card-without-authentication).',
            'name': 'error_on_requires_action'},
           {'annotation': object, 'default': None, 'description': 'The list of payment method types to exclude from use with this payment.', 'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Automations to be run during the PaymentIntent lifecycle', 'name': 'hooks'},
           {'annotation': str, 'default': None, 'description': "ID of the mandate that's used for this payment.", 'name': 'mandate'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'mandate_data'},
           {'annotation': object,
            'default': None,
            'description': "Set to `true` to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect card details and [charge them later](https://docs.stripe.com/payments/cards/charging-saved-cards).",
            'name': 'off_session'},
           {'annotation': object, 'default': None, 'description': 'Provides industry-specific information about the charge.', 'name': 'payment_details'},
           {'annotation': str,
            'default': None,
            'description': 'ID of the payment method (a PaymentMethod, Card, or [compatible Source](https://docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.\n'
                           'If the payment method is attached to a Customer, it must match the [customer](https://api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.',
            'name': 'payment_method'},
           {'annotation': dict, 'default': None, 'description': 'If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear\nin the [payment_method](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method)\nproperty on the PaymentIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this PaymentIntent.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': 'The list of payment method types (for example, a card) that this PaymentIntent can use. Use `automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](https://dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found '
                           '[here](https://docs.stripe.com/api/payment_methods/object#payment_method_object-type).',
            'name': 'payment_method_types'},
           {'annotation': dict, 'default': None, 'description': 'Options to configure Radar. Learn more about [Radar Sessions](https://docs.stripe.com/radar/radar-session).', 'name': 'radar_options'},
           {'annotation': object, 'default': None, 'description': 'Email address that the receipt for the resulting payment will be sent to. If `receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](https://dashboard.stripe.com/account/emails).', 'name': 'receipt_email'},
           {'annotation': str,
            'default': None,
            'description': "The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site.\nIf you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.\nThis parameter is only used for cards and other redirect-based payment methods.",
            'name': 'return_url'},
           {'annotation': str,
            'default': None,
            'description': "Indicates that you intend to make future payments with this PaymentIntent's payment method.\n"
                           '\n'
                           "If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still [attach](/api/payment_methods/attach) the "
                           'payment method to a Customer after the transaction completes.\n'
                           '\n'
                           "If the payment method is `card_present` and isn't a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.\n"
                           '\n'
                           'When processing card payments, Stripe uses `setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).\n'
                           '\n'
                           "If you've already set `setup_future_usage` and you're performing a request using a publishable key, you can only update the value from `on_session` to `off_session`.",
            'name': 'setup_future_usage'},
           {'annotation': object, 'default': None, 'description': 'Shipping information for this PaymentIntent.', 'name': 'shipping'},
           {'annotation': bool, 'default': None, 'description': 'Set to `true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.', 'name': 'use_stripe_sdk'}],
  'doc_url': 'https://docs.stripe.com/api/confirms/update',
  'op_id': 'PostPaymentIntentsIntentConfirm',
  'path': '/v1/payment_intents/{intent}/confirm',
  'qparams': [],
  'summary': 'Confirm a PaymentIntent',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.', 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Provides industry-specific information about the amount.', 'name': 'amount_details'},
           {'annotation': int,
            'default': None,
            'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected "
                           'accounts](https://docs.stripe.com/payments/connected-accounts).',
            'name': 'application_fee_amount'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Automations to be run during the PaymentIntent lifecycle', 'name': 'hooks'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Provides industry-specific information about the charge.', 'name': 'payment_details'},
           {'annotation': str,
            'default': None,
            'description': "Text that appears on the customer's statement as the statement descriptor for a non-card or card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor "
                           'docs](https://docs.stripe.com/get-started/account/statement-descriptors).',
            'name': 'statement_descriptor'},
           {'annotation': dict, 'default': None, 'description': 'The parameters used to automatically create a transfer after the payment is captured.\nLearn more about the [use case for connected accounts](https://docs.stripe.com/payments/connected-accounts).', 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/increment_authorizations/update',
  'op_id': 'PostPaymentIntentsIntentIncrementAuthorization',
  'path': '/v1/payment_intents/{intent}/increment_authorization',
  'qparams': [],
  'summary': 'Increment an authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Two positive integers, in *cents*, equal to the values of the microdeposits sent to the bank account.', 'name': 'amounts'},
           {'annotation': str, 'default': None, 'description': 'The client secret of the PaymentIntent.', 'name': 'client_secret'},
           {'annotation': str, 'default': None, 'description': 'A six-character code starting with SM present in the microdeposit sent to the bank account.', 'name': 'descriptor_code'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/verify_microdeposits/update',
  'op_id': 'PostPaymentIntentsIntentVerifyMicrodeposits',
  'path': '/v1/payment_intents/{intent}/verify_microdeposits',
  'qparams': [],
  'summary': 'Verify microdeposits on a PaymentIntent',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_links/list',
  'op_id': 'GetPaymentLinks',
  'path': '/v1/payment_links',
  'qparams': [{'annotation': 'str', 'description': 'Only return payment links that are active or inactive (e.g., pass `false` to list all inactive payment links).', 'name': 'active'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all payment links',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Behavior after the purchase is complete.', 'name': 'after_completion'},
           {'annotation': bool, 'default': None, 'description': 'Enables user redeemable promotion codes.', 'name': 'allow_promotion_codes'},
           {'annotation': int, 'default': None, 'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. Can only be applied when there are no line items with recurring prices.", 'name': 'application_fee_amount'},
           {'annotation': int,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.",
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Configuration for automatic tax collection.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': "Configuration for collecting the customer's billing address. Defaults to `auto`.", 'name': 'billing_address_collection'},
           {'annotation': dict, 'default': None, 'description': 'Configure fields to gather active consent from customers.', 'name': 'consent_collection'},
           {'annotation': str, 'default': None, 'description': "Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies) and supported by each line item's price.", 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': "Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_fields'},
           {'annotation': dict, 'default': None, 'description': "Display additional text for your customers using custom text. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_text'},
           {'annotation': str, 'default': None, 'description': 'Configures whether [checkout sessions](https://docs.stripe.com/api/checkout/sessions) created by this payment link create a [Customer](https://docs.stripe.com/api/customers).', 'name': 'customer_creation'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The custom message to be displayed to a customer when a payment link is no longer active.', 'name': 'inactive_message'},
           {'annotation': dict, 'default': None, 'description': 'Generate a post-purchase Invoice for one-time payments.', 'name': 'invoice_creation'},
           {'annotation': list, 'default': None, 'description': 'The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.', 'name': 'line_items'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`. Metadata '
                           'associated with this Payment Link will automatically be copied to [checkout sessions](https://docs.stripe.com/api/checkout/sessions) created by this payment link.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': "Controls settings applied for collecting the customer's name.", 'name': 'name_collection'},
           {'annotation': str, 'default': None, 'description': 'The account on behalf of which to charge.', 'name': 'on_behalf_of'},
           {'annotation': list,
            'default': None,
            'description': 'A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring [Prices](https://docs.stripe.com/api/prices).\n'
                           'There is a maximum of 10 optional items allowed on a payment link, and the existing limits on the number of line items allowed on a payment link apply to the combined number of line items and optional items.\n'
                           'There is a maximum of 20 combined line items and optional items.',
            'name': 'optional_items'},
           {'annotation': dict, 'default': None, 'description': 'A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in `payment` mode.', 'name': 'payment_intent_data'},
           {'annotation': str,
            'default': None,
            'description': 'Specify whether Checkout should collect a payment method. When set to `if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.\n'
                           '\n'
                           'Can only be set in `subscription` mode. Defaults to `always`.\n'
                           '\n'
                           "If you'd like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](https://docs.stripe.com/payments/checkout/free-trials).",
            'name': 'payment_method_collection'},
           {'annotation': list,
            'default': None,
            'description': 'The list of payment method types that customers can use. If no value is passed, Stripe will dynamically show relevant payment methods from your [payment method settings](https://dashboard.stripe.com/settings/payment_methods) (20+ payment methods '
                           '[supported](https://docs.stripe.com/payments/payment-methods/integration-options#payment-method-product-support)).',
            'name': 'payment_method_types'},
           {'annotation': dict, 'default': None, 'description': 'Controls phone number collection settings during checkout.\n\nWe recommend that you review your privacy policy and check with your legal contacts.', 'name': 'phone_number_collection'},
           {'annotation': dict, 'default': None, 'description': 'Settings that restrict the usage of a payment link.', 'name': 'restrictions'},
           {'annotation': dict, 'default': None, 'description': "Configuration for collecting the customer's shipping address.", 'name': 'shipping_address_collection'},
           {'annotation': list, 'default': None, 'description': 'The shipping rate options to apply to [checkout sessions](https://docs.stripe.com/api/checkout/sessions) created by this payment link.', 'name': 'shipping_options'},
           {'annotation': str,
            'default': None,
            'description': 'Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](https://docs.stripe.com/api/payment_links/payment_links/object#url) property (example: `donate.stripe.com`).',
            'name': 'submit_type'},
           {'annotation': dict, 'default': None, 'description': 'When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use `subscription_data`.', 'name': 'subscription_data'},
           {'annotation': dict, 'default': None, 'description': 'Controls tax ID collection during checkout.', 'name': 'tax_id_collection'},
           {'annotation': dict, 'default': None, 'description': 'The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.', 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/payment_links/create',
  'op_id': 'PostPaymentLinks',
  'path': '/v1/payment_links',
  'qparams': [],
  'summary': 'Create a payment link',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/payment_links/delete', 'op_id': 'GetPaymentLinksPaymentLink', 'path': '/v1/payment_links/{payment_link}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve payment link', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': "Whether the payment link's `url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.", 'name': 'active'},
           {'annotation': dict, 'default': None, 'description': 'Behavior after the purchase is complete.', 'name': 'after_completion'},
           {'annotation': bool, 'default': None, 'description': 'Enables user redeemable promotion codes.', 'name': 'allow_promotion_codes'},
           {'annotation': dict, 'default': None, 'description': 'Configuration for automatic tax collection.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': "Configuration for collecting the customer's billing address. Defaults to `auto`.", 'name': 'billing_address_collection'},
           {'annotation': object, 'default': None, 'description': "Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_fields'},
           {'annotation': dict, 'default': None, 'description': "Display additional text for your customers using custom text. You can't set this parameter if `ui_mode` is `custom`.", 'name': 'custom_text'},
           {'annotation': str, 'default': None, 'description': 'Configures whether [checkout sessions](https://docs.stripe.com/api/checkout/sessions) created by this payment link create a [Customer](https://docs.stripe.com/api/customers).', 'name': 'customer_creation'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'The custom message to be displayed to a customer when a payment link is no longer active.', 'name': 'inactive_message'},
           {'annotation': dict, 'default': None, 'description': 'Generate a post-purchase Invoice for one-time payments.', 'name': 'invoice_creation'},
           {'annotation': list, 'default': None, 'description': 'The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.', 'name': 'line_items'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`. Metadata '
                           'associated with this Payment Link will automatically be copied to [checkout sessions](https://docs.stripe.com/api/checkout/sessions) created by this payment link.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': "Controls settings applied for collecting the customer's name.", 'name': 'name_collection'},
           {'annotation': dict, 'default': None, 'description': 'A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in `payment` mode.', 'name': 'payment_intent_data'},
           {'annotation': str,
            'default': None,
            'description': 'Specify whether Checkout should collect a payment method. When set to `if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.\n'
                           '\n'
                           'Can only be set in `subscription` mode. Defaults to `always`.\n'
                           '\n'
                           "If you'd like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](https://docs.stripe.com/payments/checkout/free-trials).",
            'name': 'payment_method_collection'},
           {'annotation': object, 'default': None, 'description': 'The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](https://dashboard.stripe.com/settings/payment_methods).', 'name': 'payment_method_types'},
           {'annotation': dict, 'default': None, 'description': 'Controls phone number collection settings during checkout.\n\nWe recommend that you review your privacy policy and check with your legal contacts.', 'name': 'phone_number_collection'},
           {'annotation': object, 'default': None, 'description': 'Settings that restrict the usage of a payment link.', 'name': 'restrictions'},
           {'annotation': object, 'default': None, 'description': "Configuration for collecting the customer's shipping address.", 'name': 'shipping_address_collection'},
           {'annotation': str,
            'default': None,
            'description': 'Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](https://docs.stripe.com/api/payment_links/payment_links/object#url) property (example: `donate.stripe.com`).',
            'name': 'submit_type'},
           {'annotation': dict, 'default': None, 'description': 'When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use `subscription_data`.', 'name': 'subscription_data'},
           {'annotation': dict, 'default': None, 'description': 'Controls tax ID collection during checkout.', 'name': 'tax_id_collection'}],
  'doc_url': 'https://docs.stripe.com/api/payment_links/update',
  'op_id': 'PostPaymentLinksPaymentLink',
  'path': '/v1/payment_links/{payment_link}',
  'qparams': [],
  'summary': 'Update a payment link',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/line_items/delete',
  'op_id': 'GetPaymentLinksPaymentLinkLineItems',
  'path': '/v1/payment_links/{payment_link}/line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a payment link's line items",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_method_configurations/list',
  'op_id': 'GetPaymentMethodConfigurations',
  'path': '/v1/payment_method_configurations',
  'qparams': [{'annotation': 'str', 'description': 'The Connect application to filter by.', 'name': 'application'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List payment method configurations',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Canadian pre-authorized debit payments, check this [page](https://docs.stripe.com/payments/acss-debit) for more details like country availability.', 'name': 'acss_debit'},
           {'annotation': dict,
            'default': None,
            'description': '[Affirm](https://www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](https://docs.stripe.com/payments/affirm) for '
                           'more details like country availability.',
            'name': 'affirm'},
           {'annotation': dict,
            'default': None,
            'description': 'Afterpay gives your customers a way to pay for purchases in installments, check this [page](https://docs.stripe.com/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.',
            'name': 'afterpay_clearpay'},
           {'annotation': dict,
            'default': None,
            'description': "Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer's login credentials. Check this "
                           '[page](https://docs.stripe.com/payments/alipay) for more details.',
            'name': 'alipay'},
           {'annotation': dict, 'default': None, 'description': 'Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.', 'name': 'alma'},
           {'annotation': dict, 'default': None, 'description': 'Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.', 'name': 'amazon_pay'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users can accept [Apple Pay](https://stripe.com/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](https://stripe.com/pricing) is the same as other card transactions. Check '
                           'this [page](https://docs.stripe.com/apple-pay) for more details.',
            'name': 'apple_pay'},
           {'annotation': dict, 'default': None, 'description': 'Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.', 'name': 'apple_pay_later'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](https://docs.stripe.com/payments/au-becs-debit) for more details.', 'name': 'au_becs_debit'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](https://docs.stripe.com/payments/payment-methods/bacs-debit) for more details.', 'name': 'bacs_debit'},
           {'annotation': dict,
            'default': None,
            'description': 'Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](https://docs.stripe.com/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this '
                           '[page](https://docs.stripe.com/payments/bancontact) for more details.',
            'name': 'bancontact'},
           {'annotation': dict,
            'default': None,
            'description': 'Billie is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate '
                           'notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.',
            'name': 'billie'},
           {'annotation': dict,
            'default': None,
            'description': 'BLIK is a [single use](https://docs.stripe.com/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this '
                           '[page](https://docs.stripe.com/payments/blik) for more details.',
            'name': 'blik'},
           {'annotation': dict, 'default': None, 'description': 'Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](https://docs.stripe.com/payments/boleto) for more details.', 'name': 'boleto'},
           {'annotation': dict, 'default': None, 'description': 'Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.', 'name': 'card'},
           {'annotation': dict,
            'default': None,
            'description': "Cartes Bancaires is France's local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](https://docs.stripe.com/payments/cartes-bancaires) for more details.",
            'name': 'cartes_bancaires'},
           {'annotation': dict, 'default': None, 'description': 'Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](https://docs.stripe.com/payments/cash-app-pay) for more details.', 'name': 'cashapp'},
           {'annotation': dict, 'default': None, 'description': '[Stablecoin payments](https://docs.stripe.com/payments/stablecoin-payments) enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.', 'name': 'crypto'},
           {'annotation': dict, 'default': None, 'description': 'Uses a customer’s [cash balance](https://docs.stripe.com/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](https://docs.stripe.com/payments/bank-transfers) for more details.', 'name': 'customer_balance'},
           {'annotation': dict,
            'default': None,
            'description': 'EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](https://docs.stripe.com/payments/eps) for more details.',
            'name': 'eps'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It '
                           'is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](https://docs.stripe.com/payments/fpx) for more details.',
            'name': 'fpx'},
           {'annotation': dict,
            'default': None,
            'description': 'Meal vouchers in France, or “titres-restaurant”, is a local benefits program commonly offered by employers for their employees to purchase prepared food and beverages on working days. Check this [page](https://docs.stripe.com/payments/meal-vouchers/fr-meal-vouchers) for more details.',
            'name': 'fr_meal_voucher_conecs'},
           {'annotation': dict,
            'default': None,
            'description': 'giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. '
                           'giropay accounts for 10% of online checkouts in Germany. Check this [page](https://docs.stripe.com/payments/giropay) for more details.',
            'name': 'giropay'},
           {'annotation': dict,
            'default': None,
            'description': "Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer's Google account. Check this "
                           '[page](https://docs.stripe.com/google-pay) for more details.',
            'name': 'google_pay'},
           {'annotation': dict, 'default': None, 'description': 'GrabPay is a payment method developed by [Grab](https://www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](https://docs.stripe.com/payments/grabpay) for more details.', 'name': 'grabpay'},
           {'annotation': dict,
            'default': None,
            'description': 'iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check '
                           'this [page](https://docs.stripe.com/payments/ideal) for more details.',
            'name': 'ideal'},
           {'annotation': dict,
            'default': None,
            'description': 'JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this '
                           '[page](https://support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.',
            'name': 'jcb'},
           {'annotation': dict, 'default': None, 'description': 'Kakao Pay is a popular local wallet available in South Korea.', 'name': 'kakao_pay'},
           {'annotation': dict,
            'default': None,
            'description': "Klarna gives customers a range of [payment options](https://docs.stripe.com/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer's billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check "
                           'this [page](https://docs.stripe.com/payments/klarna) for more details.',
            'name': 'klarna'},
           {'annotation': dict, 'default': None, 'description': 'Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](https://docs.stripe.com/payments/konbini) for more details.', 'name': 'konbini'},
           {'annotation': dict, 'default': None, 'description': 'Korean cards let users pay using locally issued cards from South Korea.', 'name': 'kr_card'},
           {'annotation': dict, 'default': None, 'description': '[Link](https://docs.stripe.com/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.', 'name': 'link'},
           {'annotation': dict, 'default': None, 'description': 'MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this [page](https://docs.stripe.com/payments/mb-way) for more details.', 'name': 'mb_way'},
           {'annotation': dict,
            'default': None,
            'description': 'MobilePay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](https://docs.stripe.com/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this '
                           '[page](https://docs.stripe.com/payments/mobilepay) for more details.',
            'name': 'mobilepay'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](https://stripe.com/docs/sources)—a single integration path for creating payments using any supported method.', 'name': 'multibanco'},
           {'annotation': str, 'default': None, 'description': 'Configuration name.', 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': 'Naver Pay is a popular local wallet available in South Korea.', 'name': 'naver_pay'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](https://docs.stripe.com/payments/nz-bank-account) for more details.', 'name': 'nz_bank_account'},
           {'annotation': dict,
            'default': None,
            'description': 'OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](https://docs.stripe.com/payments/oxxo) for more details.',
            'name': 'oxxo'},
           {'annotation': dict,
            'default': None,
            'description': 'Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this '
                           '[page](https://docs.stripe.com/payments/p24) for more details.',
            'name': 'p24'},
           {'annotation': str, 'default': None, 'description': "Configuration's parent configuration. Specify to create a child configuration.", 'name': 'parent'},
           {'annotation': dict,
            'default': None,
            'description': 'Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.',
            'name': 'pay_by_bank'},
           {'annotation': dict, 'default': None, 'description': 'PAYCO is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.', 'name': 'payco'},
           {'annotation': dict, 'default': None, 'description': 'PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](https://docs.stripe.com/payments/paynow) for more details.', 'name': 'paynow'},
           {'annotation': dict, 'default': None, 'description': 'PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](https://docs.stripe.com/payments/paypal) for more details.', 'name': 'paypal'},
           {'annotation': dict,
            'default': None,
            'description': 'PayTo is a [real-time](https://docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](https://docs.stripe.com/payments/payto) for more details.',
            'name': 'payto'},
           {'annotation': dict, 'default': None, 'description': 'Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this [page](https://docs.stripe.com/payments/pix) for more details.', 'name': 'pix'},
           {'annotation': dict, 'default': None, 'description': 'PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](https://docs.stripe.com/payments/promptpay) for more details.', 'name': 'promptpay'},
           {'annotation': dict, 'default': None, 'description': 'Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.', 'name': 'revolut_pay'},
           {'annotation': dict, 'default': None, 'description': 'Samsung Pay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.', 'name': 'samsung_pay'},
           {'annotation': dict,
            'default': None,
            'description': 'Satispay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your '
                           'website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.',
            'name': 'satispay'},
           {'annotation': dict,
            'default': None,
            'description': 'The [Single Euro Payments Area (SEPA)](https://en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA '
                           'region, check this [page](https://docs.stripe.com/payments/sepa-debit) for more details.',
            'name': 'sepa_debit'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users in Europe and the United States can use the [Payment Intents API](https://stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](https://www.sofort.com/) payments from customers. Check this '
                           '[page](https://docs.stripe.com/payments/sofort) for more details.',
            'name': 'sofort'},
           {'annotation': dict,
            'default': None,
            'description': 'Swish is a [real-time](https://docs.stripe.com/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](https://docs.stripe.com/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this '
                           '[page](https://docs.stripe.com/payments/swish) for more details.',
            'name': 'swish'},
           {'annotation': dict, 'default': None, 'description': 'Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](https://docs.stripe.com/payments/twint) for more details.', 'name': 'twint'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](https://docs.stripe.com/payments/ach-direct-debit) for more details.',
            'name': 'us_bank_account'},
           {'annotation': dict,
            'default': None,
            'description': "WeChat, owned by Tencent, is China's leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses' apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this "
                           '[page](https://docs.stripe.com/payments/wechat-pay) for more details.',
            'name': 'wechat_pay'},
           {'annotation': dict, 'default': None, 'description': 'Zip gives your customers a way to split purchases over a series of payments. Check this [page](https://docs.stripe.com/payments/zip) for more details like country availability.', 'name': 'zip'}],
  'doc_url': 'https://docs.stripe.com/api/payment_method_configurations/create',
  'op_id': 'PostPaymentMethodConfigurations',
  'path': '/v1/payment_method_configurations',
  'qparams': [],
  'summary': 'Create a payment method configuration',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_method_configurations/delete',
  'op_id': 'GetPaymentMethodConfigurationsConfiguration',
  'path': '/v1/payment_method_configurations/{configuration}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve payment method configuration',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Canadian pre-authorized debit payments, check this [page](https://docs.stripe.com/payments/acss-debit) for more details like country availability.', 'name': 'acss_debit'},
           {'annotation': bool, 'default': None, 'description': 'Whether the configuration can be used for new payments.', 'name': 'active'},
           {'annotation': dict,
            'default': None,
            'description': '[Affirm](https://www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](https://docs.stripe.com/payments/affirm) for '
                           'more details like country availability.',
            'name': 'affirm'},
           {'annotation': dict,
            'default': None,
            'description': 'Afterpay gives your customers a way to pay for purchases in installments, check this [page](https://docs.stripe.com/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.',
            'name': 'afterpay_clearpay'},
           {'annotation': dict,
            'default': None,
            'description': "Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer's login credentials. Check this "
                           '[page](https://docs.stripe.com/payments/alipay) for more details.',
            'name': 'alipay'},
           {'annotation': dict, 'default': None, 'description': 'Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.', 'name': 'alma'},
           {'annotation': dict, 'default': None, 'description': 'Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.', 'name': 'amazon_pay'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users can accept [Apple Pay](https://stripe.com/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](https://stripe.com/pricing) is the same as other card transactions. Check '
                           'this [page](https://docs.stripe.com/apple-pay) for more details.',
            'name': 'apple_pay'},
           {'annotation': dict, 'default': None, 'description': 'Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.', 'name': 'apple_pay_later'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](https://docs.stripe.com/payments/au-becs-debit) for more details.', 'name': 'au_becs_debit'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](https://docs.stripe.com/payments/payment-methods/bacs-debit) for more details.', 'name': 'bacs_debit'},
           {'annotation': dict,
            'default': None,
            'description': 'Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](https://docs.stripe.com/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this '
                           '[page](https://docs.stripe.com/payments/bancontact) for more details.',
            'name': 'bancontact'},
           {'annotation': dict,
            'default': None,
            'description': 'Billie is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate '
                           'notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.',
            'name': 'billie'},
           {'annotation': dict,
            'default': None,
            'description': 'BLIK is a [single use](https://docs.stripe.com/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this '
                           '[page](https://docs.stripe.com/payments/blik) for more details.',
            'name': 'blik'},
           {'annotation': dict, 'default': None, 'description': 'Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](https://docs.stripe.com/payments/boleto) for more details.', 'name': 'boleto'},
           {'annotation': dict, 'default': None, 'description': 'Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.', 'name': 'card'},
           {'annotation': dict,
            'default': None,
            'description': "Cartes Bancaires is France's local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](https://docs.stripe.com/payments/cartes-bancaires) for more details.",
            'name': 'cartes_bancaires'},
           {'annotation': dict, 'default': None, 'description': 'Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](https://docs.stripe.com/payments/cash-app-pay) for more details.', 'name': 'cashapp'},
           {'annotation': dict, 'default': None, 'description': '[Stablecoin payments](https://docs.stripe.com/payments/stablecoin-payments) enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.', 'name': 'crypto'},
           {'annotation': dict, 'default': None, 'description': 'Uses a customer’s [cash balance](https://docs.stripe.com/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](https://docs.stripe.com/payments/bank-transfers) for more details.', 'name': 'customer_balance'},
           {'annotation': dict,
            'default': None,
            'description': 'EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](https://docs.stripe.com/payments/eps) for more details.',
            'name': 'eps'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It '
                           'is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](https://docs.stripe.com/payments/fpx) for more details.',
            'name': 'fpx'},
           {'annotation': dict,
            'default': None,
            'description': 'Meal vouchers in France, or “titres-restaurant”, is a local benefits program commonly offered by employers for their employees to purchase prepared food and beverages on working days. Check this [page](https://docs.stripe.com/payments/meal-vouchers/fr-meal-vouchers) for more details.',
            'name': 'fr_meal_voucher_conecs'},
           {'annotation': dict,
            'default': None,
            'description': 'giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. '
                           'giropay accounts for 10% of online checkouts in Germany. Check this [page](https://docs.stripe.com/payments/giropay) for more details.',
            'name': 'giropay'},
           {'annotation': dict,
            'default': None,
            'description': "Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer's Google account. Check this "
                           '[page](https://docs.stripe.com/google-pay) for more details.',
            'name': 'google_pay'},
           {'annotation': dict, 'default': None, 'description': 'GrabPay is a payment method developed by [Grab](https://www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](https://docs.stripe.com/payments/grabpay) for more details.', 'name': 'grabpay'},
           {'annotation': dict,
            'default': None,
            'description': 'iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check '
                           'this [page](https://docs.stripe.com/payments/ideal) for more details.',
            'name': 'ideal'},
           {'annotation': dict,
            'default': None,
            'description': 'JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this '
                           '[page](https://support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.',
            'name': 'jcb'},
           {'annotation': dict, 'default': None, 'description': 'Kakao Pay is a popular local wallet available in South Korea.', 'name': 'kakao_pay'},
           {'annotation': dict,
            'default': None,
            'description': "Klarna gives customers a range of [payment options](https://docs.stripe.com/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer's billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check "
                           'this [page](https://docs.stripe.com/payments/klarna) for more details.',
            'name': 'klarna'},
           {'annotation': dict, 'default': None, 'description': 'Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](https://docs.stripe.com/payments/konbini) for more details.', 'name': 'konbini'},
           {'annotation': dict, 'default': None, 'description': 'Korean cards let users pay using locally issued cards from South Korea.', 'name': 'kr_card'},
           {'annotation': dict, 'default': None, 'description': '[Link](https://docs.stripe.com/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.', 'name': 'link'},
           {'annotation': dict, 'default': None, 'description': 'MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this [page](https://docs.stripe.com/payments/mb-way) for more details.', 'name': 'mb_way'},
           {'annotation': dict,
            'default': None,
            'description': 'MobilePay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](https://docs.stripe.com/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this '
                           '[page](https://docs.stripe.com/payments/mobilepay) for more details.',
            'name': 'mobilepay'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](https://stripe.com/docs/sources)—a single integration path for creating payments using any supported method.', 'name': 'multibanco'},
           {'annotation': str, 'default': None, 'description': 'Configuration name.', 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': 'Naver Pay is a popular local wallet available in South Korea.', 'name': 'naver_pay'},
           {'annotation': dict, 'default': None, 'description': 'Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](https://docs.stripe.com/payments/nz-bank-account) for more details.', 'name': 'nz_bank_account'},
           {'annotation': dict,
            'default': None,
            'description': 'OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](https://docs.stripe.com/payments/oxxo) for more details.',
            'name': 'oxxo'},
           {'annotation': dict,
            'default': None,
            'description': 'Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this '
                           '[page](https://docs.stripe.com/payments/p24) for more details.',
            'name': 'p24'},
           {'annotation': dict,
            'default': None,
            'description': 'Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.',
            'name': 'pay_by_bank'},
           {'annotation': dict, 'default': None, 'description': 'PAYCO is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.', 'name': 'payco'},
           {'annotation': dict, 'default': None, 'description': 'PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](https://docs.stripe.com/payments/paynow) for more details.', 'name': 'paynow'},
           {'annotation': dict, 'default': None, 'description': 'PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](https://docs.stripe.com/payments/paypal) for more details.', 'name': 'paypal'},
           {'annotation': dict,
            'default': None,
            'description': 'PayTo is a [real-time](https://docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](https://docs.stripe.com/payments/payto) for more details.',
            'name': 'payto'},
           {'annotation': dict, 'default': None, 'description': 'Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this [page](https://docs.stripe.com/payments/pix) for more details.', 'name': 'pix'},
           {'annotation': dict, 'default': None, 'description': 'PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](https://docs.stripe.com/payments/promptpay) for more details.', 'name': 'promptpay'},
           {'annotation': dict, 'default': None, 'description': 'Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.', 'name': 'revolut_pay'},
           {'annotation': dict, 'default': None, 'description': 'Samsung Pay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.', 'name': 'samsung_pay'},
           {'annotation': dict,
            'default': None,
            'description': 'Satispay is a [single-use](https://docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your '
                           'website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.',
            'name': 'satispay'},
           {'annotation': dict,
            'default': None,
            'description': 'The [Single Euro Payments Area (SEPA)](https://en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA '
                           'region, check this [page](https://docs.stripe.com/payments/sepa-debit) for more details.',
            'name': 'sepa_debit'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users in Europe and the United States can use the [Payment Intents API](https://stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](https://www.sofort.com/) payments from customers. Check this '
                           '[page](https://docs.stripe.com/payments/sofort) for more details.',
            'name': 'sofort'},
           {'annotation': dict,
            'default': None,
            'description': 'Swish is a [real-time](https://docs.stripe.com/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](https://docs.stripe.com/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this '
                           '[page](https://docs.stripe.com/payments/swish) for more details.',
            'name': 'swish'},
           {'annotation': dict, 'default': None, 'description': 'Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](https://docs.stripe.com/payments/twint) for more details.', 'name': 'twint'},
           {'annotation': dict,
            'default': None,
            'description': 'Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](https://docs.stripe.com/payments/ach-direct-debit) for more details.',
            'name': 'us_bank_account'},
           {'annotation': dict,
            'default': None,
            'description': "WeChat, owned by Tencent, is China's leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses' apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this "
                           '[page](https://docs.stripe.com/payments/wechat-pay) for more details.',
            'name': 'wechat_pay'},
           {'annotation': dict, 'default': None, 'description': 'Zip gives your customers a way to split purchases over a series of payments. Check this [page](https://docs.stripe.com/payments/zip) for more details like country availability.', 'name': 'zip'}],
  'doc_url': 'https://docs.stripe.com/api/payment_method_configurations/update',
  'op_id': 'PostPaymentMethodConfigurationsConfiguration',
  'path': '/v1/payment_method_configurations/{configuration}',
  'qparams': [],
  'summary': 'Update payment method configuration',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_method_domains/list',
  'op_id': 'GetPaymentMethodDomains',
  'path': '/v1/payment_method_domains',
  'qparams': [{'annotation': 'str', 'description': 'The domain name that this payment method domain object represents.', 'name': 'domain_name'},
              {'annotation': 'str', 'description': 'Whether this payment method domain is enabled. If the domain is not enabled, payment methods will not appear in Elements or Embedded Checkout', 'name': 'enabled'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List payment method domains',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The domain name that this payment method domain object represents.', 'name': 'domain_name'},
           {'annotation': bool, 'default': None, 'description': 'Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements or Embedded Checkout.', 'name': 'enabled'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/payment_method_domains/create',
  'op_id': 'PostPaymentMethodDomains',
  'path': '/v1/payment_method_domains',
  'qparams': [],
  'summary': 'Create a payment method domain',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_method_domains/delete',
  'op_id': 'GetPaymentMethodDomainsPaymentMethodDomain',
  'path': '/v1/payment_method_domains/{payment_method_domain}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a payment method domain',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements or Embedded Checkout.', 'name': 'enabled'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/payment_method_domains/update',
  'op_id': 'PostPaymentMethodDomainsPaymentMethodDomain',
  'path': '/v1/payment_method_domains/{payment_method_domain}',
  'qparams': [],
  'summary': 'Update a payment method domain',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/validates/update',
  'op_id': 'PostPaymentMethodDomainsPaymentMethodDomainValidate',
  'path': '/v1/payment_method_domains/{payment_method_domain}/validate',
  'qparams': [],
  'summary': 'Validate an existing payment method domain',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payment_methods/list',
  'op_id': 'GetPaymentMethods',
  'path': '/v1/payment_methods',
  'qparams': [{'annotation': 'str', 'description': 'This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.', 'name': 'allow_redisplay'},
              {'annotation': 'str', 'description': 'The ID of the customer whose PaymentMethods will be retrieved.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'The ID of the Account whose PaymentMethods will be retrieved.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Filters the list by the object `type` field. Unfiltered, the list returns all payment method types except `custom`. If your integration expects only one type of payment method in the response, specify that type value in the request to reduce your payload.', 'name': 'type'}],
  'summary': 'List PaymentMethods',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'If this is an `acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.', 'name': 'acss_debit'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `affirm` PaymentMethod, this hash contains details about the Affirm payment method.', 'name': 'affirm'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.', 'name': 'afterpay_clearpay'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `Alipay` PaymentMethod, this hash contains details about the Alipay payment method.', 'name': 'alipay'},
           {'annotation': str,
            'default': None,
            'description': 'This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to `unspecified`.',
            'name': 'allow_redisplay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.', 'name': 'alma'},
           {'annotation': dict, 'default': None, 'description': 'If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.', 'name': 'amazon_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `au_becs_debit` PaymentMethod, this hash contains details about the bank account.', 'name': 'au_becs_debit'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.', 'name': 'bacs_debit'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.', 'name': 'bancontact'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `billie` PaymentMethod, this hash contains details about the Billie payment method.', 'name': 'billie'},
           {'annotation': dict, 'default': None, 'description': 'Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.', 'name': 'billing_details'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `blik` PaymentMethod, this hash contains details about the BLIK payment method.', 'name': 'blik'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `boleto` PaymentMethod, this hash contains details about the Boleto payment method.', 'name': 'boleto'},
           {'annotation': object,
            'default': None,
            'description': 'If this is a `card` PaymentMethod, this hash contains the user\'s card details. For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format `card: {token: "tok_visa"}`. When providing a card number, you must meet the '
                           'requirements for [PCI compliance](https://stripe.com/docs/security#validating-pci-compliance). We strongly recommend using Stripe.js instead of interacting with this API directly.',
            'name': 'card'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.', 'name': 'cashapp'},
           {'annotation': dict, 'default': None, 'description': 'If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.', 'name': 'crypto'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `custom` PaymentMethod, this hash contains details about the Custom payment method.', 'name': 'custom'},
           {'annotation': str, 'default': None, 'description': 'The `Customer` to whom the original PaymentMethod is attached.', 'name': 'customer'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.', 'name': 'customer_balance'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `eps` PaymentMethod, this hash contains details about the EPS payment method.', 'name': 'eps'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `fpx` PaymentMethod, this hash contains details about the FPX payment method.', 'name': 'fpx'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `giropay` PaymentMethod, this hash contains details about the Giropay payment method.', 'name': 'giropay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.', 'name': 'grabpay'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `ideal` PaymentMethod, this hash contains details about the iDEAL payment method.', 'name': 'ideal'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.', 'name': 'interac_present'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.', 'name': 'kakao_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `klarna` PaymentMethod, this hash contains details about the Klarna payment method.', 'name': 'klarna'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `konbini` PaymentMethod, this hash contains details about the Konbini payment method.', 'name': 'konbini'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.', 'name': 'kr_card'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `Link` PaymentMethod, this hash contains details about the Link payment method.', 'name': 'link'},
           {'annotation': dict, 'default': None, 'description': 'If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.', 'name': 'mb_way'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.', 'name': 'mobilepay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.', 'name': 'multibanco'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.', 'name': 'naver_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.', 'name': 'nz_bank_account'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `oxxo` PaymentMethod, this hash contains details about the OXXO payment method.', 'name': 'oxxo'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `p24` PaymentMethod, this hash contains details about the P24 payment method.', 'name': 'p24'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.', 'name': 'pay_by_bank'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `payco` PaymentMethod, this hash contains details about the PAYCO payment method.', 'name': 'payco'},
           {'annotation': str, 'default': None, 'description': 'The PaymentMethod to share.', 'name': 'payment_method'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `paynow` PaymentMethod, this hash contains details about the PayNow payment method.', 'name': 'paynow'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `paypal` PaymentMethod, this hash contains details about the PayPal payment method.', 'name': 'paypal'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `payto` PaymentMethod, this hash contains details about the PayTo payment method.', 'name': 'payto'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `pix` PaymentMethod, this hash contains details about the Pix payment method.', 'name': 'pix'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.', 'name': 'promptpay'},
           {'annotation': dict, 'default': None, 'description': 'Options to configure Radar. See [Radar Session](https://docs.stripe.com/radar/radar-session) for more information.', 'name': 'radar_options'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.', 'name': 'revolut_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.', 'name': 'samsung_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `satispay` PaymentMethod, this hash contains details about the Satispay payment method.', 'name': 'satispay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.', 'name': 'sepa_debit'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `sofort` PaymentMethod, this hash contains details about the SOFORT payment method.', 'name': 'sofort'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `swish` PaymentMethod, this hash contains details about the Swish payment method.', 'name': 'swish'},
           {'annotation': dict, 'default': None, 'description': 'If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.', 'name': 'twint'},
           {'annotation': str, 'default': None, 'description': 'The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.', 'name': 'type'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.', 'name': 'us_bank_account'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.', 'name': 'wechat_pay'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `zip` PaymentMethod, this hash contains details about the Zip payment method.', 'name': 'zip'}],
  'doc_url': 'https://docs.stripe.com/api/payment_methods/create',
  'op_id': 'PostPaymentMethods',
  'path': '/v1/payment_methods',
  'qparams': [],
  'summary': 'Shares a PaymentMethod',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/payment_methods/delete', 'op_id': 'GetPaymentMethodsPaymentMethod', 'path': '/v1/payment_methods/{payment_method}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a PaymentMethod', 'verb': 'get'},
 {'data': [{'annotation': str,
            'default': None,
            'description': 'This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to `unspecified`.',
            'name': 'allow_redisplay'},
           {'annotation': dict, 'default': None, 'description': 'Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.', 'name': 'billing_details'},
           {'annotation': dict, 'default': None, 'description': "If this is a `card` PaymentMethod, this hash contains the user's card details.", 'name': 'card'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'If this is a `payto` PaymentMethod, this hash contains details about the PayTo payment method.', 'name': 'payto'},
           {'annotation': dict, 'default': None, 'description': 'If this is an `us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.', 'name': 'us_bank_account'}],
  'doc_url': 'https://docs.stripe.com/api/payment_methods/update',
  'op_id': 'PostPaymentMethodsPaymentMethod',
  'path': '/v1/payment_methods/{payment_method}',
  'qparams': [],
  'summary': 'Update a PaymentMethod',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The ID of the customer to which to attach the PaymentMethod.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The ID of the Account representing the customer to which to attach the PaymentMethod.', 'name': 'customer_account'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/attachs/update',
  'op_id': 'PostPaymentMethodsPaymentMethodAttach',
  'path': '/v1/payment_methods/{payment_method}/attach',
  'qparams': [],
  'summary': 'Attach a PaymentMethod to a Customer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/detachs/update',
  'op_id': 'PostPaymentMethodsPaymentMethodDetach',
  'path': '/v1/payment_methods/{payment_method}/detach',
  'qparams': [],
  'summary': 'Detach a PaymentMethod from a Customer',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The amount you initially requested for this payment.', 'name': 'amount_requested'},
           {'annotation': dict, 'default': None, 'description': 'Customer information for this payment.', 'name': 'customer_details'},
           {'annotation': str, 'default': None, 'description': 'Indicates whether the customer was present in your checkout flow during this payment.', 'name': 'customer_presence'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about the payment attempt failure.', 'name': 'failed'},
           {'annotation': dict, 'default': None, 'description': 'Information about the payment attempt guarantee.', 'name': 'guaranteed'},
           {'annotation': int, 'default': None, 'description': 'When the reported payment was initiated. Measured in seconds since the Unix epoch.', 'name': 'initiated_at'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The outcome of the reported payment.', 'name': 'outcome'},
           {'annotation': dict, 'default': None, 'description': 'Information about the Payment Method debited for this payment.', 'name': 'payment_method_details'},
           {'annotation': dict, 'default': None, 'description': 'Processor information for this payment.', 'name': 'processor_details'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for this payment.', 'name': 'shipping_details'}],
  'doc_url': 'https://docs.stripe.com/api/report_payments/create',
  'op_id': 'PostPaymentRecordsReportPayment',
  'path': '/v1/payment_records/report_payment',
  'qparams': [],
  'summary': 'Report a payment',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/payment_records/delete', 'op_id': 'GetPaymentRecordsId', 'path': '/v1/payment_records/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Payment Record', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about the payment attempt failure.', 'name': 'failed'},
           {'annotation': dict, 'default': None, 'description': 'Information about the payment attempt guarantee.', 'name': 'guaranteed'},
           {'annotation': int, 'default': None, 'description': 'When the reported payment was initiated. Measured in seconds since the Unix epoch.', 'name': 'initiated_at'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The outcome of the reported payment.', 'name': 'outcome'},
           {'annotation': dict, 'default': None, 'description': 'Information about the Payment Method debited for this payment.', 'name': 'payment_method_details'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for this payment.', 'name': 'shipping_details'}],
  'doc_url': 'https://docs.stripe.com/api/report_payment_attempts/update',
  'op_id': 'PostPaymentRecordsIdReportPaymentAttempt',
  'path': '/v1/payment_records/{id}/report_payment_attempt',
  'qparams': [],
  'summary': 'Report a payment attempt',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'When the reported payment was canceled. Measured in seconds since the Unix epoch.', 'name': 'canceled_at'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/report_payment_attempt_canceleds/update',
  'op_id': 'PostPaymentRecordsIdReportPaymentAttemptCanceled',
  'path': '/v1/payment_records/{id}/report_payment_attempt_canceled',
  'qparams': [],
  'summary': 'Report payment attempt canceled',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'When the reported payment failed. Measured in seconds since the Unix epoch.', 'name': 'failed_at'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/report_payment_attempt_faileds/update',
  'op_id': 'PostPaymentRecordsIdReportPaymentAttemptFailed',
  'path': '/v1/payment_records/{id}/report_payment_attempt_failed',
  'qparams': [],
  'summary': 'Report payment attempt failed',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'When the reported payment was guaranteed. Measured in seconds since the Unix epoch.', 'name': 'guaranteed_at'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/report_payment_attempt_guaranteeds/update',
  'op_id': 'PostPaymentRecordsIdReportPaymentAttemptGuaranteed',
  'path': '/v1/payment_records/{id}/report_payment_attempt_guaranteed',
  'qparams': [],
  'summary': 'Report payment attempt guaranteed',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Customer information for this payment.', 'name': 'customer_details'},
           {'annotation': object, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'Shipping information for this payment.', 'name': 'shipping_details'}],
  'doc_url': 'https://docs.stripe.com/api/report_payment_attempt_informationals/update',
  'op_id': 'PostPaymentRecordsIdReportPaymentAttemptInformational',
  'path': '/v1/payment_records/{id}/report_payment_attempt_informational',
  'qparams': [],
  'summary': 'Report payment attempt informational',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'A positive integer in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) representing how much of this payment to refund. Can refund only up to the remaining, unrefunded amount of the payment.', 'name': 'amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'When the reported refund was initiated. Measured in seconds since the Unix epoch.', 'name': 'initiated_at'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The outcome of the reported refund.', 'name': 'outcome'},
           {'annotation': dict, 'default': None, 'description': 'Processor information for this refund.', 'name': 'processor_details'},
           {'annotation': dict, 'default': None, 'description': 'Information about the payment attempt refund.', 'name': 'refunded'}],
  'doc_url': 'https://docs.stripe.com/api/report_refunds/update',
  'op_id': 'PostPaymentRecordsIdReportRefund',
  'path': '/v1/payment_records/{id}/report_refund',
  'qparams': [],
  'summary': 'Report a refund',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/payouts/list',
  'op_id': 'GetPayouts',
  'path': '/v1/payouts',
  'qparams': [{'annotation': 'str', 'description': 'Only return payouts that are expected to arrive during the given date interval.', 'name': 'arrival_date'},
              {'annotation': 'str', 'description': 'Only return payouts that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'The ID of an external account - only return payouts sent to this external account.', 'name': 'destination'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return payouts that have the given status: `pending`, `paid`, `failed`, or `canceled`.', 'name': 'status'}],
  'summary': 'List all payouts',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer in cents representing how much to payout.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': "The ID of a bank account or a card to send the payout to. If you don't provide a destination, we use the default external account for the specified currency.", 'name': 'destination'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The method used to send this payout, which is `standard` or `instant`. We support `instant` for payouts to debit cards and bank accounts in certain countries. Learn more about [bank support for Instant Payouts](https://stripe.com/docs/payouts/instant-payouts-banks).', 'name': 'method'},
           {'annotation': str, 'default': None, 'description': 'The ID of a v2 FinancialAccount to send funds to.', 'name': 'payout_method'},
           {'annotation': str, 'default': None, 'description': 'The balance type of your Stripe balance to draw this payout from. Balances for different payment sources are kept separately. You can find the amounts with the Balances API. One of `bank_account`, `card`, or `fpx`.', 'name': 'source_type'},
           {'annotation': str,
            'default': None,
            'description': "A string that displays on the recipient's bank or card statement (up to 22 characters). A `statement_descriptor` that's longer than 22 characters return an error. Most banks truncate this information and display it inconsistently. Some banks might not display it at all.",
            'name': 'statement_descriptor'}],
  'doc_url': 'https://docs.stripe.com/api/payouts/create',
  'op_id': 'PostPayouts',
  'path': '/v1/payouts',
  'qparams': [],
  'summary': 'Create a payout',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/payouts/delete', 'op_id': 'GetPayoutsPayout', 'path': '/v1/payouts/{payout}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a payout', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/payouts/update',
  'op_id': 'PostPayoutsPayout',
  'path': '/v1/payouts/{payout}',
  'qparams': [],
  'summary': 'Update a payout',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/cancels/update', 'op_id': 'PostPayoutsPayoutCancel', 'path': '/v1/payouts/{payout}/cancel', 'qparams': [], 'summary': 'Cancel a payout', 'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/reverses/update',
  'op_id': 'PostPayoutsPayoutReverse',
  'path': '/v1/payouts/{payout}/reverse',
  'qparams': [],
  'summary': 'Reverse a payout',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/plans/list',
  'op_id': 'GetPlans',
  'path': '/v1/plans',
  'qparams': [{'annotation': 'str', 'description': 'Only return plans that are active or inactive (e.g., pass `false` to list all inactive plans).', 'name': 'active'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return plans for the given product.', 'name': 'product'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all plans',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the plan is currently available for new subscriptions. Defaults to `true`.', 'name': 'active'},
           {'annotation': int, 'default': None, 'description': 'A positive integer in cents (or local equivalent) (or 0 for a free plan) representing how much to charge on a recurring basis.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Same as `amount`, but accepts a decimal value with at most 12 decimal places. Only one of `amount` and `amount_decimal` can be set.', 'name': 'amount_decimal'},
           {'annotation': str,
            'default': None,
            'description': 'Describes how to compute the price per period. Either `per_unit` or `tiered`. `per_unit` indicates that the fixed amount (specified in `amount`) will be charged per unit in `quantity` (for plans with `usage_type=licensed`), or per unit of total usage (for plans with `usage_type=metered`). `tiered` indicates that the unit pricing '
                           'will be computed using a tiering strategy as defined using the `tiers` and `tiers_mode` attributes.',
            'name': 'billing_scheme'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'An identifier randomly generated by Stripe. Used to identify this plan when subscribing a customer. You can optionally override this ID, but the ID must be unique across all plans in your Stripe account. You can, however, use the same plan ID in both live and test modes.', 'name': 'id'},
           {'annotation': str, 'default': None, 'description': 'Specifies billing frequency. Either `day`, `week`, `month` or `year`.', 'name': 'interval'},
           {'annotation': int, 'default': None, 'description': 'The number of intervals between subscription billings. For example, `interval=month` and `interval_count=3` bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).', 'name': 'interval_count'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The meter tracking the usage of a metered price', 'name': 'meter'},
           {'annotation': str, 'default': None, 'description': 'A brief description of the plan, hidden from customers.', 'name': 'nickname'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'product'},
           {'annotation': list, 'default': None, 'description': 'Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.', 'name': 'tiers'},
           {'annotation': str, 'default': None, 'description': 'Defines if the tiering price should be `graduated` or `volume` based. In `volume`-based tiering, the maximum quantity within a period determines the per unit price, in `graduated` tiering pricing can successively change as the quantity grows.', 'name': 'tiers_mode'},
           {'annotation': dict, 'default': None, 'description': 'Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined with `tiers`.', 'name': 'transform_usage'},
           {'annotation': int, 'default': None, 'description': 'Default number of trial days when subscribing a customer to this plan using [`trial_from_plan=true`](https://docs.stripe.com/api#create_subscription-trial_from_plan).', 'name': 'trial_period_days'},
           {'annotation': str, 'default': None, 'description': 'Configures how the quantity per period should be determined. Can be either `metered` or `licensed`. `licensed` automatically bills the `quantity` set when adding it to a subscription. `metered` aggregates the total usage based on usage records. Defaults to `licensed`.', 'name': 'usage_type'}],
  'doc_url': 'https://docs.stripe.com/api/plans/create',
  'op_id': 'PostPlans',
  'path': '/v1/plans',
  'qparams': [],
  'summary': 'Create a plan',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/plans/delete', 'op_id': 'DeletePlansPlan', 'path': '/v1/plans/{plan}', 'qparams': [], 'summary': 'Delete a plan', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/plans/delete', 'op_id': 'GetPlansPlan', 'path': '/v1/plans/{plan}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a plan', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the plan is currently available for new subscriptions.', 'name': 'active'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'A brief description of the plan, hidden from customers.', 'name': 'nickname'},
           {'annotation': str, 'default': None, 'description': 'The product the plan belongs to. This cannot be changed once it has been used in a subscription or subscription schedule.', 'name': 'product'},
           {'annotation': int, 'default': None, 'description': 'Default number of trial days when subscribing a customer to this plan using [`trial_from_plan=true`](https://docs.stripe.com/api#create_subscription-trial_from_plan).', 'name': 'trial_period_days'}],
  'doc_url': 'https://docs.stripe.com/api/plans/update',
  'op_id': 'PostPlansPlan',
  'path': '/v1/plans/{plan}',
  'qparams': [],
  'summary': 'Update a plan',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/prices/list',
  'op_id': 'GetPrices',
  'path': '/v1/prices',
  'qparams': [{'annotation': 'str', 'description': 'Only return prices that are active or inactive (e.g., pass `false` to list all inactive prices).', 'name': 'active'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return prices for the given currency.', 'name': 'currency'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return the price with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.', 'name': 'lookup_keys'},
              {'annotation': 'str', 'description': 'Only return prices for the given product.', 'name': 'product'},
              {'annotation': 'str', 'description': 'Only return prices with these recurring fields.', 'name': 'recurring'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return prices of type `recurring` or `one_time`.', 'name': 'type'}],
  'summary': 'List all prices',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the price can be used for new purchases. Defaults to `true`.', 'name': 'active'},
           {'annotation': str,
            'default': None,
            'description': 'Describes how to compute the price per period. Either `per_unit` or `tiered`. `per_unit` indicates that the fixed amount (specified in `unit_amount` or `unit_amount_decimal`) will be charged per unit in `quantity` (for prices with `usage_type=licensed`), or per unit of total usage (for prices with `usage_type=metered`). `tiered` '
                           'indicates that the unit pricing will be computed using a tiering strategy as defined using the `tiers` and `tiers_mode` attributes.',
            'name': 'billing_scheme'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': dict, 'default': None, 'description': 'Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html) and a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency_options'},
           {'annotation': dict, 'default': None, 'description': 'When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.', 'name': 'custom_unit_amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.', 'name': 'lookup_key'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'A brief description of the price, hidden from customers.', 'name': 'nickname'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [Product](https://docs.stripe.com/api/products) that this [Price](https://docs.stripe.com/api/prices) will belong to.', 'name': 'product'},
           {'annotation': dict, 'default': None, 'description': 'These fields can be used to create a new product that this price will belong to.', 'name': 'product_data'},
           {'annotation': dict, 'default': None, 'description': 'The recurring components of a price such as `interval` and `usage_type`.', 'name': 'recurring'},
           {'annotation': str,
            'default': None,
            'description': 'Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or '
                           '`unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.',
            'name': 'tax_behavior'},
           {'annotation': list, 'default': None, 'description': 'Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.', 'name': 'tiers'},
           {'annotation': str, 'default': None, 'description': 'Defines if the tiering price should be `graduated` or `volume` based. In `volume`-based tiering, the maximum quantity within a period determines the per unit price, in `graduated` tiering pricing can successively change as the quantity grows.', 'name': 'tiers_mode'},
           {'annotation': bool, 'default': None, 'description': 'If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.', 'name': 'transfer_lookup_key'},
           {'annotation': dict, 'default': None, 'description': 'Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined with `tiers`.', 'name': 'transform_quantity'},
           {'annotation': int, 'default': None, 'description': 'A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of `unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required, unless `billing_scheme=tiered`.', 'name': 'unit_amount'},
           {'annotation': str, 'default': None, 'description': 'Same as `unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.', 'name': 'unit_amount_decimal'}],
  'doc_url': 'https://docs.stripe.com/api/prices/create',
  'op_id': 'PostPrices',
  'path': '/v1/prices',
  'qparams': [],
  'summary': 'Create a price',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetPricesSearch',
  'path': '/v1/prices/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for prices](https://docs.stripe.com/search#query-fields-for-prices).', 'name': 'query'}],
  'summary': 'Search prices',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/prices/delete', 'op_id': 'GetPricesPrice', 'path': '/v1/prices/{price}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a price', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the price can be used for new purchases. Defaults to `true`.', 'name': 'active'},
           {'annotation': object, 'default': None, 'description': 'Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html) and a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency_options'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.', 'name': 'lookup_key'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'A brief description of the price, hidden from customers.', 'name': 'nickname'},
           {'annotation': str,
            'default': None,
            'description': 'Only required if a [default tax behavior](https://docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or '
                           '`unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.',
            'name': 'tax_behavior'},
           {'annotation': bool, 'default': None, 'description': 'If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.', 'name': 'transfer_lookup_key'}],
  'doc_url': 'https://docs.stripe.com/api/prices/update',
  'op_id': 'PostPricesPrice',
  'path': '/v1/prices/{price}',
  'qparams': [],
  'summary': 'Update a price',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/products/list',
  'op_id': 'GetProducts',
  'path': '/v1/products',
  'qparams': [{'annotation': 'str', 'description': 'Only return products that are active or inactive (e.g., pass `false` to list all inactive products).', 'name': 'active'},
              {'annotation': 'str', 'description': 'Only return products that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Only return products with the given IDs. Cannot be used with [starting_after](https://api.stripe.com#list_products-starting_after) or [ending_before](https://api.stripe.com#list_products-ending_before).', 'name': 'ids'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return products that can be shipped (i.e., physical, not digital products).', 'name': 'shippable'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return products with the given url.', 'name': 'url'}],
  'summary': 'List all products',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the product is currently available for purchase. Defaults to `true`.', 'name': 'active'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object. This Price will be set as the default price for this product.', 'name': 'default_price_data'},
           {'annotation': str, 'default': None, 'description': "The product's description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.", 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.', 'name': 'id'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 8 URLs of images for this product, meant to be displayable to the customer.', 'name': 'images'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 15 marketing features for this product. These are displayed in [pricing tables](https://docs.stripe.com/payments/checkout/pricing-table).', 'name': 'marketing_features'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The product's name, meant to be displayable to the customer.", 'name': 'name'},
           {'annotation': dict, 'default': None, 'description': 'The dimensions of this product for shipping purposes.', 'name': 'package_dimensions'},
           {'annotation': bool, 'default': None, 'description': 'Whether this product is shipped (i.e., physical goods).', 'name': 'shippable'},
           {'annotation': str,
            'default': None,
            'description': "An arbitrary string to be displayed on your customer's credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.\n"
                           '\n'
                           'This may be up to 22 characters. The statement description may not include `<`, `>`, `\\`, `"`, `\'` characters, and will appear on your customer\'s statement in capital letters. Non-ASCII characters are automatically stripped.\n'
                           ' It must contain at least one letter. Only used for subscription payments.',
            'name': 'statement_descriptor'},
           {'annotation': str, 'default': None, 'description': 'A [tax code](https://docs.stripe.com/tax/tax-categories) ID.', 'name': 'tax_code'},
           {'annotation': str, 'default': None, 'description': "A label that represents units of this product. When set, this will be included in customers' receipts, invoices, Checkout, and the customer portal.", 'name': 'unit_label'},
           {'annotation': str, 'default': None, 'description': 'A URL of a publicly-accessible webpage for this product.', 'name': 'url'}],
  'doc_url': 'https://docs.stripe.com/api/products/create',
  'op_id': 'PostProducts',
  'path': '/v1/products',
  'qparams': [],
  'summary': 'Create a product',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetProductsSearch',
  'path': '/v1/products/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for products](https://docs.stripe.com/search#query-fields-for-products).', 'name': 'query'}],
  'summary': 'Search products',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/products/delete', 'op_id': 'DeleteProductsId', 'path': '/v1/products/{id}', 'qparams': [], 'summary': 'Delete a product', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/products/delete', 'op_id': 'GetProductsId', 'path': '/v1/products/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a product', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the product is available for purchase.', 'name': 'active'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [Price](https://docs.stripe.com/api/prices) object that is the default price for this product.', 'name': 'default_price'},
           {'annotation': object, 'default': None, 'description': "The product's description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.", 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'A list of up to 8 URLs of images for this product, meant to be displayable to the customer.', 'name': 'images'},
           {'annotation': object, 'default': None, 'description': 'A list of up to 15 marketing features for this product. These are displayed in [pricing tables](https://docs.stripe.com/payments/checkout/pricing-table).', 'name': 'marketing_features'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': "The product's name, meant to be displayable to the customer.", 'name': 'name'},
           {'annotation': object, 'default': None, 'description': 'The dimensions of this product for shipping purposes.', 'name': 'package_dimensions'},
           {'annotation': bool, 'default': None, 'description': 'Whether this product is shipped (i.e., physical goods).', 'name': 'shippable'},
           {'annotation': str,
            'default': None,
            'description': "An arbitrary string to be displayed on your customer's credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.\n"
                           '\n'
                           'This may be up to 22 characters. The statement description may not include `<`, `>`, `\\`, `"`, `\'` characters, and will appear on your customer\'s statement in capital letters. Non-ASCII characters are automatically stripped.\n'
                           ' It must contain at least one letter. May only be set if `type=service`. Only used for subscription payments.',
            'name': 'statement_descriptor'},
           {'annotation': object, 'default': None, 'description': 'A [tax code](https://docs.stripe.com/tax/tax-categories) ID.', 'name': 'tax_code'},
           {'annotation': object, 'default': None, 'description': "A label that represents units of this product. When set, this will be included in customers' receipts, invoices, Checkout, and the customer portal. May only be set if `type=service`.", 'name': 'unit_label'},
           {'annotation': object, 'default': None, 'description': 'A URL of a publicly-accessible webpage for this product.', 'name': 'url'}],
  'doc_url': 'https://docs.stripe.com/api/products/update',
  'op_id': 'PostProductsId',
  'path': '/v1/products/{id}',
  'qparams': [],
  'summary': 'Update a product',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/features/delete',
  'op_id': 'GetProductsProductFeatures',
  'path': '/v1/products/{product}/features',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all features attached to a product',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The ID of the [Feature](https://docs.stripe.com/api/entitlements/feature) object attached to this product.', 'name': 'entitlement_feature'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/features/update',
  'op_id': 'PostProductsProductFeatures',
  'path': '/v1/products/{product}/features',
  'qparams': [],
  'summary': 'Attach a feature to a product',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/features/delete', 'op_id': 'DeleteProductsProductFeaturesId', 'path': '/v1/products/{product}/features/{id}', 'qparams': [], 'summary': 'Remove a feature from a product', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/features/delete', 'op_id': 'GetProductsProductFeaturesId', 'path': '/v1/products/{product}/features/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a product_feature', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/promotion_codes/list',
  'op_id': 'GetPromotionCodes',
  'path': '/v1/promotion_codes',
  'qparams': [{'annotation': 'str', 'description': 'Filter promotion codes by whether they are active.', 'name': 'active'},
              {'annotation': 'str', 'description': 'Only return promotion codes that have this case-insensitive code.', 'name': 'code'},
              {'annotation': 'str', 'description': 'Only return promotion codes for this coupon.', 'name': 'coupon'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return promotion codes that are restricted to this customer.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return promotion codes that are restricted to this account representing the customer.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all promotion codes',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the promotion code is currently active.', 'name': 'active'},
           {'annotation': str, 'default': None, 'description': 'The customer-facing code. Regardless of case, this code must be unique across all active promotion codes for a specific customer. Valid characters are lower case letters (a-z), upper case letters (A-Z), and digits (0-9).\n\nIf left blank, we will generate one automatically.', 'name': 'code'},
           {'annotation': str, 'default': None, 'description': 'The customer who can use this promotion code. If not set, all customers can use the promotion code.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The account representing the customer who can use this promotion code. If not set, all customers can use the promotion code.', 'name': 'customer_account'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': "The timestamp at which this promotion code will expire. If the coupon has specified a `redeems_by`, then this value cannot be after the coupon's `redeems_by`.", 'name': 'expires_at'},
           {'annotation': int, 'default': None, 'description': "A positive integer specifying the number of times the promotion code can be redeemed. If the coupon has specified a `max_redemptions`, then this value cannot be greater than the coupon's `max_redemptions`.", 'name': 'max_redemptions'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'The promotion referenced by this promotion code.', 'name': 'promotion'},
           {'annotation': dict, 'default': None, 'description': 'Settings that restrict the redemption of the promotion code.', 'name': 'restrictions'}],
  'doc_url': 'https://docs.stripe.com/api/promotion_codes/create',
  'op_id': 'PostPromotionCodes',
  'path': '/v1/promotion_codes',
  'qparams': [],
  'summary': 'Create a promotion code',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/promotion_codes/delete', 'op_id': 'GetPromotionCodesPromotionCode', 'path': '/v1/promotion_codes/{promotion_code}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a promotion code', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the promotion code is currently active. A promotion code can only be reactivated when the coupon is still valid and the promotion code is otherwise redeemable.', 'name': 'active'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Settings that restrict the redemption of the promotion code.', 'name': 'restrictions'}],
  'doc_url': 'https://docs.stripe.com/api/promotion_codes/update',
  'op_id': 'PostPromotionCodesPromotionCode',
  'path': '/v1/promotion_codes/{promotion_code}',
  'qparams': [],
  'summary': 'Update a promotion code',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/quotes/list',
  'op_id': 'GetQuotes',
  'path': '/v1/quotes',
  'qparams': [{'annotation': 'str', 'description': "The ID of the customer whose quotes you're retrieving.", 'name': 'customer'},
              {'annotation': 'str', 'description': "The ID of the account representing the customer whose quotes you're retrieving.", 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'The status of the quote.', 'name': 'status'},
              {'annotation': 'str', 'description': 'Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.', 'name': 'test_clock'}],
  'summary': 'List all quotes',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.", 'name': 'application_fee_amount'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.",
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.', 'name': 'automatic_tax'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with '
                           'payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': str, 'default': None, 'description': 'The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.', 'name': 'customer_account'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any line item that does not have `tax_rates` set.', 'name': 'default_tax_rates'},
           {'annotation': object, 'default': None, 'description': 'A description that will be displayed on the quote PDF. If no value is passed, the default description configured in your [quote template settings](https://dashboard.stripe.com/settings/billing/quote) will be used.', 'name': 'description'},
           {'annotation': object, 'default': None, 'description': 'The discounts applied to the quote.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int,
            'default': None,
            'description': 'A future timestamp on which the quote will be canceled if in `open` or `draft` status. Measured in seconds since the Unix epoch. If no value is passed, the default expiration date configured in your [quote template settings](https://dashboard.stripe.com/settings/billing/quote) will be used.',
            'name': 'expires_at'},
           {'annotation': object, 'default': None, 'description': 'A footer that will be displayed on the quote PDF. If no value is passed, the default footer configured in your [quote template settings](https://dashboard.stripe.com/settings/billing/quote) will be used.', 'name': 'footer'},
           {'annotation': dict, 'default': None, 'description': 'Clone an existing quote. The new quote will be created in `status=draft`. When using this parameter, you cannot specify any other parameters except for `expires_at`.', 'name': 'from_quote'},
           {'annotation': object, 'default': None, 'description': 'A header that will be displayed on the quote PDF. If no value is passed, the default header configured in your [quote template settings](https://dashboard.stripe.com/settings/billing/quote) will be used.', 'name': 'header'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.', 'name': 'line_items'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The account on behalf of which to charge.', 'name': 'on_behalf_of'},
           {'annotation': dict,
            'default': None,
            'description': 'When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if `subscription_data[effective_date]` is present and in the future, '
                           'otherwise a subscription is created.',
            'name': 'subscription_data'},
           {'annotation': str, 'default': None, 'description': 'ID of the test clock to attach to the quote.', 'name': 'test_clock'},
           {'annotation': object, 'default': None, 'description': 'The data with which to automatically create a Transfer for each of the invoices.', 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/quotes/create',
  'op_id': 'PostQuotes',
  'path': '/v1/quotes',
  'qparams': [],
  'summary': 'Create a quote',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/quotes/delete', 'op_id': 'GetQuotesQuote', 'path': '/v1/quotes/{quote}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a quote', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': "The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.", 'name': 'application_fee_amount'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.",
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.', 'name': 'automatic_tax'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with '
                           'payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': str, 'default': None, 'description': 'The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.', 'name': 'customer_account'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any line item that does not have `tax_rates` set.', 'name': 'default_tax_rates'},
           {'annotation': object, 'default': None, 'description': 'A description that will be displayed on the quote PDF.', 'name': 'description'},
           {'annotation': object, 'default': None, 'description': 'The discounts applied to the quote.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'A future timestamp on which the quote will be canceled if in `open` or `draft` status. Measured in seconds since the Unix epoch.', 'name': 'expires_at'},
           {'annotation': object, 'default': None, 'description': 'A footer that will be displayed on the quote PDF.', 'name': 'footer'},
           {'annotation': object, 'default': None, 'description': 'A header that will be displayed on the quote PDF.', 'name': 'header'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.', 'name': 'line_items'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The account on behalf of which to charge.', 'name': 'on_behalf_of'},
           {'annotation': dict,
            'default': None,
            'description': 'When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if `subscription_data[effective_date]` is present and in the future, '
                           'otherwise a subscription is created.',
            'name': 'subscription_data'},
           {'annotation': object, 'default': None, 'description': 'The data with which to automatically create a Transfer for each of the invoices.', 'name': 'transfer_data'}],
  'doc_url': 'https://docs.stripe.com/api/quotes/update',
  'op_id': 'PostQuotesQuote',
  'path': '/v1/quotes/{quote}',
  'qparams': [],
  'summary': 'Update a quote',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/accepts/update', 'op_id': 'PostQuotesQuoteAccept', 'path': '/v1/quotes/{quote}/accept', 'qparams': [], 'summary': 'Accept a quote', 'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/cancels/update', 'op_id': 'PostQuotesQuoteCancel', 'path': '/v1/quotes/{quote}/cancel', 'qparams': [], 'summary': 'Cancel a quote', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/computed_upfront_line_items/delete',
  'op_id': 'GetQuotesQuoteComputedUpfrontLineItems',
  'path': '/v1/quotes/{quote}/computed_upfront_line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a quote's upfront line items",
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': int, 'default': None, 'description': 'A future timestamp on which the quote will be canceled if in `open` or `draft` status. Measured in seconds since the Unix epoch.', 'name': 'expires_at'}],
  'doc_url': 'https://docs.stripe.com/api/finalizes/update',
  'op_id': 'PostQuotesQuoteFinalize',
  'path': '/v1/quotes/{quote}/finalize',
  'qparams': [],
  'summary': 'Finalize a quote',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/line_items/delete',
  'op_id': 'GetQuotesQuoteLineItems',
  'path': '/v1/quotes/{quote}/line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a quote's line items",
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/pdfs/retrieve', 'op_id': 'GetQuotesQuotePdf', 'path': '/v1/quotes/{quote}/pdf', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Download quote PDF', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/early_fraud_warnings/list',
  'op_id': 'GetRadarEarlyFraudWarnings',
  'path': '/v1/radar/early_fraud_warnings',
  'qparams': [{'annotation': 'str', 'description': 'Only return early fraud warnings for the charge specified by this charge ID.', 'name': 'charge'},
              {'annotation': 'str', 'description': 'Only return early fraud warnings that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return early fraud warnings for charges that were created by the PaymentIntent specified by this PaymentIntent ID.', 'name': 'payment_intent'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all early fraud warnings',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/early_fraud_warnings/delete',
  'op_id': 'GetRadarEarlyFraudWarningsEarlyFraudWarning',
  'path': '/v1/radar/early_fraud_warnings/{early_fraud_warning}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an early fraud warning',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Details about the Client Device Metadata to associate with the payment evaluation.', 'name': 'client_device_metadata_details'},
           {'annotation': dict, 'default': None, 'description': 'Details about the customer associated with the payment evaluation.', 'name': 'customer_details'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Details about the payment.', 'name': 'payment_details'}],
  'doc_url': 'https://docs.stripe.com/api/payment_evaluations/create',
  'op_id': 'PostRadarPaymentEvaluations',
  'path': '/v1/radar/payment_evaluations',
  'qparams': [],
  'summary': 'Create a Payment Evaluation',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/value_list_items/list',
  'op_id': 'GetRadarValueListItems',
  'path': '/v1/radar/value_list_items',
  'qparams': [{'annotation': 'str', 'description': 'Only return items that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Return items belonging to the parent list whose value matches the specified value (using an "is like" match).', 'name': 'value'},
              {'annotation': 'str', 'description': 'Identifier for the parent value list this item belongs to.', 'name': 'value_list'}],
  'summary': 'List all value list items',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The value of the item (whose type must match the type of the parent value list).', 'name': 'value'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the value list which the created item will be added to.', 'name': 'value_list'}],
  'doc_url': 'https://docs.stripe.com/api/value_list_items/create',
  'op_id': 'PostRadarValueListItems',
  'path': '/v1/radar/value_list_items',
  'qparams': [],
  'summary': 'Create a value list item',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/value_list_items/delete', 'op_id': 'DeleteRadarValueListItemsItem', 'path': '/v1/radar/value_list_items/{item}', 'qparams': [], 'summary': 'Delete a value list item', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/value_list_items/delete', 'op_id': 'GetRadarValueListItemsItem', 'path': '/v1/radar/value_list_items/{item}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a value list item', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/value_lists/list',
  'op_id': 'GetRadarValueLists',
  'path': '/v1/radar/value_lists',
  'qparams': [{'annotation': 'str', 'description': 'The alias used to reference the value list when writing rules.', 'name': 'alias'},
              {'annotation': 'str', 'description': 'A value contained within a value list - returns all value lists containing this value.', 'name': 'contains'},
              {'annotation': 'str', 'description': 'Only return value lists that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all value lists',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the value list for use in rules.', 'name': 'alias'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Type of the items in the value list. One of `card_fingerprint`, `card_bin`, `email`, `ip_address`, `country`, `string`, `case_sensitive_string`, `customer_id`, `sepa_debit_fingerprint`, or `us_bank_account_fingerprint`. Use `string` if the item type is unknown or mixed.', 'name': 'item_type'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The human-readable name of the value list.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/value_lists/create',
  'op_id': 'PostRadarValueLists',
  'path': '/v1/radar/value_lists',
  'qparams': [],
  'summary': 'Create a value list',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/value_lists/delete', 'op_id': 'DeleteRadarValueListsValueList', 'path': '/v1/radar/value_lists/{value_list}', 'qparams': [], 'summary': 'Delete a value list', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/value_lists/delete', 'op_id': 'GetRadarValueListsValueList', 'path': '/v1/radar/value_lists/{value_list}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a value list', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The name of the value list for use in rules.', 'name': 'alias'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The human-readable name of the value list.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/value_lists/update',
  'op_id': 'PostRadarValueListsValueList',
  'path': '/v1/radar/value_lists/{value_list}',
  'qparams': [],
  'summary': 'Update a value list',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/refunds/list',
  'op_id': 'GetRefunds',
  'path': '/v1/refunds',
  'qparams': [{'annotation': 'str', 'description': 'Only return refunds for the charge specified by this charge ID.', 'name': 'charge'},
              {'annotation': 'str', 'description': 'Only return refunds that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return refunds for the PaymentIntent specified by this ID.', 'name': 'payment_intent'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all refunds',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': '', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the charge to refund.', 'name': 'charge'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'Customer whose customer balance to refund from.', 'name': 'customer'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.', 'name': 'instructions_email'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Origin of the refund', 'name': 'origin'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the PaymentIntent to refund.', 'name': 'payment_intent'},
           {'annotation': str,
            'default': None,
            'description': 'String indicating the reason for the refund. If set, possible values are `duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](https://docs.stripe.com/radar/lists), and will also help '
                           'us improve our fraud detection algorithms.',
            'name': 'reason'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the '
                           'application that created the charge.',
            'name': 'refund_application_fee'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).<br><br>A transfer can be reversed only by the application that created the charge.',
            'name': 'reverse_transfer'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/create',
  'op_id': 'PostRefunds',
  'path': '/v1/refunds',
  'qparams': [],
  'summary': 'Create customer balance refund',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/refunds/delete', 'op_id': 'GetRefundsRefund', 'path': '/v1/refunds/{refund}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a refund', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostRefundsRefund',
  'path': '/v1/refunds/{refund}',
  'qparams': [],
  'summary': 'Update a refund',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/cancels/update', 'op_id': 'PostRefundsRefundCancel', 'path': '/v1/refunds/{refund}/cancel', 'qparams': [], 'summary': 'Cancel a refund', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/report_runs/list',
  'op_id': 'GetReportingReportRuns',
  'path': '/v1/reporting/report_runs',
  'qparams': [{'annotation': 'str', 'description': 'Only return Report Runs that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all Report Runs',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Parameters specifying how the report should be run. Different Report Types have different required and optional parameters, listed in the [API Access to Reports](https://docs.stripe.com/reporting/statements/api) documentation.', 'name': 'parameters'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [report type](https://docs.stripe.com/reporting/statements/api#report-types) to run, such as `"balance.summary.1"`.', 'name': 'report_type'}],
  'doc_url': 'https://docs.stripe.com/api/report_runs/create',
  'op_id': 'PostReportingReportRuns',
  'path': '/v1/reporting/report_runs',
  'qparams': [],
  'summary': 'Create a Report Run',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/report_runs/delete', 'op_id': 'GetReportingReportRunsReportRun', 'path': '/v1/reporting/report_runs/{report_run}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Report Run', 'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/report_types/list', 'op_id': 'GetReportingReportTypes', 'path': '/v1/reporting/report_types', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'List all Report Types', 'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/report_types/delete', 'op_id': 'GetReportingReportTypesReportType', 'path': '/v1/reporting/report_types/{report_type}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Report Type', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/reviews/list',
  'op_id': 'GetReviews',
  'path': '/v1/reviews',
  'qparams': [{'annotation': 'str', 'description': 'Only return reviews that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all open reviews',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/reviews/delete', 'op_id': 'GetReviewsReview', 'path': '/v1/reviews/{review}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a review', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/approves/update', 'op_id': 'PostReviewsReviewApprove', 'path': '/v1/reviews/{review}/approve', 'qparams': [], 'summary': 'Approve a review', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/setup_attempts/list',
  'op_id': 'GetSetupAttempts',
  'path': '/v1/setup_attempts',
  'qparams': [{'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value\ncan be a string with an integer Unix timestamp or a\ndictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return SetupAttempts created by the SetupIntent specified by\nthis ID.', 'name': 'setup_intent'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all SetupAttempts',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/setup_intents/list',
  'op_id': 'GetSetupIntents',
  'path': '/v1/setup_intents',
  'qparams': [{'annotation': 'str',
               'description': "If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.\n"
                              '\n'
                              'It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.',
               'name': 'attach_to_self'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return SetupIntents for the customer specified by this customer ID.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return SetupIntents for the account specified by this customer ID.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return SetupIntents that associate with the specified payment method.', 'name': 'payment_method'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all SetupIntents',
  'verb': 'get'},
 {'data': [{'annotation': bool,
            'default': None,
            'description': "If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.\n"
                           '\n'
                           'It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.',
            'name': 'attach_to_self'},
           {'annotation': dict, 'default': None, 'description': 'When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.', 'name': 'automatic_payment_methods'},
           {'annotation': bool, 'default': None, 'description': 'Set to `true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.', 'name': 'confirm'},
           {'annotation': str, 'default': None, 'description': 'ID of the ConfirmationToken used to confirm this SetupIntent.\n\nIf the provided ConfirmationToken contains properties that are also being provided in this request, such as `payment_method`, then the values in this request will take precedence.', 'name': 'confirmation_token'},
           {'annotation': str, 'default': None, 'description': "ID of the Customer this SetupIntent belongs to, if one exists.\n\nIf present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.", 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': "ID of the Account this SetupIntent belongs to, if one exists.\n\nIf present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.", 'name': 'customer_account'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'The list of payment method types to exclude from use with this SetupIntent.', 'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list,
            'default': None,
            'description': 'Indicates the directions of money movement for which this payment method is intended to be used.\n'
                           '\n'
                           'Include `inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.',
            'name': 'flow_directions'},
           {'annotation': object, 'default': None, 'description': 'This hash contains details about the mandate to create. This parameter can only be used with [`confirm=true`](https://docs.stripe.com/api/setup_intents/create#create_setup_intent-confirm).', 'name': 'mandate_data'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The Stripe account ID created for this SetupIntent.', 'name': 'on_behalf_of'},
           {'annotation': str, 'default': None, 'description': 'ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.', 'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [payment method configuration](https://docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.', 'name': 'payment_method_configuration'},
           {'annotation': dict, 'default': None, 'description': 'When included, this hash creates a PaymentMethod that is set as the [`payment_method`](https://docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method)\nvalue in the SetupIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this SetupIntent.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': "The list of payment method types (for example, card) that this SetupIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](https://dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found "
                           '[here](https://docs.stripe.com/api/payment_methods/object#payment_method_object-type).',
            'name': 'payment_method_types'},
           {'annotation': str,
            'default': None,
            'description': "The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with "
                           '[`confirm=true`](https://docs.stripe.com/api/setup_intents/create#create_setup_intent-confirm).',
            'name': 'return_url'},
           {'annotation': dict,
            'default': None,
            'description': 'If you populate this hash, this SetupIntent generates a `single_use` mandate after successful completion.\n\nSingle-use mandates are only valid for the following payment methods: `acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.',
            'name': 'single_use'},
           {'annotation': str, 'default': None, 'description': 'Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to `off_session`.', 'name': 'usage'},
           {'annotation': bool, 'default': None, 'description': 'Set to `true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.', 'name': 'use_stripe_sdk'}],
  'doc_url': 'https://docs.stripe.com/api/setup_intents/create',
  'op_id': 'PostSetupIntents',
  'path': '/v1/setup_intents',
  'qparams': [],
  'summary': 'Create a SetupIntent',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/setup_intents/delete',
  'op_id': 'GetSetupIntentsIntent',
  'path': '/v1/setup_intents/{intent}',
  'qparams': [{'annotation': 'str', 'description': 'The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.', 'name': 'client_secret'}, {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a SetupIntent',
  'verb': 'get'},
 {'data': [{'annotation': bool,
            'default': None,
            'description': "If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.\n"
                           '\n'
                           'It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.',
            'name': 'attach_to_self'},
           {'annotation': str, 'default': None, 'description': "ID of the Customer this SetupIntent belongs to, if one exists.\n\nIf present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.", 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': "ID of the Account this SetupIntent belongs to, if one exists.\n\nIf present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.", 'name': 'customer_account'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': object, 'default': None, 'description': 'The list of payment method types to exclude from use with this SetupIntent.', 'name': 'excluded_payment_method_types'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list,
            'default': None,
            'description': 'Indicates the directions of money movement for which this payment method is intended to be used.\n'
                           '\n'
                           'Include `inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.',
            'name': 'flow_directions'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.', 'name': 'payment_method'},
           {'annotation': str, 'default': None, 'description': 'The ID of the [payment method configuration](https://docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.', 'name': 'payment_method_configuration'},
           {'annotation': dict, 'default': None, 'description': 'When included, this hash creates a PaymentMethod that is set as the [`payment_method`](https://docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method)\nvalue in the SetupIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this SetupIntent.', 'name': 'payment_method_options'},
           {'annotation': list,
            'default': None,
            'description': "The list of payment method types (for example, card) that this SetupIntent can set up. If you don't provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](https://dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found "
                           '[here](https://docs.stripe.com/api/payment_methods/object#payment_method_object-type).',
            'name': 'payment_method_types'}],
  'doc_url': 'https://docs.stripe.com/api/setup_intents/update',
  'op_id': 'PostSetupIntentsIntent',
  'path': '/v1/setup_intents/{intent}',
  'qparams': [],
  'summary': 'Update a SetupIntent',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'Reason for canceling this SetupIntent. Possible values are: `abandoned`, `requested_by_customer`, or `duplicate`', 'name': 'cancellation_reason'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostSetupIntentsIntentCancel',
  'path': '/v1/setup_intents/{intent}/cancel',
  'qparams': [],
  'summary': 'Cancel a SetupIntent',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The client secret of the SetupIntent.', 'name': 'client_secret'},
           {'annotation': str, 'default': None, 'description': 'ID of the ConfirmationToken used to confirm this SetupIntent.\n\nIf the provided ConfirmationToken contains properties that are also being provided in this request, such as `payment_method`, then the values in this request will take precedence.', 'name': 'confirmation_token'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': '', 'name': 'mandate_data'},
           {'annotation': str, 'default': None, 'description': 'ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.', 'name': 'payment_method'},
           {'annotation': dict, 'default': None, 'description': 'When included, this hash creates a PaymentMethod that is set as the [`payment_method`](https://docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method)\nvalue in the SetupIntent.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this SetupIntent.', 'name': 'payment_method_options'},
           {'annotation': str,
            'default': None,
            'description': "The URL to redirect your customer back to after they authenticate on the payment method's app or site.\nIf you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.\nThis parameter is only used for cards and other redirect-based payment methods.",
            'name': 'return_url'},
           {'annotation': bool, 'default': None, 'description': 'Set to `true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.', 'name': 'use_stripe_sdk'}],
  'doc_url': 'https://docs.stripe.com/api/confirms/update',
  'op_id': 'PostSetupIntentsIntentConfirm',
  'path': '/v1/setup_intents/{intent}/confirm',
  'qparams': [],
  'summary': 'Confirm a SetupIntent',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Two positive integers, in *cents*, equal to the values of the microdeposits sent to the bank account.', 'name': 'amounts'},
           {'annotation': str, 'default': None, 'description': 'The client secret of the SetupIntent.', 'name': 'client_secret'},
           {'annotation': str, 'default': None, 'description': 'A six-character code starting with SM present in the microdeposit sent to the bank account.', 'name': 'descriptor_code'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/verify_microdeposits/update',
  'op_id': 'PostSetupIntentsIntentVerifyMicrodeposits',
  'path': '/v1/setup_intents/{intent}/verify_microdeposits',
  'qparams': [],
  'summary': 'Verify microdeposits on a SetupIntent',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/shipping_rates/list',
  'op_id': 'GetShippingRates',
  'path': '/v1/shipping_rates',
  'qparams': [{'annotation': 'str', 'description': 'Only return shipping rates that are active or inactive.', 'name': 'active'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return shipping rates for the given currency.', 'name': 'currency'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all shipping rates',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.', 'name': 'delivery_estimate'},
           {'annotation': str, 'default': None, 'description': 'The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.', 'name': 'display_name'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Describes a fixed amount to charge for shipping. Must be present if type is `fixed_amount`.', 'name': 'fixed_amount'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or `unspecified`.', 'name': 'tax_behavior'},
           {'annotation': str, 'default': None, 'description': 'A [tax code](https://docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is `txcd_92010001`.', 'name': 'tax_code'},
           {'annotation': str, 'default': None, 'description': 'The type of calculation to use on the shipping rate.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/shipping_rates/create',
  'op_id': 'PostShippingRates',
  'path': '/v1/shipping_rates',
  'qparams': [],
  'summary': 'Create a shipping rate',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/shipping_rates/delete',
  'op_id': 'GetShippingRatesShippingRateToken',
  'path': '/v1/shipping_rates/{shipping_rate_token}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a shipping rate',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether the shipping rate can be used for new purchases. Defaults to `true`.', 'name': 'active'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Describes a fixed amount to charge for shipping. Must be present if type is `fixed_amount`.', 'name': 'fixed_amount'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of `inclusive`, `exclusive`, or `unspecified`.', 'name': 'tax_behavior'}],
  'doc_url': 'https://docs.stripe.com/api/shipping_rates/update',
  'op_id': 'PostShippingRatesShippingRateToken',
  'path': '/v1/shipping_rates/{shipping_rate_token}',
  'qparams': [],
  'summary': 'Update a shipping rate',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The name of the query to update.', 'name': 'name'},
           {'annotation': str, 'default': None, 'description': 'The sql statement to update the specified query statement with. This should be a valid Trino SQL statement that can be run in Sigma.', 'name': 'sql'}],
  'doc_url': 'https://docs.stripe.com/api/saved_queries/update',
  'op_id': 'PostSigmaSavedQueriesId',
  'path': '/v1/sigma/saved_queries/{id}',
  'qparams': [],
  'summary': 'Update an existing Sigma Query',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/scheduled_query_runs/list',
  'op_id': 'GetSigmaScheduledQueryRuns',
  'path': '/v1/sigma/scheduled_query_runs',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all scheduled query runs',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/scheduled_query_runs/delete',
  'op_id': 'GetSigmaScheduledQueryRunsScheduledQueryRun',
  'path': '/v1/sigma/scheduled_query_runs/{scheduled_query_run}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a scheduled query run',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount associated with the source. This is the amount for which the source will be chargeable once ready. Required for `single_use` sources. Not supported for `receiver` type sources, where charge amount may not be specified until funds land.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO code for the currency](https://stripe.com/docs/currencies) associated with the source. This is the currency for which the source will be chargeable once ready.', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'The `Customer` to whom the original source is attached to. Must be set when the original source is not a `Source` (e.g., `Card`).', 'name': 'customer'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The authentication `flow` of the source to create. `flow` is one of `redirect`, `receiver`, `code_verification`, `none`. It is generally inferred unless a type supports multiple flows.', 'name': 'flow'},
           {'annotation': dict, 'default': None, 'description': 'Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.', 'name': 'mandate'},
           {'annotation': dict, 'default': None, 'description': '', 'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The source to share.', 'name': 'original_source'},
           {'annotation': dict, 'default': None, 'description': 'Information about the owner of the payment instrument that may be used or required by particular source types.', 'name': 'owner'},
           {'annotation': dict, 'default': None, 'description': 'Optional parameters for the receiver flow. Can be set only if the source is a receiver (`flow` is `receiver`).', 'name': 'receiver'},
           {'annotation': dict, 'default': None, 'description': 'Parameters required for the redirect flow. Required if the source is authenticated by a redirect (`flow` is `redirect`).', 'name': 'redirect'},
           {'annotation': dict, 'default': None, 'description': 'Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.', 'name': 'source_order'},
           {'annotation': str,
            'default': None,
            'description': "An arbitrary string to be displayed on your customer's statement. As an example, if your website is `RunClub` and the item you're charging for is a race ticket, you may want to specify a `statement_descriptor` of `RunClub 5K race ticket.` While many payment types will display this information, some may not display it at all.",
            'name': 'statement_descriptor'},
           {'annotation': str, 'default': None, 'description': 'An optional token used to create the source. When passed, token properties will override source parameters.', 'name': 'token'},
           {'annotation': str, 'default': None, 'description': 'The `type` of the source to create. Required unless `customer` and `original_source` are specified (see the [Cloning card Sources](https://docs.stripe.com/sources/connect#cloning-card-sources) guide)', 'name': 'type'},
           {'annotation': str, 'default': None, 'description': '', 'name': 'usage'}],
  'doc_url': 'https://docs.stripe.com/api/sources/create',
  'op_id': 'PostSources',
  'path': '/v1/sources',
  'qparams': [],
  'summary': 'Shares a source',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/sources/delete',
  'op_id': 'GetSourcesSource',
  'path': '/v1/sources/{source}',
  'qparams': [{'annotation': 'str', 'description': 'The client secret of the source. Required if a publishable key is used to retrieve the source.', 'name': 'client_secret'}, {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a source',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount associated with the source.', 'name': 'amount'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.', 'name': 'mandate'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': dict, 'default': None, 'description': 'Information about the owner of the payment instrument that may be used or required by particular source types.', 'name': 'owner'},
           {'annotation': dict, 'default': None, 'description': 'Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.', 'name': 'source_order'}],
  'doc_url': 'https://docs.stripe.com/api/sources/update',
  'op_id': 'PostSourcesSource',
  'path': '/v1/sources/{source}',
  'qparams': [],
  'summary': 'Update a source',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/mandate_notifications/delete',
  'op_id': 'GetSourcesSourceMandateNotificationsMandateNotification',
  'path': '/v1/sources/{source}/mandate_notifications/{mandate_notification}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a Source MandateNotification',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/source_transactions/delete',
  'op_id': 'GetSourcesSourceSourceTransactions',
  'path': '/v1/sources/{source}/source_transactions',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': '',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/source_transactions/delete',
  'op_id': 'GetSourcesSourceSourceTransactionsSourceTransaction',
  'path': '/v1/sources/{source}/source_transactions/{source_transaction}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a source transaction',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': list, 'default': None, 'description': 'The values needed to verify the source.', 'name': 'values'}],
  'doc_url': 'https://docs.stripe.com/api/verifys/update',
  'op_id': 'PostSourcesSourceVerify',
  'path': '/v1/sources/{source}/verify',
  'qparams': [],
  'summary': '',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscription_items/list',
  'op_id': 'GetSubscriptionItems',
  'path': '/v1/subscription_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'The ID of the subscription whose items will be retrieved.', 'name': 'subscription'}],
  'summary': 'List all subscription items',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object, 'default': None, 'description': 'The coupons to redeem into discounts for the subscription item.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': "Use `allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA "
                           'Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           "Use `default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice's payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA "
                           'regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.\n'
                           '\n'
                           'Use `pending_if_incomplete` to update the subscription using [pending updates](https://docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](https://docs.stripe.com/billing/pending-updates-reference#supported-attributes).\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was "
                           'the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/changelog/2019-03-14) to learn more.',
            'name': 'payment_behavior'},
           {'annotation': str, 'default': None, 'description': 'The ID of the price object.', 'name': 'price'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object inline.', 'name': 'price_data'},
           {'annotation': str,
            'default': None,
            'description': "Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting `billing_cycle_anchor=now`, or starting a trial), or if an item's `quantity` changes. The default value is `create_prorations`.",
            'name': 'proration_behavior'},
           {'annotation': int, 'default': None, 'description': 'If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](https://api.stripe.com#retrieve_customer_invoice) endpoint.', 'name': 'proration_date'},
           {'annotation': int, 'default': None, 'description': "The quantity you'd like to apply to the subscription item you're creating.", 'name': 'quantity'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the subscription to modify.', 'name': 'subscription'},
           {'annotation': object,
            'default': None,
            'description': 'A list of [Tax Rate](https://docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [`default_tax_rates`](https://docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.',
            'name': 'tax_rates'}],
  'doc_url': 'https://docs.stripe.com/api/subscription_items/create',
  'op_id': 'PostSubscriptionItems',
  'path': '/v1/subscription_items',
  'qparams': [],
  'summary': 'Create a subscription item',
  'verb': 'post'},
 {'data': [{'annotation': bool, 'default': None, 'description': "Delete all usage for the given subscription item. Allowed only when the current plan's `usage_type` is `metered`.", 'name': 'clear_usage'},
           {'annotation': str,
            'default': None,
            'description': "Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting `billing_cycle_anchor=now`, or starting a trial), or if an item's `quantity` changes. The default value is `create_prorations`.",
            'name': 'proration_behavior'},
           {'annotation': int, 'default': None, 'description': 'If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](https://api.stripe.com#retrieve_customer_invoice) endpoint.', 'name': 'proration_date'}],
  'doc_url': 'https://docs.stripe.com/api/subscription_items/delete',
  'op_id': 'DeleteSubscriptionItemsItem',
  'path': '/v1/subscription_items/{item}',
  'qparams': [],
  'summary': 'Delete a subscription item',
  'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/subscription_items/delete', 'op_id': 'GetSubscriptionItemsItem', 'path': '/v1/subscription_items/{item}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a subscription item', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object, 'default': None, 'description': 'The coupons to redeem into discounts for the subscription item.', 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `false` (on-session).', 'name': 'off_session'},
           {'annotation': str,
            'default': None,
            'description': "Use `allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA "
                           'Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           "Use `default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice's payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA "
                           'regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.\n'
                           '\n'
                           'Use `pending_if_incomplete` to update the subscription using [pending updates](https://docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](https://docs.stripe.com/billing/pending-updates-reference#supported-attributes).\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was "
                           'the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/changelog/2019-03-14) to learn more.',
            'name': 'payment_behavior'},
           {'annotation': str, 'default': None, 'description': "The ID of the price object. One of `price` or `price_data` is required. When changing a subscription item's price, `quantity` is set to 1 unless a `quantity` parameter is provided.", 'name': 'price'},
           {'annotation': dict, 'default': None, 'description': 'Data used to generate a new [Price](https://docs.stripe.com/api/prices) object inline. One of `price` or `price_data` is required.', 'name': 'price_data'},
           {'annotation': str,
            'default': None,
            'description': "Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting `billing_cycle_anchor=now`, or starting a trial), or if an item's `quantity` changes. The default value is `create_prorations`.",
            'name': 'proration_behavior'},
           {'annotation': int, 'default': None, 'description': 'If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](https://api.stripe.com#retrieve_customer_invoice) endpoint.', 'name': 'proration_date'},
           {'annotation': int, 'default': None, 'description': "The quantity you'd like to apply to the subscription item you're creating.", 'name': 'quantity'},
           {'annotation': object,
            'default': None,
            'description': 'A list of [Tax Rate](https://docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [`default_tax_rates`](https://docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.',
            'name': 'tax_rates'}],
  'doc_url': 'https://docs.stripe.com/api/subscription_items/update',
  'op_id': 'PostSubscriptionItemsItem',
  'path': '/v1/subscription_items/{item}',
  'qparams': [],
  'summary': 'Update a subscription item',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscription_schedules/list',
  'op_id': 'GetSubscriptionSchedules',
  'path': '/v1/subscription_schedules',
  'qparams': [{'annotation': 'str', 'description': 'Only return subscription schedules that were created canceled the given date interval.', 'name': 'canceled_at'},
              {'annotation': 'str', 'description': 'Only return subscription schedules that completed during the given date interval.', 'name': 'completed_at'},
              {'annotation': 'str', 'description': 'Only return subscription schedules that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return subscription schedules for the given customer.', 'name': 'customer'},
              {'annotation': 'str', 'description': 'Only return subscription schedules for the given account.', 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return subscription schedules that were released during the given date interval.', 'name': 'released_at'},
              {'annotation': 'str', 'description': 'Only return subscription schedules that have not started yet.', 'name': 'scheduled'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all schedules',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Controls how prorations and invoices for subscriptions are calculated and orchestrated.', 'name': 'billing_mode'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the customer to create the subscription schedule for.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the account to create the subscription schedule for.', 'name': 'customer_account'},
           {'annotation': dict, 'default': None, 'description': "Object representing the subscription schedule's default settings.", 'name': 'default_settings'},
           {'annotation': str,
            'default': None,
            'description': 'Behavior of the subscription schedule and underlying subscription when it ends. Possible values are `release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.',
            'name': 'end_behavior'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': "Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription's item(s), set to auto-renew using the subscription's interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a "
                           'subscription schedule with other modifications, we recommend making two separate API calls.',
            'name': 'from_subscription'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': list, 'default': None, 'description': 'List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the `end_date` of one phase will always equal the `start_date` of the next phase.', 'name': 'phases'},
           {'annotation': object, 'default': None, 'description': 'When the subscription schedule starts. We recommend using `now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.', 'name': 'start_date'}],
  'doc_url': 'https://docs.stripe.com/api/subscription_schedules/create',
  'op_id': 'PostSubscriptionSchedules',
  'path': '/v1/subscription_schedules',
  'qparams': [],
  'summary': 'Create a schedule',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/subscription_schedules/delete', 'op_id': 'GetSubscriptionSchedulesSchedule', 'path': '/v1/subscription_schedules/{schedule}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a schedule', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Object representing the subscription schedule's default settings.", 'name': 'default_settings'},
           {'annotation': str,
            'default': None,
            'description': 'Behavior of the subscription schedule and underlying subscription when it ends. Possible values are `release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.',
            'name': 'end_behavior'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': list,
            'default': None,
            'description': 'List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the `end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.',
            'name': 'phases'},
           {'annotation': str, 'default': None, 'description': 'If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is `create_prorations`.', 'name': 'proration_behavior'}],
  'doc_url': 'https://docs.stripe.com/api/subscription_schedules/update',
  'op_id': 'PostSubscriptionSchedulesSchedule',
  'path': '/v1/subscription_schedules/{schedule}',
  'qparams': [],
  'summary': 'Update a schedule',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool, 'default': None, 'description': 'If the subscription schedule is `active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.', 'name': 'invoice_now'},
           {'annotation': bool, 'default': None, 'description': 'If the subscription schedule is `active`, indicates if the cancellation should be prorated. Defaults to `true`.', 'name': 'prorate'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostSubscriptionSchedulesScheduleCancel',
  'path': '/v1/subscription_schedules/{schedule}/cancel',
  'qparams': [],
  'summary': 'Cancel a schedule',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': bool, 'default': None, 'description': 'Keep any cancellation on the subscription that the schedule has set', 'name': 'preserve_cancel_date'}],
  'doc_url': 'https://docs.stripe.com/api/releases/update',
  'op_id': 'PostSubscriptionSchedulesScheduleRelease',
  'path': '/v1/subscription_schedules/{schedule}/release',
  'qparams': [],
  'summary': 'Release a schedule',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/list',
  'op_id': 'GetSubscriptions',
  'path': '/v1/subscriptions',
  'qparams': [{'annotation': 'str', 'description': 'Filter subscriptions by their automatic tax settings.', 'name': 'automatic_tax'},
              {'annotation': 'str', 'description': 'The collection method of the subscriptions to retrieve. Either `charge_automatically` or `send_invoice`.', 'name': 'collection_method'},
              {'annotation': 'str', 'description': 'Only return subscriptions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return subscriptions whose minimum item current_period_end falls within the given date interval.', 'name': 'current_period_end'},
              {'annotation': 'str', 'description': 'Only return subscriptions whose maximum item current_period_start falls within the given date interval.', 'name': 'current_period_start'},
              {'annotation': 'str', 'description': "The ID of the customer whose subscriptions you're retrieving.", 'name': 'customer'},
              {'annotation': 'str', 'description': "The ID of the account representing the customer whose subscriptions you're retrieving.", 'name': 'customer_account'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Filter for subscriptions that contain this recurring price ID.', 'name': 'price'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str',
               'description': 'The status of the subscriptions to retrieve. Passing in a value of `canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete '
                              'payment](https://docs.stripe.com/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.',
               'name': 'status'},
              {'annotation': 'str', 'description': 'Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.', 'name': 'test_clock'}],
  'summary': 'List subscriptions',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.', 'name': 'add_invoice_items'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For "
                           'more information, see the application fees [documentation](https://stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).',
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Automatic tax settings for this subscription.', 'name': 'automatic_tax'},
           {'annotation': int, 'default': None, 'description': "A past timestamp to backdate the subscription's start date to. If set, the first invoice will contain line items for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.", 'name': 'backdate_start_date'},
           {'annotation': int,
            'default': None,
            'description': "A future timestamp in UTC format to anchor the subscription's [billing cycle](https://docs.stripe.com/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for `week` intervals, the day of month for `month` and `year` intervals, and the month of year for "
                           '`year` intervals.',
            'name': 'billing_cycle_anchor'},
           {'annotation': dict, 'default': None, 'description': 'Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals. When provided, the billing_cycle_anchor is set to the next occurrence of the day_of_month at the hour, minute, and second UTC.', 'name': 'billing_cycle_anchor_config'},
           {'annotation': dict, 'default': None, 'description': 'Controls how prorations and invoices for subscriptions are calculated and orchestrated.', 'name': 'billing_mode'},
           {'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object,
            'default': None,
            'description': 'A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using `proration_behavior`. If set during a future period, this will always cause a proration for that period.',
            'name': 'cancel_at'},
           {'annotation': bool, 'default': None, 'description': 'Indicate whether this subscription should cancel at the end of the current period (`current_period_end`). Defaults to `false`.', 'name': 'cancel_at_period_end'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as '
                           '`active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the customer to subscribe.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'The identifier of the account representing the customer to subscribe.', 'name': 'customer_account'},
           {'annotation': int, 'default': None, 'description': 'Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where `collection_method` is set to `send_invoice`.', 'name': 'days_until_due'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over `default_source`. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_payment_method'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If `default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_source'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any subscription item that does not have `tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.', 'name': 'default_tax_rates'},
           {'annotation': str, 'default': None, 'description': "The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.", 'name': 'description'},
           {'annotation': object, 'default': None, 'description': "The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription's customer.", 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 20 subscription items, each with an attached price.', 'name': 'items'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `false` (on-session).', 'name': 'off_session'},
           {'annotation': object, 'default': None, 'description': "The account on behalf of which to charge, for each of the subscription's invoices.", 'name': 'on_behalf_of'},
           {'annotation': str,
            'default': None,
            'description': 'Only applies to subscriptions with `collection_method=charge_automatically`.\n'
                           '\n'
                           "Use `allow_incomplete` to create Subscriptions with `status=incomplete` if the first invoice can't be paid. Creating Subscriptions with this status allows you to manage scenarios where additional customer actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete "
                           'payment. See the [SCA Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           'Use `default_incomplete` to create Subscriptions with `status=incomplete` when the first invoice requires payment, otherwise start as active. Subscriptions transition to `status=active` when successfully confirming the PaymentIntent on the first invoice. This allows simpler management of scenarios where additional customer '
                           'actions are needed to pay a subscription’s invoice, such as failed payments, [SCA regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method. If the PaymentIntent is not confirmed within 23 hours Subscriptions transition to '
                           '`status=incomplete_expired`, which is a terminal state.\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's first invoice can't be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further customer action is needed, this parameter doesn't create a Subscription and returns an error instead. This "
                           'was the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/upgrades#2019-03-14) to learn more.\n'
                           '\n'
                           '`pending_if_incomplete` is only used with updates and cannot be passed when creating a Subscription.\n'
                           '\n'
                           'Subscriptions with `collection_method=send_invoice` are automatically activated regardless of the first Invoice status.',
            'name': 'payment_behavior'},
           {'annotation': dict, 'default': None, 'description': 'Payment settings to pass to invoices created by the subscription.', 'name': 'payment_settings'},
           {'annotation': object, 'default': None, 'description': 'Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](https://docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.', 'name': 'pending_invoice_item_interval'},
           {'annotation': str, 'default': None, 'description': 'Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) resulting from the `billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.', 'name': 'proration_behavior'},
           {'annotation': dict, 'default': None, 'description': "If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.", 'name': 'transfer_data'},
           {'annotation': object,
            'default': None,
            'description': "Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value `now` can be provided to end the customer's trial immediately. Can be at most two years "
                           'from `billing_cycle_anchor`. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) to learn more.',
            'name': 'trial_end'},
           {'annotation': bool,
            'default': None,
            'description': "Indicates if a plan's `trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) "
                           'to learn more.',
            'name': 'trial_from_plan'},
           {'annotation': int,
            'default': None,
            'description': 'Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) to learn more.',
            'name': 'trial_period_days'},
           {'annotation': dict, 'default': None, 'description': 'Settings related to subscription trials.', 'name': 'trial_settings'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/create',
  'op_id': 'PostSubscriptions',
  'path': '/v1/subscriptions',
  'qparams': [],
  'summary': 'Create a subscription',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/searchs/retrieve',
  'op_id': 'GetSubscriptionsSearch',
  'path': '/v1/subscriptions/search',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': "A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.", 'name': 'page'},
              {'annotation': 'str', 'description': 'The search query string. See [search query language](https://docs.stripe.com/search#search-query-language) and the list of supported [query fields for subscriptions](https://docs.stripe.com/search#query-fields-for-subscriptions).', 'name': 'query'}],
  'summary': 'Search subscriptions',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Details about why this subscription was cancelled', 'name': 'cancellation_details'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool, 'default': None, 'description': 'Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to `false`.', 'name': 'invoice_now'},
           {'annotation': bool, 'default': None, 'description': 'Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to `false`.', 'name': 'prorate'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/delete',
  'op_id': 'DeleteSubscriptionsSubscriptionExposedId',
  'path': '/v1/subscriptions/{subscription_exposed_id}',
  'qparams': [],
  'summary': 'Cancel a subscription',
  'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/delete',
  'op_id': 'GetSubscriptionsSubscriptionExposedId',
  'path': '/v1/subscriptions/{subscription_exposed_id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a subscription',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.', 'name': 'add_invoice_items'},
           {'annotation': object,
            'default': None,
            'description': "A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For "
                           'more information, see the application fees [documentation](https://stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).',
            'name': 'application_fee_percent'},
           {'annotation': dict, 'default': None, 'description': 'Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.', 'name': 'automatic_tax'},
           {'annotation': str, 'default': None, 'description': "Either `now` or `unchanged`. Setting the value to `now` resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle [documentation](https://docs.stripe.com/billing/subscriptions/billing-cycle).", 'name': 'billing_cycle_anchor'},
           {'annotation': object, 'default': None, 'description': 'Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.', 'name': 'billing_thresholds'},
           {'annotation': object,
            'default': None,
            'description': 'A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using `proration_behavior`. If set during a future period, this will always cause a proration for that period.',
            'name': 'cancel_at'},
           {'annotation': bool, 'default': None, 'description': 'Indicate whether this subscription should cancel at the end of the current period (`current_period_end`). Defaults to `false`.', 'name': 'cancel_at_period_end'},
           {'annotation': dict, 'default': None, 'description': 'Details about why this subscription was cancelled', 'name': 'cancellation_details'},
           {'annotation': str,
            'default': None,
            'description': 'Either `charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as '
                           '`active`. Defaults to `charge_automatically`.',
            'name': 'collection_method'},
           {'annotation': int, 'default': None, 'description': 'Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where `collection_method` is set to `send_invoice`.', 'name': 'days_until_due'},
           {'annotation': str,
            'default': None,
            'description': "ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over `default_source`. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_payment_method'},
           {'annotation': object,
            'default': None,
            'description': "ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If `default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer's "
                           '[invoice_settings.default_payment_method](https://docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](https://docs.stripe.com/api/customers/object#customer_object-default_source).',
            'name': 'default_source'},
           {'annotation': object, 'default': None, 'description': 'The tax rates that will apply to any subscription item that does not have `tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription. Pass an empty string to remove previously-defined tax rates.', 'name': 'default_tax_rates'},
           {'annotation': object, 'default': None, 'description': "The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.", 'name': 'description'},
           {'annotation': object, 'default': None, 'description': "The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription's customer.", 'name': 'discounts'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'All invoices will be billed using the specified settings.', 'name': 'invoice_settings'},
           {'annotation': list, 'default': None, 'description': 'A list of up to 20 subscription items, each with an attached price.', 'name': 'items'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool, 'default': None, 'description': 'Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to `false` (on-session).', 'name': 'off_session'},
           {'annotation': object, 'default': None, 'description': "The account on behalf of which to charge, for each of the subscription's invoices.", 'name': 'on_behalf_of'},
           {'annotation': object, 'default': None, 'description': 'If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to `paused`. Learn more about [pausing collection](https://docs.stripe.com/billing/subscriptions/pause-payment).', 'name': 'pause_collection'},
           {'annotation': str,
            'default': None,
            'description': "Use `allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription's invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA "
                           'Migration Guide](https://docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.\n'
                           '\n'
                           "Use `default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice's payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA "
                           'regulation](https://docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.\n'
                           '\n'
                           'Use `pending_if_incomplete` to update the subscription using [pending updates](https://docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](https://docs.stripe.com/billing/pending-updates-reference#supported-attributes).\n'
                           '\n'
                           "Use `error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription's invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was "
                           'the default behavior for API versions prior to 2019-03-14. See the [changelog](https://docs.stripe.com/changelog/2019-03-14) to learn more.',
            'name': 'payment_behavior'},
           {'annotation': dict, 'default': None, 'description': 'Payment settings to pass to invoices created by the subscription.', 'name': 'payment_settings'},
           {'annotation': object, 'default': None, 'description': 'Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](https://docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.', 'name': 'pending_invoice_item_interval'},
           {'annotation': str,
            'default': None,
            'description': "Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting `billing_cycle_anchor=now`, or starting a trial), or if an item's `quantity` changes. The default value is `create_prorations`.",
            'name': 'proration_behavior'},
           {'annotation': int,
            'default': None,
            'description': 'If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](https://stripe.com/docs/api/invoices/create_preview) endpoint. `proration_date` can also be used to implement custom proration logic, '
                           'such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.',
            'name': 'proration_date'},
           {'annotation': object, 'default': None, 'description': "If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.", 'name': 'transfer_data'},
           {'annotation': object,
            'default': None,
            'description': 'Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, `trial_end` will override the default trial period of the plan the customer is being subscribed to. The '
                           "`billing_cycle_anchor` will be updated to the `trial_end` value. The special value `now` can be provided to end the customer's trial immediately. Can be at most two years from `billing_cycle_anchor`.",
            'name': 'trial_end'},
           {'annotation': bool,
            'default': None,
            'description': "Indicates if a plan's `trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](https://docs.stripe.com/billing/subscriptions/trials) "
                           'to learn more.',
            'name': 'trial_from_plan'},
           {'annotation': dict, 'default': None, 'description': 'Settings related to subscription trials.', 'name': 'trial_settings'}],
  'doc_url': 'https://docs.stripe.com/api/subscriptions/update',
  'op_id': 'PostSubscriptionsSubscriptionExposedId',
  'path': '/v1/subscriptions/{subscription_exposed_id}',
  'qparams': [],
  'summary': 'Update a subscription',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/discounts/delete', 'op_id': 'DeleteSubscriptionsSubscriptionExposedIdDiscount', 'path': '/v1/subscriptions/{subscription_exposed_id}/discount', 'qparams': [], 'summary': 'Delete a subscription discount', 'verb': 'delete'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Controls how prorations and invoices for subscriptions are calculated and orchestrated.', 'name': 'billing_mode'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/migrates/update',
  'op_id': 'PostSubscriptionsSubscriptionMigrate',
  'path': '/v1/subscriptions/{subscription}/migrate',
  'qparams': [],
  'summary': 'Migrate a subscription',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The billing cycle anchor that applies when the subscription is resumed. Either `now` or `unchanged`. The default is `now`. For more information, see the billing cycle [documentation](https://docs.stripe.com/billing/subscriptions/billing-cycle).', 'name': 'billing_cycle_anchor'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'Determines how to handle [prorations](https://docs.stripe.com/billing/subscriptions/prorations) resulting from the `billing_cycle_anchor` being `unchanged`. When the `billing_cycle_anchor` is set to `now` (default value), no prorations are generated. If no value is passed, the default is `create_prorations`.',
            'name': 'proration_behavior'},
           {'annotation': int, 'default': None, 'description': 'If set, prorations will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](https://stripe.com/docs/api/invoices/create_preview) endpoint.', 'name': 'proration_date'}],
  'doc_url': 'https://docs.stripe.com/api/resumes/update',
  'op_id': 'PostSubscriptionsSubscriptionResume',
  'path': '/v1/subscriptions/{subscription}/resume',
  'qparams': [],
  'summary': 'Resume a subscription',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/finds/retrieve',
  'op_id': 'GetTaxAssociationsFind',
  'path': '/v1/tax/associations/find',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': 'str', 'description': 'Valid [PaymentIntent](https://docs.stripe.com/api/payment_intents/object) id', 'name': 'payment_intent'}],
  'summary': 'Find a Tax Association',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': "The ID of an existing customer to use for this calculation. If provided, the customer's address and tax IDs are copied to `customer_details`.", 'name': 'customer'},
           {'annotation': dict, 'default': None, 'description': 'Details about the customer, including address and tax IDs.', 'name': 'customer_details'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list, 'default': None, 'description': 'A list of items the customer is purchasing.', 'name': 'line_items'},
           {'annotation': dict, 'default': None, 'description': 'Details about the address from which the goods are being shipped.', 'name': 'ship_from_details'},
           {'annotation': dict, 'default': None, 'description': 'Shipping cost details to be used for the calculation.', 'name': 'shipping_cost'},
           {'annotation': int, 'default': None, 'description': 'Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.', 'name': 'tax_date'}],
  'doc_url': 'https://docs.stripe.com/api/calculations/create',
  'op_id': 'PostTaxCalculations',
  'path': '/v1/tax/calculations',
  'qparams': [],
  'summary': 'Create a Tax Calculation',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/calculations/delete', 'op_id': 'GetTaxCalculationsCalculation', 'path': '/v1/tax/calculations/{calculation}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Tax Calculation', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/line_items/delete',
  'op_id': 'GetTaxCalculationsCalculationLineItems',
  'path': '/v1/tax/calculations/{calculation}/line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a calculation's line items",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/registrations/list',
  'op_id': 'GetTaxRegistrations',
  'path': '/v1/tax/registrations',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'The status of the Tax Registration.', 'name': 'status'}],
  'summary': 'List registrations',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Time at which the Tax Registration becomes active. It can be either `now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.', 'name': 'active_from'},
           {'annotation': str, 'default': None, 'description': 'Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).', 'name': 'country'},
           {'annotation': dict, 'default': None, 'description': 'Specific options for a registration in the specified `country`.', 'name': 'country_options'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.', 'name': 'expires_at'}],
  'doc_url': 'https://docs.stripe.com/api/registrations/create',
  'op_id': 'PostTaxRegistrations',
  'path': '/v1/tax/registrations',
  'qparams': [],
  'summary': 'Create a registration',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/registrations/delete', 'op_id': 'GetTaxRegistrationsId', 'path': '/v1/tax/registrations/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a registration', 'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'Time at which the registration becomes active. It can be either `now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.', 'name': 'active_from'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either `now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.', 'name': 'expires_at'}],
  'doc_url': 'https://docs.stripe.com/api/registrations/update',
  'op_id': 'PostTaxRegistrationsId',
  'path': '/v1/tax/registrations/{id}',
  'qparams': [],
  'summary': 'Update a registration',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/settings/list', 'op_id': 'GetTaxSettings', 'path': '/v1/tax/settings', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve settings', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Default configuration to be used on Stripe Tax calculations.', 'name': 'defaults'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'The place where your business is located.', 'name': 'head_office'}],
  'doc_url': 'https://docs.stripe.com/api/settings/create',
  'op_id': 'PostTaxSettings',
  'path': '/v1/tax/settings',
  'qparams': [],
  'summary': 'Update settings',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'Tax Calculation ID to be used as input when creating the transaction.', 'name': 'calculation'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': int,
            'default': None,
            'description': 'The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports. The timestamp must fall within the `tax_date` and the current time, unless the `tax_date` is scheduled in advance. Defaults to the current time.',
            'name': 'posted_at'},
           {'annotation': str, 'default': None, 'description': "A custom order or sale identifier, such as 'myOrder_123'. Must be unique across all transactions, including reversals.", 'name': 'reference'}],
  'doc_url': 'https://docs.stripe.com/api/create_from_calculations/create',
  'op_id': 'PostTaxTransactionsCreateFromCalculation',
  'path': '/v1/tax/transactions/create_from_calculation',
  'qparams': [],
  'summary': 'Create a transaction from a calculation',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'A flat amount to reverse across the entire transaction, in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) in negative. This value represents the total amount to refund from the transaction, including taxes.', 'name': 'flat_amount'},
           {'annotation': list, 'default': None, 'description': 'The line item amounts to reverse.', 'name': 'line_items'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'If `partial`, the provided line item or shipping cost amounts are reversed. If `full`, the original transaction is fully reversed.', 'name': 'mode'},
           {'annotation': str, 'default': None, 'description': 'The ID of the Transaction to partially or fully reverse.', 'name': 'original_transaction'},
           {'annotation': str, 'default': None, 'description': 'A custom identifier for this reversal, such as `myOrder_123-refund_1`, which must be unique across all transactions. The reference helps identify this reversal transaction in exported [tax reports](https://docs.stripe.com/tax/reports).', 'name': 'reference'},
           {'annotation': dict, 'default': None, 'description': 'The shipping cost to reverse.', 'name': 'shipping_cost'}],
  'doc_url': 'https://docs.stripe.com/api/create_reversals/create',
  'op_id': 'PostTaxTransactionsCreateReversal',
  'path': '/v1/tax/transactions/create_reversal',
  'qparams': [],
  'summary': 'Create a reversal transaction',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/transactions/delete', 'op_id': 'GetTaxTransactionsTransaction', 'path': '/v1/tax/transactions/{transaction}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a transaction', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/line_items/delete',
  'op_id': 'GetTaxTransactionsTransactionLineItems',
  'path': '/v1/tax/transactions/{transaction}/line_items',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': "Retrieve a transaction's line items",
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/tax_codes/list',
  'op_id': 'GetTaxCodes',
  'path': '/v1/tax_codes',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all tax codes',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_codes/delete', 'op_id': 'GetTaxCodesId', 'path': '/v1/tax_codes/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a tax code', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/tax_ids/list',
  'op_id': 'GetTaxIds',
  'path': '/v1/tax_ids',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The account or customer the tax ID belongs to. Defaults to `owner[type]=self`.', 'name': 'owner'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all tax IDs',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'The account or customer the tax ID belongs to. Defaults to `owner[type]=self`.', 'name': 'owner'},
           {'annotation': str,
            'default': None,
            'description': 'Type of the tax ID, one of `ad_nrt`, `ae_trn`, `al_tin`, `am_tin`, `ao_tin`, `ar_cuit`, `au_abn`, `au_arn`, `aw_tin`, `az_tin`, `ba_tin`, `bb_tin`, `bd_bin`, `bf_ifu`, `bg_uic`, `bh_vat`, `bj_ifu`, `bo_tin`, `br_cnpj`, `br_cpf`, `bs_tin`, `by_tin`, `ca_bn`, `ca_gst_hst`, `ca_pst_bc`, `ca_pst_mb`, `ca_pst_sk`, `ca_qst`, `cd_nif`, '
                           '`ch_uid`, `ch_vat`, `cl_tin`, `cm_niu`, `cn_tin`, `co_nit`, `cr_tin`, `cv_nif`, `de_stn`, `do_rcn`, `ec_ruc`, `eg_tin`, `es_cif`, `et_tin`, `eu_oss_vat`, `eu_vat`, `gb_vat`, `ge_vat`, `gn_nif`, `hk_br`, `hr_oib`, `hu_tin`, `id_npwp`, `il_vat`, `in_gst`, `is_vat`, `jp_cn`, `jp_rn`, `jp_trn`, `ke_pin`, `kg_tin`, `kh_tin`, '
                           '`kr_brn`, `kz_bin`, `la_tin`, `li_uid`, `li_vat`, `ma_vat`, `md_vat`, `me_pib`, `mk_vat`, `mr_nif`, `mx_rfc`, `my_frp`, `my_itn`, `my_sst`, `ng_tin`, `no_vat`, `no_voec`, `np_pan`, `nz_gst`, `om_vat`, `pe_ruc`, `ph_tin`, `pl_nip`, `ro_tin`, `rs_pib`, `ru_inn`, `ru_kpp`, `sa_vat`, `sg_gst`, `sg_uen`, `si_tin`, `sn_ninea`, '
                           '`sr_fin`, `sv_nit`, `th_vat`, `tj_tin`, `tr_tin`, `tw_vat`, `tz_vat`, `ua_vat`, `ug_tin`, `us_ein`, `uy_ruc`, `uz_tin`, `uz_vat`, `ve_rif`, `vn_tin`, `za_vat`, `zm_tin`, or `zw_tin`',
            'name': 'type'},
           {'annotation': str, 'default': None, 'description': 'Value of the tax ID.', 'name': 'value'}],
  'doc_url': 'https://docs.stripe.com/api/tax_ids/create',
  'op_id': 'PostTaxIds',
  'path': '/v1/tax_ids',
  'qparams': [],
  'summary': 'Create a tax ID',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_ids/delete', 'op_id': 'DeleteTaxIdsId', 'path': '/v1/tax_ids/{id}', 'qparams': [], 'summary': 'Delete a tax ID', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_ids/delete', 'op_id': 'GetTaxIdsId', 'path': '/v1/tax_ids/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a tax ID', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/tax_rates/list',
  'op_id': 'GetTaxRates',
  'path': '/v1/tax_rates',
  'qparams': [{'annotation': 'str', 'description': 'Optional flag to filter by tax rates that are either active or inactive (archived).', 'name': 'active'},
              {'annotation': 'str', 'description': 'Optional range for filtering created date.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Optional flag to filter by tax rates that are inclusive (or those that are not inclusive).', 'name': 'inclusive'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all tax rates',
  'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.', 'name': 'active'},
           {'annotation': str, 'default': None, 'description': 'Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).', 'name': 'country'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': 'The display name of the tax rate, which will be shown to users.', 'name': 'display_name'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': bool, 'default': None, 'description': 'This specifies if the tax rate is inclusive or exclusive.', 'name': 'inclusive'},
           {'annotation': str, 'default': None, 'description': 'The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.', 'name': 'jurisdiction'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': int, 'default': None, 'description': 'This represents the tax rate percent out of 100.', 'name': 'percentage'},
           {'annotation': str, 'default': None, 'description': '[ISO 3166-2 subdivision code](https://en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, "NY" for New York, United States.', 'name': 'state'},
           {'annotation': str, 'default': None, 'description': 'The high-level tax type, such as `vat` or `sales_tax`.', 'name': 'tax_type'}],
  'doc_url': 'https://docs.stripe.com/api/tax_rates/create',
  'op_id': 'PostTaxRates',
  'path': '/v1/tax_rates',
  'qparams': [],
  'summary': 'Create a tax rate',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tax_rates/delete', 'op_id': 'GetTaxRatesTaxRate', 'path': '/v1/tax_rates/{tax_rate}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a tax rate', 'verb': 'get'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.', 'name': 'active'},
           {'annotation': str, 'default': None, 'description': 'Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).', 'name': 'country'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': 'The display name of the tax rate, which will be shown to users.', 'name': 'display_name'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.', 'name': 'jurisdiction'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': '[ISO 3166-2 subdivision code](https://en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, "NY" for New York, United States.', 'name': 'state'},
           {'annotation': str, 'default': None, 'description': 'The high-level tax type, such as `vat` or `sales_tax`.', 'name': 'tax_type'}],
  'doc_url': 'https://docs.stripe.com/api/tax_rates/update',
  'op_id': 'PostTaxRatesTaxRate',
  'path': '/v1/tax_rates/{tax_rate}',
  'qparams': [],
  'summary': 'Update a tax rate',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/configurations/list',
  'op_id': 'GetTerminalConfigurations',
  'path': '/v1/terminal/configurations',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'if present, only return the account default or non-default configurations.', 'name': 'is_account_default'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all Configurations',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'An object containing device type specific settings for BBPOS WisePad 3 readers.', 'name': 'bbpos_wisepad3'},
           {'annotation': dict, 'default': None, 'description': 'An object containing device type specific settings for BBPOS WisePOS E readers.', 'name': 'bbpos_wisepos_e'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Name of the configuration', 'name': 'name'},
           {'annotation': object, 'default': None, 'description': 'Configurations for collecting transactions offline.', 'name': 'offline'},
           {'annotation': dict, 'default': None, 'description': 'Reboot time settings for readers. that support customized reboot time configuration.', 'name': 'reboot_window'},
           {'annotation': dict, 'default': None, 'description': 'An object containing device type specific settings for Stripe S700 readers.', 'name': 'stripe_s700'},
           {'annotation': object, 'default': None, 'description': 'Tipping configurations for readers that support on-reader tips.', 'name': 'tipping'},
           {'annotation': dict, 'default': None, 'description': 'An object containing device type specific settings for Verifone P400 readers.', 'name': 'verifone_p400'},
           {'annotation': object, 'default': None, 'description': 'Configurations for connecting to a WiFi network.', 'name': 'wifi'}],
  'doc_url': 'https://docs.stripe.com/api/configurations/create',
  'op_id': 'PostTerminalConfigurations',
  'path': '/v1/terminal/configurations',
  'qparams': [],
  'summary': 'Create a Configuration',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/configurations/delete', 'op_id': 'DeleteTerminalConfigurationsConfiguration', 'path': '/v1/terminal/configurations/{configuration}', 'qparams': [], 'summary': 'Delete a Configuration', 'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/configurations/delete',
  'op_id': 'GetTerminalConfigurationsConfiguration',
  'path': '/v1/terminal/configurations/{configuration}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a Configuration',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'An object containing device type specific settings for BBPOS WisePad 3 readers.', 'name': 'bbpos_wisepad3'},
           {'annotation': object, 'default': None, 'description': 'An object containing device type specific settings for BBPOS WisePOS E readers.', 'name': 'bbpos_wisepos_e'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Name of the configuration', 'name': 'name'},
           {'annotation': object, 'default': None, 'description': 'Configurations for collecting transactions offline.', 'name': 'offline'},
           {'annotation': object, 'default': None, 'description': 'Reboot time settings for readers. that support customized reboot time configuration.', 'name': 'reboot_window'},
           {'annotation': object, 'default': None, 'description': 'An object containing device type specific settings for Stripe S700 readers.', 'name': 'stripe_s700'},
           {'annotation': object, 'default': None, 'description': 'Tipping configurations for readers. supporting on-reader tips', 'name': 'tipping'},
           {'annotation': object, 'default': None, 'description': 'An object containing device type specific settings for Verifone P400 readers.', 'name': 'verifone_p400'},
           {'annotation': object, 'default': None, 'description': 'Configurations for connecting to a WiFi network.', 'name': 'wifi'}],
  'doc_url': 'https://docs.stripe.com/api/configurations/update',
  'op_id': 'PostTerminalConfigurationsConfiguration',
  'path': '/v1/terminal/configurations/{configuration}',
  'qparams': [],
  'summary': 'Update a Configuration',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': 'The id of the location that this connection token is scoped to. If specified the connection token will only be usable with readers assigned to that location, otherwise the connection token will be usable with all readers. Note that location scoping only applies to internet-connected readers. For more details, see [the docs on '
                           'scoping connection tokens](https://docs.stripe.com/terminal/fleet/locations-and-zones?dashboard-or-api=api#connection-tokens).',
            'name': 'location'}],
  'doc_url': 'https://docs.stripe.com/api/connection_tokens/create',
  'op_id': 'PostTerminalConnectionTokens',
  'path': '/v1/terminal/connection_tokens',
  'qparams': [],
  'summary': 'Create a Connection Token',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/locations/list',
  'op_id': 'GetTerminalLocations',
  'path': '/v1/terminal/locations',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all Locations',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'The full address of the location.', 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': 'The Kana variation of the full address of the location (Japan only).', 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': 'The Kanji variation of the full address of the location (Japan only).', 'name': 'address_kanji'},
           {'annotation': str, 'default': None, 'description': 'The ID of a configuration that will be used to customize all readers in this location.', 'name': 'configuration_overrides'},
           {'annotation': str, 'default': None, 'description': 'A name for the location. Maximum length is 1000 characters.', 'name': 'display_name'},
           {'annotation': str, 'default': None, 'description': 'The Kana variation of the name for the location (Japan only). Maximum length is 1000 characters.', 'name': 'display_name_kana'},
           {'annotation': str, 'default': None, 'description': 'The Kanji variation of the name for the location (Japan only). Maximum length is 1000 characters.', 'name': 'display_name_kanji'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The phone number for the location.', 'name': 'phone'}],
  'doc_url': 'https://docs.stripe.com/api/locations/create',
  'op_id': 'PostTerminalLocations',
  'path': '/v1/terminal/locations',
  'qparams': [],
  'summary': 'Create a Location',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/locations/delete', 'op_id': 'DeleteTerminalLocationsLocation', 'path': '/v1/terminal/locations/{location}', 'qparams': [], 'summary': 'Delete a Location', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/locations/delete', 'op_id': 'GetTerminalLocationsLocation', 'path': '/v1/terminal/locations/{location}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Location', 'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "The full address of the location. You can't change the location's `country`. If you need to modify the `country` field, create a new `Location` object and re-register any existing readers to that location.", 'name': 'address'},
           {'annotation': dict, 'default': None, 'description': 'The Kana variation of the full address of the location (Japan only).', 'name': 'address_kana'},
           {'annotation': dict, 'default': None, 'description': 'The Kanji variation of the full address of the location (Japan only).', 'name': 'address_kanji'},
           {'annotation': object, 'default': None, 'description': 'The ID of a configuration that will be used to customize all readers in this location.', 'name': 'configuration_overrides'},
           {'annotation': object, 'default': None, 'description': 'A name for the location.', 'name': 'display_name'},
           {'annotation': object, 'default': None, 'description': 'The Kana variation of the name for the location (Japan only).', 'name': 'display_name_kana'},
           {'annotation': object, 'default': None, 'description': 'The Kanji variation of the name for the location (Japan only).', 'name': 'display_name_kanji'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The phone number for the location.', 'name': 'phone'}],
  'doc_url': 'https://docs.stripe.com/api/locations/update',
  'op_id': 'PostTerminalLocationsLocation',
  'path': '/v1/terminal/locations/{location}',
  'qparams': [],
  'summary': 'Update a Location',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Specific fields needed to generate the desired link type.', 'name': 'link_options'},
           {'annotation': str, 'default': None, 'description': 'The type of link being generated.', 'name': 'link_type'},
           {'annotation': str, 'default': None, 'description': 'Stripe account ID to generate the link for.', 'name': 'on_behalf_of'}],
  'doc_url': 'https://docs.stripe.com/api/onboarding_links/create',
  'op_id': 'PostTerminalOnboardingLinks',
  'path': '/v1/terminal/onboarding_links',
  'qparams': [],
  'summary': 'Create an Onboarding Link',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/readers/list',
  'op_id': 'GetTerminalReaders',
  'path': '/v1/terminal/readers',
  'qparams': [{'annotation': 'str', 'description': 'Filters readers by device type', 'name': 'device_type'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'A location ID to filter the response list to only readers at the specific location', 'name': 'location'},
              {'annotation': 'str', 'description': 'Filters readers by serial number', 'name': 'serial_number'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'A status filter to filter readers to only offline or online readers', 'name': 'status'}],
  'summary': 'List all Readers',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.', 'name': 'label'},
           {'annotation': str, 'default': None, 'description': 'The location to assign the reader to.', 'name': 'location'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'A code generated by the reader used for registering to an account.', 'name': 'registration_code'}],
  'doc_url': 'https://docs.stripe.com/api/readers/create',
  'op_id': 'PostTerminalReaders',
  'path': '/v1/terminal/readers',
  'qparams': [],
  'summary': 'Create a Reader',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/readers/delete', 'op_id': 'DeleteTerminalReadersReader', 'path': '/v1/terminal/readers/{reader}', 'qparams': [], 'summary': 'Delete a Reader', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/readers/delete', 'op_id': 'GetTerminalReadersReader', 'path': '/v1/terminal/readers/{reader}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Reader', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object, 'default': None, 'description': 'The new label of the reader.', 'name': 'label'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/readers/update',
  'op_id': 'PostTerminalReadersReader',
  'path': '/v1/terminal/readers/{reader}',
  'qparams': [],
  'summary': 'Update a Reader',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancel_actions/update',
  'op_id': 'PostTerminalReadersReaderCancelAction',
  'path': '/v1/terminal/readers/{reader}/cancel_action',
  'qparams': [],
  'summary': 'Cancel the current reader action',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': list, 'default': None, 'description': 'List of inputs to be collected from the customer using the Reader. Maximum 5 inputs.', 'name': 'inputs'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/collect_inputs/update',
  'op_id': 'PostTerminalReadersReaderCollectInputs',
  'path': '/v1/terminal/readers/{reader}/collect_inputs',
  'qparams': [],
  'summary': 'Collect inputs using a Reader',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Configuration overrides for this collection, such as tipping, surcharging, and customer cancellation settings.', 'name': 'collect_config'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The ID of the PaymentIntent to collect a payment method for.', 'name': 'payment_intent'}],
  'doc_url': 'https://docs.stripe.com/api/collect_payment_methods/update',
  'op_id': 'PostTerminalReadersReaderCollectPaymentMethod',
  'path': '/v1/terminal/readers/{reader}/collect_payment_method',
  'qparams': [],
  'summary': 'Hand off a PaymentIntent to a Reader and collect card details',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Configuration overrides for this confirmation, such as surcharge settings and return URL.', 'name': 'confirm_config'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The ID of the PaymentIntent to confirm.', 'name': 'payment_intent'}],
  'doc_url': 'https://docs.stripe.com/api/confirm_payment_intents/update',
  'op_id': 'PostTerminalReadersReaderConfirmPaymentIntent',
  'path': '/v1/terminal/readers/{reader}/confirm_payment_intent',
  'qparams': [],
  'summary': 'Confirm a PaymentIntent on the Reader',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The ID of the PaymentIntent to process on the reader.', 'name': 'payment_intent'},
           {'annotation': dict, 'default': None, 'description': 'Configuration overrides for this transaction, such as tipping and customer cancellation settings.', 'name': 'process_config'}],
  'doc_url': 'https://docs.stripe.com/api/process_payment_intents/update',
  'op_id': 'PostTerminalReadersReaderProcessPaymentIntent',
  'path': '/v1/terminal/readers/{reader}/process_payment_intent',
  'qparams': [],
  'summary': 'Hand-off a PaymentIntent to a Reader',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.', 'name': 'allow_redisplay'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Configuration overrides for this setup, such as MOTO and customer cancellation settings.', 'name': 'process_config'},
           {'annotation': str, 'default': None, 'description': 'The ID of the SetupIntent to process on the reader.', 'name': 'setup_intent'}],
  'doc_url': 'https://docs.stripe.com/api/process_setup_intents/update',
  'op_id': 'PostTerminalReadersReaderProcessSetupIntent',
  'path': '/v1/terminal/readers/{reader}/process_setup_intent',
  'qparams': [],
  'summary': 'Hand-off a SetupIntent to a Reader',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer in __cents__ representing how much of this charge to refund.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'ID of the Charge to refund.', 'name': 'charge'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'ID of the PaymentIntent to refund.', 'name': 'payment_intent'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the '
                           'application that created the charge.',
            'name': 'refund_application_fee'},
           {'annotation': dict, 'default': None, 'description': 'Configuration overrides for this refund, such as customer cancellation settings.', 'name': 'refund_payment_config'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.',
            'name': 'reverse_transfer'}],
  'doc_url': 'https://docs.stripe.com/api/refund_payments/update',
  'op_id': 'PostTerminalReadersReaderRefundPayment',
  'path': '/v1/terminal/readers/{reader}/refund_payment',
  'qparams': [],
  'summary': 'Refund a Charge or a PaymentIntent in-person',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Cart details to display on the reader screen, including line items, amounts, and currency.', 'name': 'cart'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'Type of information to display. Only `cart` is currently supported.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/set_reader_displays/update',
  'op_id': 'PostTerminalReadersReaderSetReaderDisplay',
  'path': '/v1/terminal/readers/{reader}/set_reader_display',
  'qparams': [],
  'summary': 'Set reader display',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'ID of an existing PaymentMethod.', 'name': 'payment_method'},
           {'annotation': dict, 'default': None, 'description': 'If provided, this hash will be used to create a PaymentMethod.', 'name': 'payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment-method-specific configuration for this ConfirmationToken.', 'name': 'payment_method_options'},
           {'annotation': str, 'default': None, 'description': 'Return URL used to confirm the Intent.', 'name': 'return_url'},
           {'annotation': str,
            'default': None,
            'description': "Indicates that you intend to make future payments with this ConfirmationToken's payment method.\n"
                           '\n'
                           "The presence of this property will [attach the payment method](https://docs.stripe.com/payments/save-during-payment) to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.",
            'name': 'setup_future_usage'},
           {'annotation': dict, 'default': None, 'description': 'Shipping information for this ConfirmationToken.', 'name': 'shipping'}],
  'doc_url': 'https://docs.stripe.com/api/confirmation_tokens/create',
  'op_id': 'PostTestHelpersConfirmationTokens',
  'path': '/v1/test_helpers/confirmation_tokens',
  'qparams': [],
  'summary': 'Create a test Confirmation Token',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount to be used for this test cash balance transaction. A positive integer representing how much to fund in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to fund $1.00 or 100 to fund ¥100, a zero-decimal currency).', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str,
            'default': None,
            'description': "A description of the test funding. This simulates free-text references supplied by customers when making bank transfers to their cash balance. You can use this to test how Stripe's [reconciliation algorithm](https://docs.stripe.com/payments/customer-balance/reconciliation) applies to different user inputs.",
            'name': 'reference'}],
  'doc_url': 'https://docs.stripe.com/api/fund_cash_balances/update',
  'op_id': 'PostTestHelpersCustomersCustomerFundCashBalance',
  'path': '/v1/test_helpers/customers/{customer}/fund_cash_balance',
  'qparams': [],
  'summary': 'Fund a test mode cash balance',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': "The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card's currency, and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).", 'name': 'amount'},
           {'annotation': dict, 'default': None, 'description': 'Detailed breakdown of amount components. These amounts are denominated in `currency` and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'amount_details'},
           {'annotation': str, 'default': None, 'description': 'How the card details were provided. Defaults to online.', 'name': 'authorization_method'},
           {'annotation': str, 'default': None, 'description': 'Card associated with this authorization.', 'name': 'card'},
           {'annotation': str, 'default': None, 'description': 'The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Fleet-specific information for authorizations using Fleet cards.', 'name': 'fleet'},
           {'annotation': str, 'default': None, 'description': 'Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.', 'name': 'fraud_disputability_likelihood'},
           {'annotation': dict, 'default': None, 'description': 'Information about fuel that was purchased with this transaction.', 'name': 'fuel'},
           {'annotation': bool, 'default': None, 'description': 'If set `true`, you may provide [amount](https://docs.stripe.com/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.', 'name': 'is_amount_controllable'},
           {'annotation': int, 'default': None, 'description': 'The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'merchant_amount'},
           {'annotation': str, 'default': None, 'description': 'The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'merchant_currency'},
           {'annotation': dict, 'default': None, 'description': 'Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.', 'name': 'merchant_data'},
           {'annotation': dict, 'default': None, 'description': 'Details about the authorization, such as identifiers, set by the card network.', 'name': 'network_data'},
           {'annotation': dict, 'default': None, 'description': 'Stripe’s assessment of the fraud risk for this authorization.', 'name': 'risk_assessment'},
           {'annotation': dict, 'default': None, 'description': 'Verifications that Stripe performed on information that the cardholder provided to the merchant.', 'name': 'verification_data'},
           {'annotation': str, 'default': None, 'description': 'The digital wallet used for this transaction. One of `apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.', 'name': 'wallet'}],
  'doc_url': 'https://docs.stripe.com/api/authorizations/create',
  'op_id': 'PostTestHelpersIssuingAuthorizations',
  'path': '/v1/test_helpers/issuing/authorizations',
  'qparams': [],
  'summary': 'Create a test-mode authorization',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'capture_amount'},
           {'annotation': bool, 'default': None, 'description': 'Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.', 'name': 'close_authorization'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Additional purchase information that is optionally provided by the merchant.', 'name': 'purchase_details'}],
  'doc_url': 'https://docs.stripe.com/api/captures/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationCapture',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/capture',
  'qparams': [],
  'summary': 'Capture a test-mode authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/expires/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationExpire',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/expire',
  'qparams': [],
  'summary': 'Expire a test-mode authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'final_amount'},
           {'annotation': dict, 'default': None, 'description': 'Fleet-specific information for authorizations using Fleet cards.', 'name': 'fleet'},
           {'annotation': dict, 'default': None, 'description': 'Information about fuel that was purchased with this transaction.', 'name': 'fuel'}],
  'doc_url': 'https://docs.stripe.com/api/finalize_amounts/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationFinalizeAmount',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/finalize_amount',
  'qparams': [],
  'summary': "Finalize a test-mode authorization's amount",
  'verb': 'post'},
 {'data': [{'annotation': bool, 'default': None, 'description': 'Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).', 'name': 'confirmed'}, {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/responds/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationFraudChallengesRespond',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/fraud_challenges/respond',
  'qparams': [],
  'summary': 'Respond to fraud challenge',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The amount to increment the authorization by. This amount is in the authorization currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'increment_amount'},
           {'annotation': bool, 'default': None, 'description': 'If set `true`, you may provide [amount](https://docs.stripe.com/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.', 'name': 'is_amount_controllable'}],
  'doc_url': 'https://docs.stripe.com/api/increments/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationIncrement',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/increment',
  'qparams': [],
  'summary': 'Increment a test-mode authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The amount to reverse from the authorization. If not provided, the full amount of the authorization will be reversed. This amount is in the authorization currency and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'reverse_amount'}],
  'doc_url': 'https://docs.stripe.com/api/reverses/update',
  'op_id': 'PostTestHelpersIssuingAuthorizationsAuthorizationReverse',
  'path': '/v1/test_helpers/issuing/authorizations/{authorization}/reverse',
  'qparams': [],
  'summary': 'Reverse a test-mode authorization',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/delivers/update',
  'op_id': 'PostTestHelpersIssuingCardsCardShippingDeliver',
  'path': '/v1/test_helpers/issuing/cards/{card}/shipping/deliver',
  'qparams': [],
  'summary': 'Deliver a testmode card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/fails/update',
  'op_id': 'PostTestHelpersIssuingCardsCardShippingFail',
  'path': '/v1/test_helpers/issuing/cards/{card}/shipping/fail',
  'qparams': [],
  'summary': 'Fail a testmode card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/returns/update',
  'op_id': 'PostTestHelpersIssuingCardsCardShippingReturn',
  'path': '/v1/test_helpers/issuing/cards/{card}/shipping/return',
  'qparams': [],
  'summary': 'Return a testmode card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/ships/update',
  'op_id': 'PostTestHelpersIssuingCardsCardShippingShip',
  'path': '/v1/test_helpers/issuing/cards/{card}/shipping/ship',
  'qparams': [],
  'summary': 'Ship a testmode card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/submits/update',
  'op_id': 'PostTestHelpersIssuingCardsCardShippingSubmit',
  'path': '/v1/test_helpers/issuing/cards/{card}/shipping/submit',
  'qparams': [],
  'summary': 'Submit a testmode card',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/activates/update',
  'op_id': 'PostTestHelpersIssuingPersonalizationDesignsPersonalizationDesignActivate',
  'path': '/v1/test_helpers/issuing/personalization_designs/{personalization_design}/activate',
  'qparams': [],
  'summary': 'Activate a testmode personalization design',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/deactivates/update',
  'op_id': 'PostTestHelpersIssuingPersonalizationDesignsPersonalizationDesignDeactivate',
  'path': '/v1/test_helpers/issuing/personalization_designs/{personalization_design}/deactivate',
  'qparams': [],
  'summary': 'Deactivate a testmode personalization design',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'The reason(s) the personalization design was rejected.', 'name': 'rejection_reasons'}],
  'doc_url': 'https://docs.stripe.com/api/rejects/update',
  'op_id': 'PostTestHelpersIssuingPersonalizationDesignsPersonalizationDesignReject',
  'path': '/v1/test_helpers/issuing/personalization_designs/{personalization_design}/reject',
  'qparams': [],
  'summary': 'Reject a testmode personalization design',
  'verb': 'post'},
 {'data': [{'annotation': str, 'default': None, 'description': 'The Bank Identification Number reflecting this settlement record.', 'name': 'bin'},
           {'annotation': int, 'default': None, 'description': "The date that the transactions are cleared and posted to user's accounts.", 'name': 'clearing_date'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The total interchange received as reimbursement for the transactions.', 'name': 'interchange_fees_amount'},
           {'annotation': int, 'default': None, 'description': 'The total net amount required to settle with the network.', 'name': 'net_total_amount'},
           {'annotation': str, 'default': None, 'description': 'The card network for this settlement. One of ["visa", "maestro"]', 'name': 'network'},
           {'annotation': str, 'default': None, 'description': 'The Settlement Identification Number assigned by the network.', 'name': 'network_settlement_identifier'},
           {'annotation': int, 'default': None, 'description': 'The total transaction amount reflected in this settlement.', 'name': 'transaction_amount'},
           {'annotation': int, 'default': None, 'description': 'The total number of transactions reflected in this settlement.', 'name': 'transaction_count'}],
  'doc_url': 'https://docs.stripe.com/api/settlements/create',
  'op_id': 'PostTestHelpersIssuingSettlements',
  'path': '/v1/test_helpers/issuing/settlements',
  'qparams': [],
  'summary': 'Create a test-mode settlement',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/completes/update',
  'op_id': 'PostTestHelpersIssuingSettlementsSettlementComplete',
  'path': '/v1/test_helpers/issuing/settlements/{settlement}/complete',
  'qparams': [],
  'summary': 'Complete a test-mode settlement',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The total amount to attempt to capture. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Card associated with this transaction.', 'name': 'card'},
           {'annotation': str, 'default': None, 'description': 'The currency of the capture. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.', 'name': 'merchant_data'},
           {'annotation': dict, 'default': None, 'description': 'Additional purchase information that is optionally provided by the merchant.', 'name': 'purchase_details'}],
  'doc_url': 'https://docs.stripe.com/api/create_force_captures/create',
  'op_id': 'PostTestHelpersIssuingTransactionsCreateForceCapture',
  'path': '/v1/test_helpers/issuing/transactions/create_force_capture',
  'qparams': [],
  'summary': 'Create a test-mode force capture',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Card associated with this unlinked refund transaction.', 'name': 'card'},
           {'annotation': str, 'default': None, 'description': 'The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.', 'name': 'merchant_data'},
           {'annotation': dict, 'default': None, 'description': 'Additional purchase information that is optionally provided by the merchant.', 'name': 'purchase_details'}],
  'doc_url': 'https://docs.stripe.com/api/create_unlinked_refunds/create',
  'op_id': 'PostTestHelpersIssuingTransactionsCreateUnlinkedRefund',
  'path': '/v1/test_helpers/issuing/transactions/create_unlinked_refund',
  'qparams': [],
  'summary': 'Create a test-mode unlinked refund',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).', 'name': 'refund_amount'}],
  'doc_url': 'https://docs.stripe.com/api/refunds/update',
  'op_id': 'PostTestHelpersIssuingTransactionsTransactionRefund',
  'path': '/v1/test_helpers/issuing/transactions/{transaction}/refund',
  'qparams': [],
  'summary': 'Refund a test-mode transaction',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/expires/update',
  'op_id': 'PostTestHelpersRefundsRefundExpire',
  'path': '/v1/test_helpers/refunds/{refund}/expire',
  'qparams': [],
  'summary': 'Expire a pending refund.',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Simulated on-reader tip amount.', 'name': 'amount_tip'},
           {'annotation': dict, 'default': None, 'description': 'Simulated data for the card payment method.', 'name': 'card'},
           {'annotation': dict, 'default': None, 'description': 'Simulated data for the card_present payment method.', 'name': 'card_present'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Simulated data for the interac_present payment method.', 'name': 'interac_present'},
           {'annotation': str, 'default': None, 'description': 'Simulated payment type.', 'name': 'type'}],
  'doc_url': 'https://docs.stripe.com/api/present_payment_methods/update',
  'op_id': 'PostTestHelpersTerminalReadersReaderPresentPaymentMethod',
  'path': '/v1/test_helpers/terminal/readers/{reader}/present_payment_method',
  'qparams': [],
  'summary': 'Simulate presenting a payment method',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': str, 'default': None, 'description': 'This parameter defines the skip behavior for input collection.', 'name': 'skip_non_required_inputs'}],
  'doc_url': 'https://docs.stripe.com/api/succeed_input_collections/update',
  'op_id': 'PostTestHelpersTerminalReadersReaderSucceedInputCollection',
  'path': '/v1/test_helpers/terminal/readers/{reader}/succeed_input_collection',
  'qparams': [],
  'summary': 'Simulate a successful input collection',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/timeout_input_collections/update',
  'op_id': 'PostTestHelpersTerminalReadersReaderTimeoutInputCollection',
  'path': '/v1/test_helpers/terminal/readers/{reader}/timeout_input_collection',
  'qparams': [],
  'summary': 'Simulate an input collection timeout',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/test_clocks/list',
  'op_id': 'GetTestHelpersTestClocks',
  'path': '/v1/test_helpers/test_clocks',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all test clocks',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int, 'default': None, 'description': 'The initial frozen time for this test clock.', 'name': 'frozen_time'},
           {'annotation': str, 'default': None, 'description': 'The name for this test clock.', 'name': 'name'}],
  'doc_url': 'https://docs.stripe.com/api/test_clocks/create',
  'op_id': 'PostTestHelpersTestClocks',
  'path': '/v1/test_helpers/test_clocks',
  'qparams': [],
  'summary': 'Create a test clock',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/test_clocks/delete', 'op_id': 'DeleteTestHelpersTestClocksTestClock', 'path': '/v1/test_helpers/test_clocks/{test_clock}', 'qparams': [], 'summary': 'Delete a test clock', 'verb': 'delete'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/test_clocks/delete', 'op_id': 'GetTestHelpersTestClocksTestClock', 'path': '/v1/test_helpers/test_clocks/{test_clock}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a test clock', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': int,
            'default': None,
            'description': "The time to advance the test clock. Must be after the test clock's current frozen time. Cannot be more than two intervals in the future from the shortest subscription in this test clock. If there are no subscriptions in this test clock, it cannot be more than two years in the future.",
            'name': 'frozen_time'}],
  'doc_url': 'https://docs.stripe.com/api/advances/update',
  'op_id': 'PostTestHelpersTestClocksTestClockAdvance',
  'path': '/v1/test_helpers/test_clocks/{test_clock}/advance',
  'qparams': [],
  'summary': 'Advance a test clock',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Details about a failed InboundTransfer.', 'name': 'failure_details'}],
  'doc_url': 'https://docs.stripe.com/api/fails/update',
  'op_id': 'PostTestHelpersTreasuryInboundTransfersIdFail',
  'path': '/v1/test_helpers/treasury/inbound_transfers/{id}/fail',
  'qparams': [],
  'summary': 'Test mode: Fail an InboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/returns/update',
  'op_id': 'PostTestHelpersTreasuryInboundTransfersIdReturn',
  'path': '/v1/test_helpers/treasury/inbound_transfers/{id}/return',
  'qparams': [],
  'summary': 'Test mode: Return an InboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/succeeds/update',
  'op_id': 'PostTestHelpersTreasuryInboundTransfersIdSucceed',
  'path': '/v1/test_helpers/treasury/inbound_transfers/{id}/succeed',
  'qparams': [],
  'summary': 'Test mode: Succeed an InboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Details about network-specific tracking information.', 'name': 'tracking_details'}],
  'doc_url': 'https://docs.stripe.com/api/outbound_payments/update',
  'op_id': 'PostTestHelpersTreasuryOutboundPaymentsId',
  'path': '/v1/test_helpers/treasury/outbound_payments/{id}',
  'qparams': [],
  'summary': 'Test mode: Update an OutboundPayment',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/fails/update',
  'op_id': 'PostTestHelpersTreasuryOutboundPaymentsIdFail',
  'path': '/v1/test_helpers/treasury/outbound_payments/{id}/fail',
  'qparams': [],
  'summary': 'Test mode: Fail an OutboundPayment',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/posts/update',
  'op_id': 'PostTestHelpersTreasuryOutboundPaymentsIdPost',
  'path': '/v1/test_helpers/treasury/outbound_payments/{id}/post',
  'qparams': [],
  'summary': 'Test mode: Post an OutboundPayment',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Optional hash to set the return code.', 'name': 'returned_details'}],
  'doc_url': 'https://docs.stripe.com/api/returns/update',
  'op_id': 'PostTestHelpersTreasuryOutboundPaymentsIdReturn',
  'path': '/v1/test_helpers/treasury/outbound_payments/{id}/return',
  'qparams': [],
  'summary': 'Test mode: Return an OutboundPayment',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Details about network-specific tracking information.', 'name': 'tracking_details'}],
  'doc_url': 'https://docs.stripe.com/api/outbound_transfers/update',
  'op_id': 'PostTestHelpersTreasuryOutboundTransfersOutboundTransfer',
  'path': '/v1/test_helpers/treasury/outbound_transfers/{outbound_transfer}',
  'qparams': [],
  'summary': 'Test mode: Update an OutboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/fails/update',
  'op_id': 'PostTestHelpersTreasuryOutboundTransfersOutboundTransferFail',
  'path': '/v1/test_helpers/treasury/outbound_transfers/{outbound_transfer}/fail',
  'qparams': [],
  'summary': 'Test mode: Fail an OutboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/posts/update',
  'op_id': 'PostTestHelpersTreasuryOutboundTransfersOutboundTransferPost',
  'path': '/v1/test_helpers/treasury/outbound_transfers/{outbound_transfer}/post',
  'qparams': [],
  'summary': 'Test mode: Post an OutboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': 'Details about a returned OutboundTransfer.', 'name': 'returned_details'}],
  'doc_url': 'https://docs.stripe.com/api/returns/update',
  'op_id': 'PostTestHelpersTreasuryOutboundTransfersOutboundTransferReturn',
  'path': '/v1/test_helpers/treasury/outbound_transfers/{outbound_transfer}/return',
  'qparams': [],
  'summary': 'Test mode: Return an OutboundTransfer',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount (in cents) to be transferred.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The FinancialAccount to send funds to.', 'name': 'financial_account'},
           {'annotation': dict, 'default': None, 'description': 'Initiating payment method details for the object.', 'name': 'initiating_payment_method_details'},
           {'annotation': str, 'default': None, 'description': "Specifies the network rails to be used. If not set, will default to the PaymentMethod's preferred network. See the [docs](https://docs.stripe.com/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.", 'name': 'network'}],
  'doc_url': 'https://docs.stripe.com/api/received_credits/create',
  'op_id': 'PostTestHelpersTreasuryReceivedCredits',
  'path': '/v1/test_helpers/treasury/received_credits',
  'qparams': [],
  'summary': 'Test mode: Create a ReceivedCredit',
  'verb': 'post'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount (in cents) to be transferred.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The FinancialAccount to pull funds from.', 'name': 'financial_account'},
           {'annotation': dict, 'default': None, 'description': 'Initiating payment method details for the object.', 'name': 'initiating_payment_method_details'},
           {'annotation': str, 'default': None, 'description': "Specifies the network rails to be used. If not set, will default to the PaymentMethod's preferred network. See the [docs](https://docs.stripe.com/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.", 'name': 'network'}],
  'doc_url': 'https://docs.stripe.com/api/received_debits/create',
  'op_id': 'PostTestHelpersTreasuryReceivedDebits',
  'path': '/v1/test_helpers/treasury/received_debits',
  'qparams': [],
  'summary': 'Test mode: Create a ReceivedDebit',
  'verb': 'post'},
 {'data': [{'annotation': dict, 'default': None, 'description': 'Information for the account this token represents.', 'name': 'account'},
           {'annotation': dict, 'default': None, 'description': 'The bank account this token will represent.', 'name': 'bank_account'},
           {'annotation': object, 'default': None, 'description': "The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user's credit card details, with the options described below.", 'name': 'card'},
           {'annotation': str,
            'default': None,
            'description': "Create a token for the customer, which is owned by the application's account. You can only use this with an [OAuth access token](https://docs.stripe.com/connect/standard-accounts) or [Stripe-Account header](https://docs.stripe.com/connect/authentication). Learn more about [cloning saved payment "
                           'methods](https://docs.stripe.com/connect/cloning-saved-payment-methods).',
            'name': 'customer'},
           {'annotation': dict, 'default': None, 'description': 'The updated CVC value this token represents.', 'name': 'cvc_update'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Information for the person this token represents.', 'name': 'person'},
           {'annotation': dict, 'default': None, 'description': 'The PII this token represents.', 'name': 'pii'}],
  'doc_url': 'https://docs.stripe.com/api/tokens/create',
  'op_id': 'PostTokens',
  'path': '/v1/tokens',
  'qparams': [],
  'summary': 'Create a CVC update token',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/tokens/delete', 'op_id': 'GetTokensToken', 'path': '/v1/tokens/{token}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a token', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/topups/list',
  'op_id': 'GetTopups',
  'path': '/v1/topups',
  'qparams': [{'annotation': 'str', 'description': 'A positive integer representing how much to transfer.', 'name': 'amount'},
              {'annotation': 'str', 'description': 'A filter on the list, based on the object `created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return top-ups that have the given status. One of `canceled`, `failed`, `pending` or `succeeded`.', 'name': 'status'}],
  'summary': 'List all top-ups',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer representing how much to transfer.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'The ID of a source to transfer funds from. For most users, this should be left unspecified which will use the bank account that was set up in the dashboard for the specified currency. In test mode, this can be a test bank token (see [Testing Top-ups](https://docs.stripe.com/connect/testing#testing-top-ups)).',
            'name': 'source'},
           {'annotation': str, 'default': None, 'description': "Extra information about a top-up for the source's bank statement. Limited to 15 ASCII characters.", 'name': 'statement_descriptor'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies this top-up as part of a group.', 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/topups/create',
  'op_id': 'PostTopups',
  'path': '/v1/topups',
  'qparams': [],
  'summary': 'Create a top-up',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/topups/delete', 'op_id': 'GetTopupsTopup', 'path': '/v1/topups/{topup}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a top-up', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/topups/update',
  'op_id': 'PostTopupsTopup',
  'path': '/v1/topups/{topup}',
  'qparams': [],
  'summary': 'Update a top-up',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'doc_url': 'https://docs.stripe.com/api/cancels/update', 'op_id': 'PostTopupsTopupCancel', 'path': '/v1/topups/{topup}/cancel', 'qparams': [], 'summary': 'Cancel a top-up', 'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transfers/list',
  'op_id': 'GetTransfers',
  'path': '/v1/transfers',
  'qparams': [{'annotation': 'str', 'description': 'Only return transfers that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return transfers for the destination specified by this account ID.', 'name': 'destination'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return transfers with the specified transfer group.', 'name': 'transfer_group'}],
  'summary': 'List all transfers',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'A positive integer in cents (or local equivalent) representing how much to transfer.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO code for currency](https://www.iso.org/iso-4217-currency-codes.html) in lowercase. Must be a [supported currency](https://docs.stripe.com/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': 'The ID of a connected Stripe account. <a href="/docs/connect/separate-charges-and-transfers">See the Connect documentation</a> for details.', 'name': 'destination'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'You can use this parameter to transfer funds from a charge before they are added to your available balance. A pending balance will transfer immediately but the funds will not become available until the original charge becomes available. [See the Connect '
                           'documentation](https://docs.stripe.com/connect/separate-charges-and-transfers#transfer-availability) for details.',
            'name': 'source_transaction'},
           {'annotation': str, 'default': None, 'description': 'The source balance to use for this transfer. One of `bank_account`, `card`, or `fpx`. For most users, this will default to `card`.', 'name': 'source_type'},
           {'annotation': str, 'default': None, 'description': 'A string that identifies this transaction as part of a group. See the [Connect documentation](https://docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.', 'name': 'transfer_group'}],
  'doc_url': 'https://docs.stripe.com/api/transfers/create',
  'op_id': 'PostTransfers',
  'path': '/v1/transfers',
  'qparams': [],
  'summary': 'Create a transfer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/reversals/delete',
  'op_id': 'GetTransfersIdReversals',
  'path': '/v1/transfers/{id}/reversals',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all reversals',
  'verb': 'get'},
 {'data': [{'annotation': int,
            'default': None,
            'description': 'A positive integer in cents (or local equivalent) representing how much of this transfer to reverse. Can only reverse up to the unreversed amount remaining of the transfer. Partial transfer reversals are only allowed for transfers to Stripe Accounts. Defaults to the entire transfer amount.',
            'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string which you can attach to a reversal object. This will be unset if you POST an empty value.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': bool,
            'default': None,
            'description': 'Boolean indicating whether the application fee should be refunded when reversing this transfer. If a full transfer reversal is given, the full application fee will be refunded. Otherwise, the application fee will be refunded with an amount proportional to the amount of the transfer reversed.',
            'name': 'refund_application_fee'}],
  'doc_url': 'https://docs.stripe.com/api/reversals/update',
  'op_id': 'PostTransfersIdReversals',
  'path': '/v1/transfers/{id}/reversals',
  'qparams': [],
  'summary': 'Create a transfer reversal',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/transfers/delete', 'op_id': 'GetTransfersTransfer', 'path': '/v1/transfers/{transfer}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a transfer', 'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/transfers/update',
  'op_id': 'PostTransfersTransfer',
  'path': '/v1/transfers/{transfer}',
  'qparams': [],
  'summary': 'Update a transfer',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/reversals/delete', 'op_id': 'GetTransfersTransferReversalsId', 'path': '/v1/transfers/{transfer}/reversals/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a reversal', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'}],
  'doc_url': 'https://docs.stripe.com/api/reversals/update',
  'op_id': 'PostTransfersTransferReversalsId',
  'path': '/v1/transfers/{transfer}/reversals/{id}',
  'qparams': [],
  'summary': 'Update a reversal',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_reversals/list',
  'op_id': 'GetTreasuryCreditReversals',
  'path': '/v1/treasury/credit_reversals',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return CreditReversals for the ReceivedCredit ID.', 'name': 'received_credit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return CreditReversals for a given status.', 'name': 'status'}],
  'summary': 'List all CreditReversals',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The ReceivedCredit to reverse.', 'name': 'received_credit'}],
  'doc_url': 'https://docs.stripe.com/api/credit_reversals/create',
  'op_id': 'PostTreasuryCreditReversals',
  'path': '/v1/treasury/credit_reversals',
  'qparams': [],
  'summary': 'Create a CreditReversal',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/credit_reversals/delete',
  'op_id': 'GetTreasuryCreditReversalsCreditReversal',
  'path': '/v1/treasury/credit_reversals/{credit_reversal}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a CreditReversal',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/debit_reversals/list',
  'op_id': 'GetTreasuryDebitReversals',
  'path': '/v1/treasury/debit_reversals',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return DebitReversals for the ReceivedDebit ID.', 'name': 'received_debit'},
              {'annotation': 'str', 'description': 'Only return DebitReversals for a given resolution.', 'name': 'resolution'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return DebitReversals for a given status.', 'name': 'status'}],
  'summary': 'List all DebitReversals',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The ReceivedDebit to reverse.', 'name': 'received_debit'}],
  'doc_url': 'https://docs.stripe.com/api/debit_reversals/create',
  'op_id': 'PostTreasuryDebitReversals',
  'path': '/v1/treasury/debit_reversals',
  'qparams': [],
  'summary': 'Create a DebitReversal',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/debit_reversals/delete',
  'op_id': 'GetTreasuryDebitReversalsDebitReversal',
  'path': '/v1/treasury/debit_reversals/{debit_reversal}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a DebitReversal',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/financial_accounts/list',
  'op_id': 'GetTreasuryFinancialAccounts',
  'path': '/v1/treasury/financial_accounts',
  'qparams': [{'annotation': 'str', 'description': 'Only return FinancialAccounts that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'An object ID cursor for use in pagination.', 'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit ranging from 1 to 100 (defaults to 10).', 'name': 'limit'},
              {'annotation': 'str', 'description': 'An object ID cursor for use in pagination.', 'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return FinancialAccounts that have the given status: `open` or `closed`', 'name': 'status'}],
  'summary': 'List all FinancialAccounts',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.', 'name': 'features'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The nickname for the FinancialAccount.', 'name': 'nickname'},
           {'annotation': dict, 'default': None, 'description': 'The set of functionalities that the platform can restrict on the FinancialAccount.', 'name': 'platform_restrictions'},
           {'annotation': list, 'default': None, 'description': 'The currencies the FinancialAccount can hold a balance in.', 'name': 'supported_currencies'}],
  'doc_url': 'https://docs.stripe.com/api/financial_accounts/create',
  'op_id': 'PostTreasuryFinancialAccounts',
  'path': '/v1/treasury/financial_accounts',
  'qparams': [],
  'summary': 'Create a FinancialAccount',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/financial_accounts/delete',
  'op_id': 'GetTreasuryFinancialAccountsFinancialAccount',
  'path': '/v1/treasury/financial_accounts/{financial_account}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a FinancialAccount',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated `status_details`. Stripe or the platform may control features via the requested field.', 'name': 'features'},
           {'annotation': dict, 'default': None, 'description': "A different bank account where funds can be deposited/debited in order to get the closing FA's balance to $0", 'name': 'forwarding_settings'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': object, 'default': None, 'description': 'The nickname for the FinancialAccount.', 'name': 'nickname'},
           {'annotation': dict, 'default': None, 'description': 'The set of functionalities that the platform can restrict on the FinancialAccount.', 'name': 'platform_restrictions'}],
  'doc_url': 'https://docs.stripe.com/api/financial_accounts/update',
  'op_id': 'PostTreasuryFinancialAccountsFinancialAccount',
  'path': '/v1/treasury/financial_accounts/{financial_account}',
  'qparams': [],
  'summary': 'Update a FinancialAccount',
  'verb': 'post'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}, {'annotation': dict, 'default': None, 'description': "A different bank account where funds can be deposited/debited in order to get the closing FA's balance to $0", 'name': 'forwarding_settings'}],
  'doc_url': 'https://docs.stripe.com/api/closes/update',
  'op_id': 'PostTreasuryFinancialAccountsFinancialAccountClose',
  'path': '/v1/treasury/financial_accounts/{financial_account}/close',
  'qparams': [],
  'summary': 'Close a FinancialAccount',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/features/delete',
  'op_id': 'GetTreasuryFinancialAccountsFinancialAccountFeatures',
  'path': '/v1/treasury/financial_accounts/{financial_account}/features',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve FinancialAccount Features',
  'verb': 'get'},
 {'data': [{'annotation': dict, 'default': None, 'description': "Encodes the FinancialAccount's ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.", 'name': 'card_issuing'},
           {'annotation': dict, 'default': None, 'description': 'Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.', 'name': 'deposit_insurance'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': dict, 'default': None, 'description': 'Contains Features that add FinancialAddresses to the FinancialAccount.', 'name': 'financial_addresses'},
           {'annotation': dict, 'default': None, 'description': 'Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.', 'name': 'inbound_transfers'},
           {'annotation': dict, 'default': None, 'description': 'Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).', 'name': 'intra_stripe_flows'},
           {'annotation': dict, 'default': None, 'description': "Includes Features related to initiating money movement out of the FinancialAccount to someone else's bucket of money.", 'name': 'outbound_payments'},
           {'annotation': dict, 'default': None, 'description': 'Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.', 'name': 'outbound_transfers'}],
  'doc_url': 'https://docs.stripe.com/api/features/update',
  'op_id': 'PostTreasuryFinancialAccountsFinancialAccountFeatures',
  'path': '/v1/treasury/financial_accounts/{financial_account}/features',
  'qparams': [],
  'summary': 'Update FinancialAccount Features',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/inbound_transfers/list',
  'op_id': 'GetTreasuryInboundTransfers',
  'path': '/v1/treasury/inbound_transfers',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return InboundTransfers that have the given status: `processing`, `succeeded`, `failed` or `canceled`.', 'name': 'status'}],
  'summary': 'List all InboundTransfers',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount (in cents) to be transferred.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The FinancialAccount to send funds to.', 'name': 'financial_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The origin payment method to be debited for the InboundTransfer.', 'name': 'origin_payment_method'},
           {'annotation': str, 'default': None, 'description': "The complete description that appears on your customers' statements. Maximum 10 characters. Can only include -#.$&*, spaces, and alphanumeric characters.", 'name': 'statement_descriptor'}],
  'doc_url': 'https://docs.stripe.com/api/inbound_transfers/create',
  'op_id': 'PostTreasuryInboundTransfers',
  'path': '/v1/treasury/inbound_transfers',
  'qparams': [],
  'summary': 'Create an InboundTransfer',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/inbound_transfers/delete', 'op_id': 'GetTreasuryInboundTransfersId', 'path': '/v1/treasury/inbound_transfers/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an InboundTransfer', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostTreasuryInboundTransfersInboundTransferCancel',
  'path': '/v1/treasury/inbound_transfers/{inbound_transfer}/cancel',
  'qparams': [],
  'summary': 'Cancel an InboundTransfer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/outbound_payments/list',
  'op_id': 'GetTreasuryOutboundPayments',
  'path': '/v1/treasury/outbound_payments',
  'qparams': [{'annotation': 'str', 'description': 'Only return OutboundPayments that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': 'Only return OutboundPayments sent to this customer.', 'name': 'customer'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return OutboundPayments that have the given status: `processing`, `failed`, `posted`, `returned`, or `canceled`.', 'name': 'status'}],
  'summary': 'List all OutboundPayments',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount (in cents) to be transferred.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the `destination_payment_method` passed in.', 'name': 'customer'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': 'The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with `destination_payment_method_data`.', 'name': 'destination_payment_method'},
           {'annotation': dict, 'default': None, 'description': 'Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with `destination_payment_method`.', 'name': 'destination_payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Payment method-specific configuration for this OutboundPayment.', 'name': 'destination_payment_method_options'},
           {'annotation': dict, 'default': None, 'description': 'End user details.', 'name': 'end_user_details'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The FinancialAccount to pull funds from.', 'name': 'financial_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for `ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. Can only include -#.$&*, spaces, and alphanumeric '
                           'characters. The default value is "payment".',
            'name': 'statement_descriptor'}],
  'doc_url': 'https://docs.stripe.com/api/outbound_payments/create',
  'op_id': 'PostTreasuryOutboundPayments',
  'path': '/v1/treasury/outbound_payments',
  'qparams': [],
  'summary': 'Create an OutboundPayment',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/outbound_payments/delete', 'op_id': 'GetTreasuryOutboundPaymentsId', 'path': '/v1/treasury/outbound_payments/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve an OutboundPayment', 'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostTreasuryOutboundPaymentsIdCancel',
  'path': '/v1/treasury/outbound_payments/{id}/cancel',
  'qparams': [],
  'summary': 'Cancel an OutboundPayment',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/outbound_transfers/list',
  'op_id': 'GetTreasuryOutboundTransfers',
  'path': '/v1/treasury/outbound_transfers',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return OutboundTransfers that have the given status: `processing`, `canceled`, `failed`, `posted`, or `returned`.', 'name': 'status'}],
  'summary': 'List all OutboundTransfers',
  'verb': 'get'},
 {'data': [{'annotation': int, 'default': None, 'description': 'Amount (in cents) to be transferred.', 'name': 'amount'},
           {'annotation': str, 'default': None, 'description': 'Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).', 'name': 'currency'},
           {'annotation': str, 'default': None, 'description': 'An arbitrary string attached to the object. Often useful for displaying to users.', 'name': 'description'},
           {'annotation': str, 'default': None, 'description': 'The PaymentMethod to use as the payment instrument for the OutboundTransfer.', 'name': 'destination_payment_method'},
           {'annotation': dict, 'default': None, 'description': 'Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with `destination_payment_method`.', 'name': 'destination_payment_method_data'},
           {'annotation': dict, 'default': None, 'description': 'Hash describing payment method configuration details.', 'name': 'destination_payment_method_options'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': str, 'default': None, 'description': 'The FinancialAccount to pull funds from.', 'name': 'financial_account'},
           {'annotation': dict,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str,
            'default': None,
            'description': 'Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for `ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is "transfer". Can only include -#.$&*, spaces, and alphanumeric characters.',
            'name': 'statement_descriptor'}],
  'doc_url': 'https://docs.stripe.com/api/outbound_transfers/create',
  'op_id': 'PostTreasuryOutboundTransfers',
  'path': '/v1/treasury/outbound_transfers',
  'qparams': [],
  'summary': 'Create an OutboundTransfer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/outbound_transfers/delete',
  'op_id': 'GetTreasuryOutboundTransfersOutboundTransfer',
  'path': '/v1/treasury/outbound_transfers/{outbound_transfer}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve an OutboundTransfer',
  'verb': 'get'},
 {'data': [{'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'doc_url': 'https://docs.stripe.com/api/cancels/update',
  'op_id': 'PostTreasuryOutboundTransfersOutboundTransferCancel',
  'path': '/v1/treasury/outbound_transfers/{outbound_transfer}/cancel',
  'qparams': [],
  'summary': 'Cancel an OutboundTransfer',
  'verb': 'post'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/received_credits/list',
  'op_id': 'GetTreasuryReceivedCredits',
  'path': '/v1/treasury/received_credits',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'The FinancialAccount that received the funds.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'Only return ReceivedCredits described by the flow.', 'name': 'linked_flows'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return ReceivedCredits that have the given status: `succeeded` or `failed`.', 'name': 'status'}],
  'summary': 'List all ReceivedCredits',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/received_credits/delete', 'op_id': 'GetTreasuryReceivedCreditsId', 'path': '/v1/treasury/received_credits/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a ReceivedCredit', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/received_debits/list',
  'op_id': 'GetTreasuryReceivedDebits',
  'path': '/v1/treasury/received_debits',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'The FinancialAccount that funds were pulled from.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return ReceivedDebits that have the given status: `succeeded` or `failed`.', 'name': 'status'}],
  'summary': 'List all ReceivedDebits',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/received_debits/delete', 'op_id': 'GetTreasuryReceivedDebitsId', 'path': '/v1/treasury/received_debits/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a ReceivedDebit', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transaction_entries/list',
  'op_id': 'GetTreasuryTransactionEntries',
  'path': '/v1/treasury/transaction_entries',
  'qparams': [{'annotation': 'str', 'description': 'Only return TransactionEntries that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str', 'description': '', 'name': 'effective_at'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The results are in reverse chronological order by `created` or `effective_at`. The default is `created`.', 'name': 'order_by'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return TransactionEntries associated with this Transaction.', 'name': 'transaction'}],
  'summary': 'List all TransactionEntries',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transaction_entries/delete',
  'op_id': 'GetTreasuryTransactionEntriesId',
  'path': '/v1/treasury/transaction_entries/{id}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a TransactionEntry',
  'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/transactions/list',
  'op_id': 'GetTreasuryTransactions',
  'path': '/v1/treasury/transactions',
  'qparams': [{'annotation': 'str', 'description': 'Only return Transactions that were created during the given date interval.', 'name': 'created'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'Returns objects associated with this FinancialAccount.', 'name': 'financial_account'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str', 'description': 'The results are in reverse chronological order by `created` or `posted_at`. The default is `created`.', 'name': 'order_by'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'},
              {'annotation': 'str', 'description': 'Only return Transactions that have the given status: `open`, `posted`, or `void`.', 'name': 'status'},
              {'annotation': 'str', 'description': 'A filter for the `status_transitions.posted_at` timestamp. When using this filter, `status=posted` and `order_by=posted_at` must also be specified.', 'name': 'status_transitions'}],
  'summary': 'List all Transactions',
  'verb': 'get'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/transactions/delete', 'op_id': 'GetTreasuryTransactionsId', 'path': '/v1/treasury/transactions/{id}', 'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}], 'summary': 'Retrieve a Transaction', 'verb': 'get'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/webhook_endpoints/list',
  'op_id': 'GetWebhookEndpoints',
  'path': '/v1/webhook_endpoints',
  'qparams': [{'annotation': 'str',
               'description': 'A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.',
               'name': 'ending_before'},
              {'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
              {'annotation': 'str', 'description': 'A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.', 'name': 'limit'},
              {'annotation': 'str',
               'description': 'A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.',
               'name': 'starting_after'}],
  'summary': 'List all webhook endpoints',
  'verb': 'get'},
 {'data': [{'annotation': str, 'default': None, 'description': "Events sent to this endpoint will be generated with this Stripe Version instead of your account's default Stripe Version.", 'name': 'api_version'},
           {'annotation': bool, 'default': None, 'description': 'Whether this endpoint should receive events from connected accounts (`true`), or from your account (`false`). Defaults to `false`.', 'name': 'connect'},
           {'annotation': object, 'default': None, 'description': 'An optional description of what the webhook is used for.', 'name': 'description'},
           {'annotation': list, 'default': None, 'description': "The list of events to enable for this endpoint. You may specify `['*']` to enable all events, except those that require explicit selection.", 'name': 'enabled_events'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The URL of the webhook endpoint.', 'name': 'url'}],
  'doc_url': 'https://docs.stripe.com/api/webhook_endpoints/create',
  'op_id': 'PostWebhookEndpoints',
  'path': '/v1/webhook_endpoints',
  'qparams': [],
  'summary': 'Create a webhook endpoint',
  'verb': 'post'},
 {'data': [], 'doc_url': 'https://docs.stripe.com/api/webhook_endpoints/delete', 'op_id': 'DeleteWebhookEndpointsWebhookEndpoint', 'path': '/v1/webhook_endpoints/{webhook_endpoint}', 'qparams': [], 'summary': 'Delete a webhook endpoint', 'verb': 'delete'},
 {'data': [],
  'doc_url': 'https://docs.stripe.com/api/webhook_endpoints/delete',
  'op_id': 'GetWebhookEndpointsWebhookEndpoint',
  'path': '/v1/webhook_endpoints/{webhook_endpoint}',
  'qparams': [{'annotation': 'str', 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'}],
  'summary': 'Retrieve a webhook endpoint',
  'verb': 'get'},
 {'data': [{'annotation': object, 'default': None, 'description': 'An optional description of what the webhook is used for.', 'name': 'description'},
           {'annotation': bool, 'default': None, 'description': 'Disable the webhook endpoint if set to true.', 'name': 'disabled'},
           {'annotation': list, 'default': None, 'description': "The list of events to enable for this endpoint. You may specify `['*']` to enable all events, except those that require explicit selection.", 'name': 'enabled_events'},
           {'annotation': list, 'default': None, 'description': 'Specifies which fields in the response should be expanded.', 'name': 'expand'},
           {'annotation': object,
            'default': None,
            'description': 'Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.',
            'name': 'metadata'},
           {'annotation': str, 'default': None, 'description': 'The URL of the webhook endpoint.', 'name': 'url'}],
  'doc_url': 'https://docs.stripe.com/api/webhook_endpoints/update',
  'op_id': 'PostWebhookEndpointsWebhookEndpoint',
  'path': '/v1/webhook_endpoints/{webhook_endpoint}',
  'qparams': [],
  'summary': 'Update a webhook endpoint',
  'verb': 'post'}]